# ahvac
HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.15.0
- Package version: 1.15.0
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ahvac
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ahvac
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ahvac
from ahvac.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = ahvac.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with ahvac.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ahvac.AuthApi(api_client)
    role = 'role_example' # str | The name of the role as it should appear in Vault.
    alicloud_mount_path = 'alicloud' # str | Path that the backend was mounted at (default to 'alicloud')

    try:
        # Create a role and associate policies to it.
        await api_instance.ali_cloud_delete_auth_role(role, alicloud_mount_path)
    except ApiException as e:
        print("Exception when calling AuthApi->ali_cloud_delete_auth_role: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**ali_cloud_delete_auth_role**](docs/AuthApi.md#ali_cloud_delete_auth_role) | **DELETE** /auth/{alicloud_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**ali_cloud_list_auth_roles**](docs/AuthApi.md#ali_cloud_list_auth_roles) | **GET** /auth/{alicloud_mount_path}/role/ | Lists all the roles that are registered with Vault.
*AuthApi* | [**ali_cloud_list_auth_roles2**](docs/AuthApi.md#ali_cloud_list_auth_roles2) | **GET** /auth/{alicloud_mount_path}/roles/ | Lists all the roles that are registered with Vault.
*AuthApi* | [**ali_cloud_login**](docs/AuthApi.md#ali_cloud_login) | **POST** /auth/{alicloud_mount_path}/login | Authenticates an RAM entity with Vault.
*AuthApi* | [**ali_cloud_read_auth_role**](docs/AuthApi.md#ali_cloud_read_auth_role) | **GET** /auth/{alicloud_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**ali_cloud_write_auth_role**](docs/AuthApi.md#ali_cloud_write_auth_role) | **POST** /auth/{alicloud_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**app_role_delete_bind_secret_id**](docs/AuthApi.md#app_role_delete_bind_secret_id) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/bind-secret-id | 
*AuthApi* | [**app_role_delete_bound_cidr_list**](docs/AuthApi.md#app_role_delete_bound_cidr_list) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/bound-cidr-list | 
*AuthApi* | [**app_role_delete_period**](docs/AuthApi.md#app_role_delete_period) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/period | 
*AuthApi* | [**app_role_delete_policies**](docs/AuthApi.md#app_role_delete_policies) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/policies | 
*AuthApi* | [**app_role_delete_role**](docs/AuthApi.md#app_role_delete_role) | **DELETE** /auth/{approle_mount_path}/role/{role_name} | 
*AuthApi* | [**app_role_delete_secret_id_bound_cidrs**](docs/AuthApi.md#app_role_delete_secret_id_bound_cidrs) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/secret-id-bound-cidrs | 
*AuthApi* | [**app_role_delete_secret_id_num_uses**](docs/AuthApi.md#app_role_delete_secret_id_num_uses) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/secret-id-num-uses | 
*AuthApi* | [**app_role_delete_secret_id_ttl**](docs/AuthApi.md#app_role_delete_secret_id_ttl) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/secret-id-ttl | 
*AuthApi* | [**app_role_delete_token_bound_cidrs**](docs/AuthApi.md#app_role_delete_token_bound_cidrs) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/token-bound-cidrs | 
*AuthApi* | [**app_role_delete_token_max_ttl**](docs/AuthApi.md#app_role_delete_token_max_ttl) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/token-max-ttl | 
*AuthApi* | [**app_role_delete_token_num_uses**](docs/AuthApi.md#app_role_delete_token_num_uses) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/token-num-uses | 
*AuthApi* | [**app_role_delete_token_ttl**](docs/AuthApi.md#app_role_delete_token_ttl) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/token-ttl | 
*AuthApi* | [**app_role_destroy_secret_id**](docs/AuthApi.md#app_role_destroy_secret_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id/destroy | 
*AuthApi* | [**app_role_destroy_secret_id2**](docs/AuthApi.md#app_role_destroy_secret_id2) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/secret-id/destroy | 
*AuthApi* | [**app_role_destroy_secret_id_by_accessor**](docs/AuthApi.md#app_role_destroy_secret_id_by_accessor) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id-accessor/destroy | 
*AuthApi* | [**app_role_destroy_secret_id_by_accessor2**](docs/AuthApi.md#app_role_destroy_secret_id_by_accessor2) | **DELETE** /auth/{approle_mount_path}/role/{role_name}/secret-id-accessor/destroy | 
*AuthApi* | [**app_role_list_roles**](docs/AuthApi.md#app_role_list_roles) | **GET** /auth/{approle_mount_path}/role/ | 
*AuthApi* | [**app_role_list_secret_ids**](docs/AuthApi.md#app_role_list_secret_ids) | **GET** /auth/{approle_mount_path}/role/{role_name}/secret-id/ | 
*AuthApi* | [**app_role_login**](docs/AuthApi.md#app_role_login) | **POST** /auth/{approle_mount_path}/login | 
*AuthApi* | [**app_role_look_up_secret_id**](docs/AuthApi.md#app_role_look_up_secret_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id/lookup | 
*AuthApi* | [**app_role_look_up_secret_id_by_accessor**](docs/AuthApi.md#app_role_look_up_secret_id_by_accessor) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id-accessor/lookup | 
*AuthApi* | [**app_role_read_bind_secret_id**](docs/AuthApi.md#app_role_read_bind_secret_id) | **GET** /auth/{approle_mount_path}/role/{role_name}/bind-secret-id | 
*AuthApi* | [**app_role_read_bound_cidr_list**](docs/AuthApi.md#app_role_read_bound_cidr_list) | **GET** /auth/{approle_mount_path}/role/{role_name}/bound-cidr-list | 
*AuthApi* | [**app_role_read_local_secret_ids**](docs/AuthApi.md#app_role_read_local_secret_ids) | **GET** /auth/{approle_mount_path}/role/{role_name}/local-secret-ids | 
*AuthApi* | [**app_role_read_period**](docs/AuthApi.md#app_role_read_period) | **GET** /auth/{approle_mount_path}/role/{role_name}/period | 
*AuthApi* | [**app_role_read_policies**](docs/AuthApi.md#app_role_read_policies) | **GET** /auth/{approle_mount_path}/role/{role_name}/policies | 
*AuthApi* | [**app_role_read_role**](docs/AuthApi.md#app_role_read_role) | **GET** /auth/{approle_mount_path}/role/{role_name} | 
*AuthApi* | [**app_role_read_role_id**](docs/AuthApi.md#app_role_read_role_id) | **GET** /auth/{approle_mount_path}/role/{role_name}/role-id | 
*AuthApi* | [**app_role_read_secret_id_bound_cidrs**](docs/AuthApi.md#app_role_read_secret_id_bound_cidrs) | **GET** /auth/{approle_mount_path}/role/{role_name}/secret-id-bound-cidrs | 
*AuthApi* | [**app_role_read_secret_id_num_uses**](docs/AuthApi.md#app_role_read_secret_id_num_uses) | **GET** /auth/{approle_mount_path}/role/{role_name}/secret-id-num-uses | 
*AuthApi* | [**app_role_read_secret_id_ttl**](docs/AuthApi.md#app_role_read_secret_id_ttl) | **GET** /auth/{approle_mount_path}/role/{role_name}/secret-id-ttl | 
*AuthApi* | [**app_role_read_token_bound_cidrs**](docs/AuthApi.md#app_role_read_token_bound_cidrs) | **GET** /auth/{approle_mount_path}/role/{role_name}/token-bound-cidrs | 
*AuthApi* | [**app_role_read_token_max_ttl**](docs/AuthApi.md#app_role_read_token_max_ttl) | **GET** /auth/{approle_mount_path}/role/{role_name}/token-max-ttl | 
*AuthApi* | [**app_role_read_token_num_uses**](docs/AuthApi.md#app_role_read_token_num_uses) | **GET** /auth/{approle_mount_path}/role/{role_name}/token-num-uses | 
*AuthApi* | [**app_role_read_token_ttl**](docs/AuthApi.md#app_role_read_token_ttl) | **GET** /auth/{approle_mount_path}/role/{role_name}/token-ttl | 
*AuthApi* | [**app_role_tidy_secret_id**](docs/AuthApi.md#app_role_tidy_secret_id) | **POST** /auth/{approle_mount_path}/tidy/secret-id | 
*AuthApi* | [**app_role_write_bind_secret_id**](docs/AuthApi.md#app_role_write_bind_secret_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/bind-secret-id | 
*AuthApi* | [**app_role_write_bound_cidr_list**](docs/AuthApi.md#app_role_write_bound_cidr_list) | **POST** /auth/{approle_mount_path}/role/{role_name}/bound-cidr-list | 
*AuthApi* | [**app_role_write_custom_secret_id**](docs/AuthApi.md#app_role_write_custom_secret_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/custom-secret-id | 
*AuthApi* | [**app_role_write_period**](docs/AuthApi.md#app_role_write_period) | **POST** /auth/{approle_mount_path}/role/{role_name}/period | 
*AuthApi* | [**app_role_write_policies**](docs/AuthApi.md#app_role_write_policies) | **POST** /auth/{approle_mount_path}/role/{role_name}/policies | 
*AuthApi* | [**app_role_write_role**](docs/AuthApi.md#app_role_write_role) | **POST** /auth/{approle_mount_path}/role/{role_name} | 
*AuthApi* | [**app_role_write_role_id**](docs/AuthApi.md#app_role_write_role_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/role-id | 
*AuthApi* | [**app_role_write_secret_id**](docs/AuthApi.md#app_role_write_secret_id) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id | 
*AuthApi* | [**app_role_write_secret_id_bound_cidrs**](docs/AuthApi.md#app_role_write_secret_id_bound_cidrs) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id-bound-cidrs | 
*AuthApi* | [**app_role_write_secret_id_num_uses**](docs/AuthApi.md#app_role_write_secret_id_num_uses) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id-num-uses | 
*AuthApi* | [**app_role_write_secret_id_ttl**](docs/AuthApi.md#app_role_write_secret_id_ttl) | **POST** /auth/{approle_mount_path}/role/{role_name}/secret-id-ttl | 
*AuthApi* | [**app_role_write_token_bound_cidrs**](docs/AuthApi.md#app_role_write_token_bound_cidrs) | **POST** /auth/{approle_mount_path}/role/{role_name}/token-bound-cidrs | 
*AuthApi* | [**app_role_write_token_max_ttl**](docs/AuthApi.md#app_role_write_token_max_ttl) | **POST** /auth/{approle_mount_path}/role/{role_name}/token-max-ttl | 
*AuthApi* | [**app_role_write_token_num_uses**](docs/AuthApi.md#app_role_write_token_num_uses) | **POST** /auth/{approle_mount_path}/role/{role_name}/token-num-uses | 
*AuthApi* | [**app_role_write_token_ttl**](docs/AuthApi.md#app_role_write_token_ttl) | **POST** /auth/{approle_mount_path}/role/{role_name}/token-ttl | 
*AuthApi* | [**aws_configure_certificate**](docs/AuthApi.md#aws_configure_certificate) | **POST** /auth/{aws_mount_path}/config/certificate/{cert_name} | 
*AuthApi* | [**aws_configure_client**](docs/AuthApi.md#aws_configure_client) | **POST** /auth/{aws_mount_path}/config/client | 
*AuthApi* | [**aws_configure_identity_access_list_tidy_operation**](docs/AuthApi.md#aws_configure_identity_access_list_tidy_operation) | **POST** /auth/{aws_mount_path}/config/tidy/identity-accesslist | 
*AuthApi* | [**aws_configure_identity_integration**](docs/AuthApi.md#aws_configure_identity_integration) | **POST** /auth/{aws_mount_path}/config/identity | 
*AuthApi* | [**aws_configure_identity_whitelist_tidy_operation**](docs/AuthApi.md#aws_configure_identity_whitelist_tidy_operation) | **POST** /auth/{aws_mount_path}/config/tidy/identity-whitelist | 
*AuthApi* | [**aws_configure_role_tag_blacklist_tidy_operation**](docs/AuthApi.md#aws_configure_role_tag_blacklist_tidy_operation) | **POST** /auth/{aws_mount_path}/config/tidy/roletag-blacklist | 
*AuthApi* | [**aws_configure_role_tag_deny_list_tidy_operation**](docs/AuthApi.md#aws_configure_role_tag_deny_list_tidy_operation) | **POST** /auth/{aws_mount_path}/config/tidy/roletag-denylist | 
*AuthApi* | [**aws_delete_auth_role**](docs/AuthApi.md#aws_delete_auth_role) | **DELETE** /auth/{aws_mount_path}/role/{role} | 
*AuthApi* | [**aws_delete_certificate_configuration**](docs/AuthApi.md#aws_delete_certificate_configuration) | **DELETE** /auth/{aws_mount_path}/config/certificate/{cert_name} | 
*AuthApi* | [**aws_delete_client_configuration**](docs/AuthApi.md#aws_delete_client_configuration) | **DELETE** /auth/{aws_mount_path}/config/client | 
*AuthApi* | [**aws_delete_identity_access_list**](docs/AuthApi.md#aws_delete_identity_access_list) | **DELETE** /auth/{aws_mount_path}/identity-accesslist/{instance_id} | 
*AuthApi* | [**aws_delete_identity_access_list_tidy_settings**](docs/AuthApi.md#aws_delete_identity_access_list_tidy_settings) | **DELETE** /auth/{aws_mount_path}/config/tidy/identity-accesslist | 
*AuthApi* | [**aws_delete_identity_whitelist**](docs/AuthApi.md#aws_delete_identity_whitelist) | **DELETE** /auth/{aws_mount_path}/identity-whitelist/{instance_id} | 
*AuthApi* | [**aws_delete_identity_whitelist_tidy_settings**](docs/AuthApi.md#aws_delete_identity_whitelist_tidy_settings) | **DELETE** /auth/{aws_mount_path}/config/tidy/identity-whitelist | 
*AuthApi* | [**aws_delete_role_tag_blacklist**](docs/AuthApi.md#aws_delete_role_tag_blacklist) | **DELETE** /auth/{aws_mount_path}/roletag-blacklist/{role_tag} | 
*AuthApi* | [**aws_delete_role_tag_blacklist_tidy_settings**](docs/AuthApi.md#aws_delete_role_tag_blacklist_tidy_settings) | **DELETE** /auth/{aws_mount_path}/config/tidy/roletag-blacklist | 
*AuthApi* | [**aws_delete_role_tag_deny_list**](docs/AuthApi.md#aws_delete_role_tag_deny_list) | **DELETE** /auth/{aws_mount_path}/roletag-denylist/{role_tag} | 
*AuthApi* | [**aws_delete_role_tag_deny_list_tidy_settings**](docs/AuthApi.md#aws_delete_role_tag_deny_list_tidy_settings) | **DELETE** /auth/{aws_mount_path}/config/tidy/roletag-denylist | 
*AuthApi* | [**aws_delete_sts_role**](docs/AuthApi.md#aws_delete_sts_role) | **DELETE** /auth/{aws_mount_path}/config/sts/{account_id} | 
*AuthApi* | [**aws_list_auth_roles**](docs/AuthApi.md#aws_list_auth_roles) | **GET** /auth/{aws_mount_path}/role/ | 
*AuthApi* | [**aws_list_auth_roles2**](docs/AuthApi.md#aws_list_auth_roles2) | **GET** /auth/{aws_mount_path}/roles/ | 
*AuthApi* | [**aws_list_certificate_configurations**](docs/AuthApi.md#aws_list_certificate_configurations) | **GET** /auth/{aws_mount_path}/config/certificates/ | 
*AuthApi* | [**aws_list_identity_access_list**](docs/AuthApi.md#aws_list_identity_access_list) | **GET** /auth/{aws_mount_path}/identity-accesslist/ | 
*AuthApi* | [**aws_list_identity_whitelist**](docs/AuthApi.md#aws_list_identity_whitelist) | **GET** /auth/{aws_mount_path}/identity-whitelist/ | 
*AuthApi* | [**aws_list_role_tag_blacklists**](docs/AuthApi.md#aws_list_role_tag_blacklists) | **GET** /auth/{aws_mount_path}/roletag-blacklist/ | 
*AuthApi* | [**aws_list_role_tag_deny_lists**](docs/AuthApi.md#aws_list_role_tag_deny_lists) | **GET** /auth/{aws_mount_path}/roletag-denylist/ | 
*AuthApi* | [**aws_list_sts_role_relationships**](docs/AuthApi.md#aws_list_sts_role_relationships) | **GET** /auth/{aws_mount_path}/config/sts/ | 
*AuthApi* | [**aws_login**](docs/AuthApi.md#aws_login) | **POST** /auth/{aws_mount_path}/login | 
*AuthApi* | [**aws_read_auth_role**](docs/AuthApi.md#aws_read_auth_role) | **GET** /auth/{aws_mount_path}/role/{role} | 
*AuthApi* | [**aws_read_certificate_configuration**](docs/AuthApi.md#aws_read_certificate_configuration) | **GET** /auth/{aws_mount_path}/config/certificate/{cert_name} | 
*AuthApi* | [**aws_read_client_configuration**](docs/AuthApi.md#aws_read_client_configuration) | **GET** /auth/{aws_mount_path}/config/client | 
*AuthApi* | [**aws_read_identity_access_list**](docs/AuthApi.md#aws_read_identity_access_list) | **GET** /auth/{aws_mount_path}/identity-accesslist/{instance_id} | 
*AuthApi* | [**aws_read_identity_access_list_tidy_settings**](docs/AuthApi.md#aws_read_identity_access_list_tidy_settings) | **GET** /auth/{aws_mount_path}/config/tidy/identity-accesslist | 
*AuthApi* | [**aws_read_identity_integration_configuration**](docs/AuthApi.md#aws_read_identity_integration_configuration) | **GET** /auth/{aws_mount_path}/config/identity | 
*AuthApi* | [**aws_read_identity_whitelist**](docs/AuthApi.md#aws_read_identity_whitelist) | **GET** /auth/{aws_mount_path}/identity-whitelist/{instance_id} | 
*AuthApi* | [**aws_read_identity_whitelist_tidy_settings**](docs/AuthApi.md#aws_read_identity_whitelist_tidy_settings) | **GET** /auth/{aws_mount_path}/config/tidy/identity-whitelist | 
*AuthApi* | [**aws_read_role_tag_blacklist**](docs/AuthApi.md#aws_read_role_tag_blacklist) | **GET** /auth/{aws_mount_path}/roletag-blacklist/{role_tag} | 
*AuthApi* | [**aws_read_role_tag_blacklist_tidy_settings**](docs/AuthApi.md#aws_read_role_tag_blacklist_tidy_settings) | **GET** /auth/{aws_mount_path}/config/tidy/roletag-blacklist | 
*AuthApi* | [**aws_read_role_tag_deny_list**](docs/AuthApi.md#aws_read_role_tag_deny_list) | **GET** /auth/{aws_mount_path}/roletag-denylist/{role_tag} | 
*AuthApi* | [**aws_read_role_tag_deny_list_tidy_settings**](docs/AuthApi.md#aws_read_role_tag_deny_list_tidy_settings) | **GET** /auth/{aws_mount_path}/config/tidy/roletag-denylist | 
*AuthApi* | [**aws_read_sts_role**](docs/AuthApi.md#aws_read_sts_role) | **GET** /auth/{aws_mount_path}/config/sts/{account_id} | 
*AuthApi* | [**aws_rotate_root_credentials**](docs/AuthApi.md#aws_rotate_root_credentials) | **POST** /auth/{aws_mount_path}/config/rotate-root | 
*AuthApi* | [**aws_tidy_identity_access_list**](docs/AuthApi.md#aws_tidy_identity_access_list) | **POST** /auth/{aws_mount_path}/tidy/identity-accesslist | 
*AuthApi* | [**aws_tidy_identity_whitelist**](docs/AuthApi.md#aws_tidy_identity_whitelist) | **POST** /auth/{aws_mount_path}/tidy/identity-whitelist | 
*AuthApi* | [**aws_tidy_role_tag_blacklist**](docs/AuthApi.md#aws_tidy_role_tag_blacklist) | **POST** /auth/{aws_mount_path}/tidy/roletag-blacklist | 
*AuthApi* | [**aws_tidy_role_tag_deny_list**](docs/AuthApi.md#aws_tidy_role_tag_deny_list) | **POST** /auth/{aws_mount_path}/tidy/roletag-denylist | 
*AuthApi* | [**aws_write_auth_role**](docs/AuthApi.md#aws_write_auth_role) | **POST** /auth/{aws_mount_path}/role/{role} | 
*AuthApi* | [**aws_write_role_tag**](docs/AuthApi.md#aws_write_role_tag) | **POST** /auth/{aws_mount_path}/role/{role}/tag | 
*AuthApi* | [**aws_write_role_tag_blacklist**](docs/AuthApi.md#aws_write_role_tag_blacklist) | **POST** /auth/{aws_mount_path}/roletag-blacklist/{role_tag} | 
*AuthApi* | [**aws_write_role_tag_deny_list**](docs/AuthApi.md#aws_write_role_tag_deny_list) | **POST** /auth/{aws_mount_path}/roletag-denylist/{role_tag} | 
*AuthApi* | [**aws_write_sts_role**](docs/AuthApi.md#aws_write_sts_role) | **POST** /auth/{aws_mount_path}/config/sts/{account_id} | 
*AuthApi* | [**azure_configure_auth**](docs/AuthApi.md#azure_configure_auth) | **POST** /auth/{azure_mount_path}/config | 
*AuthApi* | [**azure_delete_auth_configuration**](docs/AuthApi.md#azure_delete_auth_configuration) | **DELETE** /auth/{azure_mount_path}/config | 
*AuthApi* | [**azure_delete_auth_role**](docs/AuthApi.md#azure_delete_auth_role) | **DELETE** /auth/{azure_mount_path}/role/{name} | 
*AuthApi* | [**azure_list_auth_roles**](docs/AuthApi.md#azure_list_auth_roles) | **GET** /auth/{azure_mount_path}/role/ | 
*AuthApi* | [**azure_login**](docs/AuthApi.md#azure_login) | **POST** /auth/{azure_mount_path}/login | 
*AuthApi* | [**azure_read_auth_configuration**](docs/AuthApi.md#azure_read_auth_configuration) | **GET** /auth/{azure_mount_path}/config | 
*AuthApi* | [**azure_read_auth_role**](docs/AuthApi.md#azure_read_auth_role) | **GET** /auth/{azure_mount_path}/role/{name} | 
*AuthApi* | [**azure_rotate_root_credentials**](docs/AuthApi.md#azure_rotate_root_credentials) | **POST** /auth/{azure_mount_path}/rotate-root | 
*AuthApi* | [**azure_write_auth_role**](docs/AuthApi.md#azure_write_auth_role) | **POST** /auth/{azure_mount_path}/role/{name} | 
*AuthApi* | [**centrify_configure**](docs/AuthApi.md#centrify_configure) | **POST** /auth/{centrify_mount_path}/config | 
*AuthApi* | [**centrify_login**](docs/AuthApi.md#centrify_login) | **POST** /auth/{centrify_mount_path}/login | Log in with a username and password.
*AuthApi* | [**centrify_read_configuration**](docs/AuthApi.md#centrify_read_configuration) | **GET** /auth/{centrify_mount_path}/config | 
*AuthApi* | [**cert_configure**](docs/AuthApi.md#cert_configure) | **POST** /auth/{cert_mount_path}/config | 
*AuthApi* | [**cert_delete_certificate**](docs/AuthApi.md#cert_delete_certificate) | **DELETE** /auth/{cert_mount_path}/certs/{name} | Manage trusted certificates used for authentication.
*AuthApi* | [**cert_delete_crl**](docs/AuthApi.md#cert_delete_crl) | **DELETE** /auth/{cert_mount_path}/crls/{name} | Manage Certificate Revocation Lists checked during authentication.
*AuthApi* | [**cert_list_certificates**](docs/AuthApi.md#cert_list_certificates) | **GET** /auth/{cert_mount_path}/certs/ | Manage trusted certificates used for authentication.
*AuthApi* | [**cert_list_crls**](docs/AuthApi.md#cert_list_crls) | **GET** /auth/{cert_mount_path}/crls/ | 
*AuthApi* | [**cert_login**](docs/AuthApi.md#cert_login) | **POST** /auth/{cert_mount_path}/login | 
*AuthApi* | [**cert_read_certificate**](docs/AuthApi.md#cert_read_certificate) | **GET** /auth/{cert_mount_path}/certs/{name} | Manage trusted certificates used for authentication.
*AuthApi* | [**cert_read_configuration**](docs/AuthApi.md#cert_read_configuration) | **GET** /auth/{cert_mount_path}/config | 
*AuthApi* | [**cert_read_crl**](docs/AuthApi.md#cert_read_crl) | **GET** /auth/{cert_mount_path}/crls/{name} | Manage Certificate Revocation Lists checked during authentication.
*AuthApi* | [**cert_write_certificate**](docs/AuthApi.md#cert_write_certificate) | **POST** /auth/{cert_mount_path}/certs/{name} | Manage trusted certificates used for authentication.
*AuthApi* | [**cert_write_crl**](docs/AuthApi.md#cert_write_crl) | **POST** /auth/{cert_mount_path}/crls/{name} | Manage Certificate Revocation Lists checked during authentication.
*AuthApi* | [**cloud_foundry_configure**](docs/AuthApi.md#cloud_foundry_configure) | **POST** /auth/{cf_mount_path}/config | 
*AuthApi* | [**cloud_foundry_delete_configuration**](docs/AuthApi.md#cloud_foundry_delete_configuration) | **DELETE** /auth/{cf_mount_path}/config | 
*AuthApi* | [**cloud_foundry_delete_role**](docs/AuthApi.md#cloud_foundry_delete_role) | **DELETE** /auth/{cf_mount_path}/roles/{role} | 
*AuthApi* | [**cloud_foundry_list_roles**](docs/AuthApi.md#cloud_foundry_list_roles) | **GET** /auth/{cf_mount_path}/roles/ | 
*AuthApi* | [**cloud_foundry_login**](docs/AuthApi.md#cloud_foundry_login) | **POST** /auth/{cf_mount_path}/login | 
*AuthApi* | [**cloud_foundry_read_configuration**](docs/AuthApi.md#cloud_foundry_read_configuration) | **GET** /auth/{cf_mount_path}/config | 
*AuthApi* | [**cloud_foundry_read_role**](docs/AuthApi.md#cloud_foundry_read_role) | **GET** /auth/{cf_mount_path}/roles/{role} | 
*AuthApi* | [**cloud_foundry_write_role**](docs/AuthApi.md#cloud_foundry_write_role) | **POST** /auth/{cf_mount_path}/roles/{role} | 
*AuthApi* | [**github_configure**](docs/AuthApi.md#github_configure) | **POST** /auth/{github_mount_path}/config | 
*AuthApi* | [**github_delete_team_mapping**](docs/AuthApi.md#github_delete_team_mapping) | **DELETE** /auth/{github_mount_path}/map/teams/{key} | Read/write/delete a single teams mapping
*AuthApi* | [**github_delete_user_mapping**](docs/AuthApi.md#github_delete_user_mapping) | **DELETE** /auth/{github_mount_path}/map/users/{key} | Read/write/delete a single users mapping
*AuthApi* | [**github_list_teams**](docs/AuthApi.md#github_list_teams) | **GET** /auth/{github_mount_path}/map/teams/ | Read mappings for teams
*AuthApi* | [**github_list_teams2**](docs/AuthApi.md#github_list_teams2) | **GET** /auth/{github_mount_path}/map/teams | Read mappings for teams
*AuthApi* | [**github_list_users**](docs/AuthApi.md#github_list_users) | **GET** /auth/{github_mount_path}/map/users/ | Read mappings for users
*AuthApi* | [**github_list_users2**](docs/AuthApi.md#github_list_users2) | **GET** /auth/{github_mount_path}/map/users | Read mappings for users
*AuthApi* | [**github_login**](docs/AuthApi.md#github_login) | **POST** /auth/{github_mount_path}/login | 
*AuthApi* | [**github_read_configuration**](docs/AuthApi.md#github_read_configuration) | **GET** /auth/{github_mount_path}/config | 
*AuthApi* | [**github_read_team_mapping**](docs/AuthApi.md#github_read_team_mapping) | **GET** /auth/{github_mount_path}/map/teams/{key} | Read/write/delete a single teams mapping
*AuthApi* | [**github_read_user_mapping**](docs/AuthApi.md#github_read_user_mapping) | **GET** /auth/{github_mount_path}/map/users/{key} | Read/write/delete a single users mapping
*AuthApi* | [**github_write_team_mapping**](docs/AuthApi.md#github_write_team_mapping) | **POST** /auth/{github_mount_path}/map/teams/{key} | Read/write/delete a single teams mapping
*AuthApi* | [**github_write_user_mapping**](docs/AuthApi.md#github_write_user_mapping) | **POST** /auth/{github_mount_path}/map/users/{key} | Read/write/delete a single users mapping
*AuthApi* | [**google_cloud_configure_auth**](docs/AuthApi.md#google_cloud_configure_auth) | **POST** /auth/{gcp_mount_path}/config | 
*AuthApi* | [**google_cloud_delete_role**](docs/AuthApi.md#google_cloud_delete_role) | **DELETE** /auth/{gcp_mount_path}/role/{name} | Create a GCP role with associated policies and required attributes.
*AuthApi* | [**google_cloud_edit_labels_for_role**](docs/AuthApi.md#google_cloud_edit_labels_for_role) | **POST** /auth/{gcp_mount_path}/role/{name}/labels | Add or remove labels for an existing &#39;gce&#39; role
*AuthApi* | [**google_cloud_edit_service_accounts_for_role**](docs/AuthApi.md#google_cloud_edit_service_accounts_for_role) | **POST** /auth/{gcp_mount_path}/role/{name}/service-accounts | Add or remove service accounts for an existing &#x60;iam&#x60; role
*AuthApi* | [**google_cloud_list_roles**](docs/AuthApi.md#google_cloud_list_roles) | **GET** /auth/{gcp_mount_path}/role/ | Lists all the roles that are registered with Vault.
*AuthApi* | [**google_cloud_list_roles2**](docs/AuthApi.md#google_cloud_list_roles2) | **GET** /auth/{gcp_mount_path}/roles/ | Lists all the roles that are registered with Vault.
*AuthApi* | [**google_cloud_login**](docs/AuthApi.md#google_cloud_login) | **POST** /auth/{gcp_mount_path}/login | 
*AuthApi* | [**google_cloud_read_auth_configuration**](docs/AuthApi.md#google_cloud_read_auth_configuration) | **GET** /auth/{gcp_mount_path}/config | 
*AuthApi* | [**google_cloud_read_role**](docs/AuthApi.md#google_cloud_read_role) | **GET** /auth/{gcp_mount_path}/role/{name} | Create a GCP role with associated policies and required attributes.
*AuthApi* | [**google_cloud_write_role**](docs/AuthApi.md#google_cloud_write_role) | **POST** /auth/{gcp_mount_path}/role/{name} | Create a GCP role with associated policies and required attributes.
*AuthApi* | [**jwt_configure**](docs/AuthApi.md#jwt_configure) | **POST** /auth/{jwt_mount_path}/config | Configure the JWT authentication backend.
*AuthApi* | [**jwt_delete_role**](docs/AuthApi.md#jwt_delete_role) | **DELETE** /auth/{jwt_mount_path}/role/{name} | Delete an existing role.
*AuthApi* | [**jwt_list_roles**](docs/AuthApi.md#jwt_list_roles) | **GET** /auth/{jwt_mount_path}/role/ | Lists all the roles registered with the backend.
*AuthApi* | [**jwt_login**](docs/AuthApi.md#jwt_login) | **POST** /auth/{jwt_mount_path}/login | Authenticates to Vault using a JWT (or OIDC) token.
*AuthApi* | [**jwt_oidc_callback**](docs/AuthApi.md#jwt_oidc_callback) | **GET** /auth/{jwt_mount_path}/oidc/callback | Callback endpoint to complete an OIDC login.
*AuthApi* | [**jwt_oidc_callback_form_post**](docs/AuthApi.md#jwt_oidc_callback_form_post) | **POST** /auth/{jwt_mount_path}/oidc/callback | Callback endpoint to handle form_posts.
*AuthApi* | [**jwt_oidc_request_authorization_url**](docs/AuthApi.md#jwt_oidc_request_authorization_url) | **POST** /auth/{jwt_mount_path}/oidc/auth_url | Request an authorization URL to start an OIDC login flow.
*AuthApi* | [**jwt_read_configuration**](docs/AuthApi.md#jwt_read_configuration) | **GET** /auth/{jwt_mount_path}/config | Read the current JWT authentication backend configuration.
*AuthApi* | [**jwt_read_role**](docs/AuthApi.md#jwt_read_role) | **GET** /auth/{jwt_mount_path}/role/{name} | Read an existing role.
*AuthApi* | [**jwt_write_role**](docs/AuthApi.md#jwt_write_role) | **POST** /auth/{jwt_mount_path}/role/{name} | Register an role with the backend.
*AuthApi* | [**kerberos_configure**](docs/AuthApi.md#kerberos_configure) | **POST** /auth/{kerberos_mount_path}/config | 
*AuthApi* | [**kerberos_configure_ldap**](docs/AuthApi.md#kerberos_configure_ldap) | **POST** /auth/{kerberos_mount_path}/config/ldap | 
*AuthApi* | [**kerberos_delete_group**](docs/AuthApi.md#kerberos_delete_group) | **DELETE** /auth/{kerberos_mount_path}/groups/{name} | 
*AuthApi* | [**kerberos_list_groups**](docs/AuthApi.md#kerberos_list_groups) | **GET** /auth/{kerberos_mount_path}/groups/ | 
*AuthApi* | [**kerberos_login**](docs/AuthApi.md#kerberos_login) | **POST** /auth/{kerberos_mount_path}/login | 
*AuthApi* | [**kerberos_login2**](docs/AuthApi.md#kerberos_login2) | **GET** /auth/{kerberos_mount_path}/login | 
*AuthApi* | [**kerberos_read_configuration**](docs/AuthApi.md#kerberos_read_configuration) | **GET** /auth/{kerberos_mount_path}/config | 
*AuthApi* | [**kerberos_read_group**](docs/AuthApi.md#kerberos_read_group) | **GET** /auth/{kerberos_mount_path}/groups/{name} | 
*AuthApi* | [**kerberos_read_ldap_configuration**](docs/AuthApi.md#kerberos_read_ldap_configuration) | **GET** /auth/{kerberos_mount_path}/config/ldap | 
*AuthApi* | [**kerberos_write_group**](docs/AuthApi.md#kerberos_write_group) | **POST** /auth/{kerberos_mount_path}/groups/{name} | 
*AuthApi* | [**kubernetes_configure_auth**](docs/AuthApi.md#kubernetes_configure_auth) | **POST** /auth/{kubernetes_mount_path}/config | 
*AuthApi* | [**kubernetes_delete_auth_role**](docs/AuthApi.md#kubernetes_delete_auth_role) | **DELETE** /auth/{kubernetes_mount_path}/role/{name} | Register an role with the backend.
*AuthApi* | [**kubernetes_list_auth_roles**](docs/AuthApi.md#kubernetes_list_auth_roles) | **GET** /auth/{kubernetes_mount_path}/role/ | Lists all the roles registered with the backend.
*AuthApi* | [**kubernetes_login**](docs/AuthApi.md#kubernetes_login) | **POST** /auth/{kubernetes_mount_path}/login | Authenticates Kubernetes service accounts with Vault.
*AuthApi* | [**kubernetes_read_auth_configuration**](docs/AuthApi.md#kubernetes_read_auth_configuration) | **GET** /auth/{kubernetes_mount_path}/config | 
*AuthApi* | [**kubernetes_read_auth_role**](docs/AuthApi.md#kubernetes_read_auth_role) | **GET** /auth/{kubernetes_mount_path}/role/{name} | Register an role with the backend.
*AuthApi* | [**kubernetes_write_auth_role**](docs/AuthApi.md#kubernetes_write_auth_role) | **POST** /auth/{kubernetes_mount_path}/role/{name} | Register an role with the backend.
*AuthApi* | [**ldap_configure_auth**](docs/AuthApi.md#ldap_configure_auth) | **POST** /auth/{ldap_mount_path}/config | 
*AuthApi* | [**ldap_delete_group**](docs/AuthApi.md#ldap_delete_group) | **DELETE** /auth/{ldap_mount_path}/groups/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**ldap_delete_user**](docs/AuthApi.md#ldap_delete_user) | **DELETE** /auth/{ldap_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**ldap_list_groups**](docs/AuthApi.md#ldap_list_groups) | **GET** /auth/{ldap_mount_path}/groups/ | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**ldap_list_users**](docs/AuthApi.md#ldap_list_users) | **GET** /auth/{ldap_mount_path}/users/ | Manage users allowed to authenticate.
*AuthApi* | [**ldap_login**](docs/AuthApi.md#ldap_login) | **POST** /auth/{ldap_mount_path}/login/{username} | Log in with a username and password.
*AuthApi* | [**ldap_read_auth_configuration**](docs/AuthApi.md#ldap_read_auth_configuration) | **GET** /auth/{ldap_mount_path}/config | 
*AuthApi* | [**ldap_read_group**](docs/AuthApi.md#ldap_read_group) | **GET** /auth/{ldap_mount_path}/groups/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**ldap_read_user**](docs/AuthApi.md#ldap_read_user) | **GET** /auth/{ldap_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**ldap_write_group**](docs/AuthApi.md#ldap_write_group) | **POST** /auth/{ldap_mount_path}/groups/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**ldap_write_user**](docs/AuthApi.md#ldap_write_user) | **POST** /auth/{ldap_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**oci_configure**](docs/AuthApi.md#oci_configure) | **POST** /auth/{oci_mount_path}/config | 
*AuthApi* | [**oci_delete_configuration**](docs/AuthApi.md#oci_delete_configuration) | **DELETE** /auth/{oci_mount_path}/config | 
*AuthApi* | [**oci_delete_role**](docs/AuthApi.md#oci_delete_role) | **DELETE** /auth/{oci_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**oci_list_roles**](docs/AuthApi.md#oci_list_roles) | **GET** /auth/{oci_mount_path}/role/ | Lists all the roles that are registered with Vault.
*AuthApi* | [**oci_login**](docs/AuthApi.md#oci_login) | **POST** /auth/{oci_mount_path}/login/{role} | Authenticates to Vault using OCI credentials
*AuthApi* | [**oci_read_configuration**](docs/AuthApi.md#oci_read_configuration) | **GET** /auth/{oci_mount_path}/config | 
*AuthApi* | [**oci_read_role**](docs/AuthApi.md#oci_read_role) | **GET** /auth/{oci_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**oci_write_role**](docs/AuthApi.md#oci_write_role) | **POST** /auth/{oci_mount_path}/role/{role} | Create a role and associate policies to it.
*AuthApi* | [**okta_configure**](docs/AuthApi.md#okta_configure) | **POST** /auth/{okta_mount_path}/config | 
*AuthApi* | [**okta_delete_group**](docs/AuthApi.md#okta_delete_group) | **DELETE** /auth/{okta_mount_path}/groups/{name} | Manage users allowed to authenticate.
*AuthApi* | [**okta_delete_user**](docs/AuthApi.md#okta_delete_user) | **DELETE** /auth/{okta_mount_path}/users/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**okta_list_groups**](docs/AuthApi.md#okta_list_groups) | **GET** /auth/{okta_mount_path}/groups/ | Manage users allowed to authenticate.
*AuthApi* | [**okta_list_users**](docs/AuthApi.md#okta_list_users) | **GET** /auth/{okta_mount_path}/users/ | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**okta_login**](docs/AuthApi.md#okta_login) | **POST** /auth/{okta_mount_path}/login/{username} | Log in with a username and password.
*AuthApi* | [**okta_read_configuration**](docs/AuthApi.md#okta_read_configuration) | **GET** /auth/{okta_mount_path}/config | 
*AuthApi* | [**okta_read_group**](docs/AuthApi.md#okta_read_group) | **GET** /auth/{okta_mount_path}/groups/{name} | Manage users allowed to authenticate.
*AuthApi* | [**okta_read_user**](docs/AuthApi.md#okta_read_user) | **GET** /auth/{okta_mount_path}/users/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**okta_verify**](docs/AuthApi.md#okta_verify) | **GET** /auth/{okta_mount_path}/verify/{nonce} | 
*AuthApi* | [**okta_write_group**](docs/AuthApi.md#okta_write_group) | **POST** /auth/{okta_mount_path}/groups/{name} | Manage users allowed to authenticate.
*AuthApi* | [**okta_write_user**](docs/AuthApi.md#okta_write_user) | **POST** /auth/{okta_mount_path}/users/{name} | Manage additional groups for users allowed to authenticate.
*AuthApi* | [**radius_configure**](docs/AuthApi.md#radius_configure) | **POST** /auth/{radius_mount_path}/config | 
*AuthApi* | [**radius_delete_user**](docs/AuthApi.md#radius_delete_user) | **DELETE** /auth/{radius_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**radius_list_users**](docs/AuthApi.md#radius_list_users) | **GET** /auth/{radius_mount_path}/users/ | Manage users allowed to authenticate.
*AuthApi* | [**radius_login**](docs/AuthApi.md#radius_login) | **POST** /auth/{radius_mount_path}/login | Log in with a username and password.
*AuthApi* | [**radius_login_with_username**](docs/AuthApi.md#radius_login_with_username) | **POST** /auth/{radius_mount_path}/login/{urlusername} | Log in with a username and password.
*AuthApi* | [**radius_read_configuration**](docs/AuthApi.md#radius_read_configuration) | **GET** /auth/{radius_mount_path}/config | 
*AuthApi* | [**radius_read_user**](docs/AuthApi.md#radius_read_user) | **GET** /auth/{radius_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**radius_write_user**](docs/AuthApi.md#radius_write_user) | **POST** /auth/{radius_mount_path}/users/{name} | Manage users allowed to authenticate.
*AuthApi* | [**token_create**](docs/AuthApi.md#token_create) | **POST** /auth/token/create | The token create path is used to create new tokens.
*AuthApi* | [**token_create_against_role**](docs/AuthApi.md#token_create_against_role) | **POST** /auth/token/create/{role_name} | This token create path is used to create new tokens adhering to the given role.
*AuthApi* | [**token_create_orphan**](docs/AuthApi.md#token_create_orphan) | **POST** /auth/token/create-orphan | The token create path is used to create new orphan tokens.
*AuthApi* | [**token_delete_role**](docs/AuthApi.md#token_delete_role) | **DELETE** /auth/token/roles/{role_name} | 
*AuthApi* | [**token_list_accessors**](docs/AuthApi.md#token_list_accessors) | **GET** /auth/token/accessors/ | List token accessors, which can then be be used to iterate and discover their properties or revoke them. Because this can be used to cause a denial of service, this endpoint requires &#39;sudo&#39; capability in addition to &#39;list&#39;.
*AuthApi* | [**token_list_roles**](docs/AuthApi.md#token_list_roles) | **GET** /auth/token/roles/ | This endpoint lists configured roles.
*AuthApi* | [**token_look_up**](docs/AuthApi.md#token_look_up) | **POST** /auth/token/lookup | 
*AuthApi* | [**token_look_up2**](docs/AuthApi.md#token_look_up2) | **GET** /auth/token/lookup | 
*AuthApi* | [**token_look_up_accessor**](docs/AuthApi.md#token_look_up_accessor) | **POST** /auth/token/lookup-accessor | This endpoint will lookup a token associated with the given accessor and its properties. Response will not contain the token ID.
*AuthApi* | [**token_look_up_self**](docs/AuthApi.md#token_look_up_self) | **GET** /auth/token/lookup-self | 
*AuthApi* | [**token_look_up_self2**](docs/AuthApi.md#token_look_up_self2) | **POST** /auth/token/lookup-self | 
*AuthApi* | [**token_read_role**](docs/AuthApi.md#token_read_role) | **GET** /auth/token/roles/{role_name} | 
*AuthApi* | [**token_renew**](docs/AuthApi.md#token_renew) | **POST** /auth/token/renew | This endpoint will renew the given token and prevent expiration.
*AuthApi* | [**token_renew_accessor**](docs/AuthApi.md#token_renew_accessor) | **POST** /auth/token/renew-accessor | This endpoint will renew a token associated with the given accessor and its properties. Response will not contain the token ID.
*AuthApi* | [**token_renew_self**](docs/AuthApi.md#token_renew_self) | **POST** /auth/token/renew-self | This endpoint will renew the token used to call it and prevent expiration.
*AuthApi* | [**token_revoke**](docs/AuthApi.md#token_revoke) | **POST** /auth/token/revoke | This endpoint will delete the given token and all of its child tokens.
*AuthApi* | [**token_revoke_accessor**](docs/AuthApi.md#token_revoke_accessor) | **POST** /auth/token/revoke-accessor | This endpoint will delete the token associated with the accessor and all of its child tokens.
*AuthApi* | [**token_revoke_orphan**](docs/AuthApi.md#token_revoke_orphan) | **POST** /auth/token/revoke-orphan | This endpoint will delete the token and orphan its child tokens.
*AuthApi* | [**token_revoke_self**](docs/AuthApi.md#token_revoke_self) | **POST** /auth/token/revoke-self | This endpoint will delete the token used to call it and all of its child tokens.
*AuthApi* | [**token_tidy**](docs/AuthApi.md#token_tidy) | **POST** /auth/token/tidy | This endpoint performs cleanup tasks that can be run if certain error conditions have occurred.
*AuthApi* | [**token_write_role**](docs/AuthApi.md#token_write_role) | **POST** /auth/token/roles/{role_name} | 
*AuthApi* | [**userpass_delete_user**](docs/AuthApi.md#userpass_delete_user) | **DELETE** /auth/{userpass_mount_path}/users/{username} | Manage users allowed to authenticate.
*AuthApi* | [**userpass_list_users**](docs/AuthApi.md#userpass_list_users) | **GET** /auth/{userpass_mount_path}/users/ | Manage users allowed to authenticate.
*AuthApi* | [**userpass_login**](docs/AuthApi.md#userpass_login) | **POST** /auth/{userpass_mount_path}/login/{username} | Log in with a username and password.
*AuthApi* | [**userpass_read_user**](docs/AuthApi.md#userpass_read_user) | **GET** /auth/{userpass_mount_path}/users/{username} | Manage users allowed to authenticate.
*AuthApi* | [**userpass_reset_password**](docs/AuthApi.md#userpass_reset_password) | **POST** /auth/{userpass_mount_path}/users/{username}/password | Reset user&#39;s password.
*AuthApi* | [**userpass_update_policies**](docs/AuthApi.md#userpass_update_policies) | **POST** /auth/{userpass_mount_path}/users/{username}/policies | Update the policies associated with the username.
*AuthApi* | [**userpass_write_user**](docs/AuthApi.md#userpass_write_user) | **POST** /auth/{userpass_mount_path}/users/{username} | Manage users allowed to authenticate.
*IdentityApi* | [**alias_create**](docs/IdentityApi.md#alias_create) | **POST** /identity/alias | Create a new alias.
*IdentityApi* | [**alias_delete_by_id**](docs/IdentityApi.md#alias_delete_by_id) | **DELETE** /identity/alias/id/{id} | 
*IdentityApi* | [**alias_list_by_id**](docs/IdentityApi.md#alias_list_by_id) | **GET** /identity/alias/id/ | List all the alias IDs.
*IdentityApi* | [**alias_read_by_id**](docs/IdentityApi.md#alias_read_by_id) | **GET** /identity/alias/id/{id} | 
*IdentityApi* | [**alias_update_by_id**](docs/IdentityApi.md#alias_update_by_id) | **POST** /identity/alias/id/{id} | 
*IdentityApi* | [**entity_batch_delete**](docs/IdentityApi.md#entity_batch_delete) | **POST** /identity/entity/batch-delete | Delete all of the entities provided
*IdentityApi* | [**entity_create**](docs/IdentityApi.md#entity_create) | **POST** /identity/entity | Create a new entity
*IdentityApi* | [**entity_create_alias**](docs/IdentityApi.md#entity_create_alias) | **POST** /identity/entity-alias | Create a new alias.
*IdentityApi* | [**entity_delete_alias_by_id**](docs/IdentityApi.md#entity_delete_alias_by_id) | **DELETE** /identity/entity-alias/id/{id} | 
*IdentityApi* | [**entity_delete_by_id**](docs/IdentityApi.md#entity_delete_by_id) | **DELETE** /identity/entity/id/{id} | 
*IdentityApi* | [**entity_delete_by_name**](docs/IdentityApi.md#entity_delete_by_name) | **DELETE** /identity/entity/name/{name} | 
*IdentityApi* | [**entity_list_aliases_by_id**](docs/IdentityApi.md#entity_list_aliases_by_id) | **GET** /identity/entity-alias/id/ | List all the alias IDs.
*IdentityApi* | [**entity_list_by_id**](docs/IdentityApi.md#entity_list_by_id) | **GET** /identity/entity/id/ | List all the entity IDs
*IdentityApi* | [**entity_list_by_name**](docs/IdentityApi.md#entity_list_by_name) | **GET** /identity/entity/name/ | List all the entity names
*IdentityApi* | [**entity_look_up**](docs/IdentityApi.md#entity_look_up) | **POST** /identity/lookup/entity | Query entities based on various properties.
*IdentityApi* | [**entity_merge**](docs/IdentityApi.md#entity_merge) | **POST** /identity/entity/merge | Merge two or more entities together
*IdentityApi* | [**entity_read_alias_by_id**](docs/IdentityApi.md#entity_read_alias_by_id) | **GET** /identity/entity-alias/id/{id} | 
*IdentityApi* | [**entity_read_by_id**](docs/IdentityApi.md#entity_read_by_id) | **GET** /identity/entity/id/{id} | 
*IdentityApi* | [**entity_read_by_name**](docs/IdentityApi.md#entity_read_by_name) | **GET** /identity/entity/name/{name} | 
*IdentityApi* | [**entity_update_alias_by_id**](docs/IdentityApi.md#entity_update_alias_by_id) | **POST** /identity/entity-alias/id/{id} | 
*IdentityApi* | [**entity_update_by_id**](docs/IdentityApi.md#entity_update_by_id) | **POST** /identity/entity/id/{id} | 
*IdentityApi* | [**entity_update_by_name**](docs/IdentityApi.md#entity_update_by_name) | **POST** /identity/entity/name/{name} | 
*IdentityApi* | [**group_create**](docs/IdentityApi.md#group_create) | **POST** /identity/group | 
*IdentityApi* | [**group_create_alias**](docs/IdentityApi.md#group_create_alias) | **POST** /identity/group-alias | Creates a new group alias, or updates an existing one.
*IdentityApi* | [**group_delete_alias_by_id**](docs/IdentityApi.md#group_delete_alias_by_id) | **DELETE** /identity/group-alias/id/{id} | 
*IdentityApi* | [**group_delete_by_id**](docs/IdentityApi.md#group_delete_by_id) | **DELETE** /identity/group/id/{id} | 
*IdentityApi* | [**group_delete_by_name**](docs/IdentityApi.md#group_delete_by_name) | **DELETE** /identity/group/name/{name} | 
*IdentityApi* | [**group_list_aliases_by_id**](docs/IdentityApi.md#group_list_aliases_by_id) | **GET** /identity/group-alias/id/ | List all the group alias IDs.
*IdentityApi* | [**group_list_by_id**](docs/IdentityApi.md#group_list_by_id) | **GET** /identity/group/id/ | List all the group IDs.
*IdentityApi* | [**group_list_by_name**](docs/IdentityApi.md#group_list_by_name) | **GET** /identity/group/name/ | 
*IdentityApi* | [**group_look_up**](docs/IdentityApi.md#group_look_up) | **POST** /identity/lookup/group | Query groups based on various properties.
*IdentityApi* | [**group_read_alias_by_id**](docs/IdentityApi.md#group_read_alias_by_id) | **GET** /identity/group-alias/id/{id} | 
*IdentityApi* | [**group_read_by_id**](docs/IdentityApi.md#group_read_by_id) | **GET** /identity/group/id/{id} | 
*IdentityApi* | [**group_read_by_name**](docs/IdentityApi.md#group_read_by_name) | **GET** /identity/group/name/{name} | 
*IdentityApi* | [**group_update_alias_by_id**](docs/IdentityApi.md#group_update_alias_by_id) | **POST** /identity/group-alias/id/{id} | 
*IdentityApi* | [**group_update_by_id**](docs/IdentityApi.md#group_update_by_id) | **POST** /identity/group/id/{id} | 
*IdentityApi* | [**group_update_by_name**](docs/IdentityApi.md#group_update_by_name) | **POST** /identity/group/name/{name} | 
*IdentityApi* | [**mfa_admin_destroy_totp_secret**](docs/IdentityApi.md#mfa_admin_destroy_totp_secret) | **POST** /identity/mfa/method/totp/admin-destroy | Destroys a TOTP secret for the given MFA method ID on the given entity
*IdentityApi* | [**mfa_admin_generate_totp_secret**](docs/IdentityApi.md#mfa_admin_generate_totp_secret) | **POST** /identity/mfa/method/totp/admin-generate | Update or create TOTP secret for the given method ID on the given entity.
*IdentityApi* | [**mfa_create_duo_method**](docs/IdentityApi.md#mfa_create_duo_method) | **POST** /identity/mfa/method/duo | Create the given MFA method
*IdentityApi* | [**mfa_create_okta_method**](docs/IdentityApi.md#mfa_create_okta_method) | **POST** /identity/mfa/method/okta | Create the given MFA method
*IdentityApi* | [**mfa_create_ping_id_method**](docs/IdentityApi.md#mfa_create_ping_id_method) | **POST** /identity/mfa/method/pingid | Create the given MFA method
*IdentityApi* | [**mfa_create_totp_method**](docs/IdentityApi.md#mfa_create_totp_method) | **POST** /identity/mfa/method/totp | Create the given MFA method
*IdentityApi* | [**mfa_delete_duo_method**](docs/IdentityApi.md#mfa_delete_duo_method) | **DELETE** /identity/mfa/method/duo/{method_id} | Delete the given MFA method
*IdentityApi* | [**mfa_delete_login_enforcement**](docs/IdentityApi.md#mfa_delete_login_enforcement) | **DELETE** /identity/mfa/login-enforcement/{name} | Delete a login enforcement
*IdentityApi* | [**mfa_delete_okta_method**](docs/IdentityApi.md#mfa_delete_okta_method) | **DELETE** /identity/mfa/method/okta/{method_id} | Delete the given MFA method
*IdentityApi* | [**mfa_delete_ping_id_method**](docs/IdentityApi.md#mfa_delete_ping_id_method) | **DELETE** /identity/mfa/method/pingid/{method_id} | Delete the given MFA method
*IdentityApi* | [**mfa_delete_totp_method**](docs/IdentityApi.md#mfa_delete_totp_method) | **DELETE** /identity/mfa/method/totp/{method_id} | Delete the given MFA method
*IdentityApi* | [**mfa_generate_totp_secret**](docs/IdentityApi.md#mfa_generate_totp_secret) | **POST** /identity/mfa/method/totp/generate | Update or create TOTP secret for the given method ID on the given entity.
*IdentityApi* | [**mfa_list_duo_methods**](docs/IdentityApi.md#mfa_list_duo_methods) | **GET** /identity/mfa/method/duo/ | List MFA method configurations for the given MFA method
*IdentityApi* | [**mfa_list_login_enforcements**](docs/IdentityApi.md#mfa_list_login_enforcements) | **GET** /identity/mfa/login-enforcement/ | List login enforcements
*IdentityApi* | [**mfa_list_methods**](docs/IdentityApi.md#mfa_list_methods) | **GET** /identity/mfa/method/ | List MFA method configurations for all MFA methods
*IdentityApi* | [**mfa_list_okta_methods**](docs/IdentityApi.md#mfa_list_okta_methods) | **GET** /identity/mfa/method/okta/ | List MFA method configurations for the given MFA method
*IdentityApi* | [**mfa_list_ping_id_methods**](docs/IdentityApi.md#mfa_list_ping_id_methods) | **GET** /identity/mfa/method/pingid/ | List MFA method configurations for the given MFA method
*IdentityApi* | [**mfa_list_totp_methods**](docs/IdentityApi.md#mfa_list_totp_methods) | **GET** /identity/mfa/method/totp/ | List MFA method configurations for the given MFA method
*IdentityApi* | [**mfa_read_duo_method**](docs/IdentityApi.md#mfa_read_duo_method) | **GET** /identity/mfa/method/duo/{method_id} | Read the current configuration for the given MFA method
*IdentityApi* | [**mfa_read_login_enforcement**](docs/IdentityApi.md#mfa_read_login_enforcement) | **GET** /identity/mfa/login-enforcement/{name} | Read the current login enforcement
*IdentityApi* | [**mfa_read_method**](docs/IdentityApi.md#mfa_read_method) | **GET** /identity/mfa/method/{method_id} | Read the current configuration for the given ID regardless of the MFA method type
*IdentityApi* | [**mfa_read_okta_method**](docs/IdentityApi.md#mfa_read_okta_method) | **GET** /identity/mfa/method/okta/{method_id} | Read the current configuration for the given MFA method
*IdentityApi* | [**mfa_read_ping_id_method**](docs/IdentityApi.md#mfa_read_ping_id_method) | **GET** /identity/mfa/method/pingid/{method_id} | Read the current configuration for the given MFA method
*IdentityApi* | [**mfa_read_totp_method**](docs/IdentityApi.md#mfa_read_totp_method) | **GET** /identity/mfa/method/totp/{method_id} | Read the current configuration for the given MFA method
*IdentityApi* | [**mfa_update_duo_method**](docs/IdentityApi.md#mfa_update_duo_method) | **POST** /identity/mfa/method/duo/{method_id} | Update the configuration for the given MFA method
*IdentityApi* | [**mfa_update_okta_method**](docs/IdentityApi.md#mfa_update_okta_method) | **POST** /identity/mfa/method/okta/{method_id} | Update the configuration for the given MFA method
*IdentityApi* | [**mfa_update_ping_id_method**](docs/IdentityApi.md#mfa_update_ping_id_method) | **POST** /identity/mfa/method/pingid/{method_id} | Update the configuration for the given MFA method
*IdentityApi* | [**mfa_update_totp_method**](docs/IdentityApi.md#mfa_update_totp_method) | **POST** /identity/mfa/method/totp/{method_id} | Update the configuration for the given MFA method
*IdentityApi* | [**mfa_write_login_enforcement**](docs/IdentityApi.md#mfa_write_login_enforcement) | **POST** /identity/mfa/login-enforcement/{name} | Create or update a login enforcement
*IdentityApi* | [**oidc_configure**](docs/IdentityApi.md#oidc_configure) | **POST** /identity/oidc/config | 
*IdentityApi* | [**oidc_delete_assignment**](docs/IdentityApi.md#oidc_delete_assignment) | **DELETE** /identity/oidc/assignment/{name} | 
*IdentityApi* | [**oidc_delete_client**](docs/IdentityApi.md#oidc_delete_client) | **DELETE** /identity/oidc/client/{name} | 
*IdentityApi* | [**oidc_delete_key**](docs/IdentityApi.md#oidc_delete_key) | **DELETE** /identity/oidc/key/{name} | CRUD operations for OIDC keys.
*IdentityApi* | [**oidc_delete_provider**](docs/IdentityApi.md#oidc_delete_provider) | **DELETE** /identity/oidc/provider/{name} | 
*IdentityApi* | [**oidc_delete_role**](docs/IdentityApi.md#oidc_delete_role) | **DELETE** /identity/oidc/role/{name} | CRUD operations on OIDC Roles
*IdentityApi* | [**oidc_delete_scope**](docs/IdentityApi.md#oidc_delete_scope) | **DELETE** /identity/oidc/scope/{name} | 
*IdentityApi* | [**oidc_generate_token**](docs/IdentityApi.md#oidc_generate_token) | **GET** /identity/oidc/token/{name} | Generate an OIDC token
*IdentityApi* | [**oidc_introspect**](docs/IdentityApi.md#oidc_introspect) | **POST** /identity/oidc/introspect | Verify the authenticity of an OIDC token
*IdentityApi* | [**oidc_list_assignments**](docs/IdentityApi.md#oidc_list_assignments) | **GET** /identity/oidc/assignment/ | 
*IdentityApi* | [**oidc_list_clients**](docs/IdentityApi.md#oidc_list_clients) | **GET** /identity/oidc/client/ | 
*IdentityApi* | [**oidc_list_keys**](docs/IdentityApi.md#oidc_list_keys) | **GET** /identity/oidc/key/ | List OIDC keys
*IdentityApi* | [**oidc_list_providers**](docs/IdentityApi.md#oidc_list_providers) | **GET** /identity/oidc/provider/ | 
*IdentityApi* | [**oidc_list_roles**](docs/IdentityApi.md#oidc_list_roles) | **GET** /identity/oidc/role/ | List configured OIDC roles
*IdentityApi* | [**oidc_list_scopes**](docs/IdentityApi.md#oidc_list_scopes) | **GET** /identity/oidc/scope/ | 
*IdentityApi* | [**oidc_provider_authorize**](docs/IdentityApi.md#oidc_provider_authorize) | **GET** /identity/oidc/provider/{name}/authorize | 
*IdentityApi* | [**oidc_provider_authorize_with_parameters**](docs/IdentityApi.md#oidc_provider_authorize_with_parameters) | **POST** /identity/oidc/provider/{name}/authorize | 
*IdentityApi* | [**oidc_provider_token**](docs/IdentityApi.md#oidc_provider_token) | **POST** /identity/oidc/provider/{name}/token | 
*IdentityApi* | [**oidc_provider_user_info**](docs/IdentityApi.md#oidc_provider_user_info) | **GET** /identity/oidc/provider/{name}/userinfo | 
*IdentityApi* | [**oidc_provider_user_info2**](docs/IdentityApi.md#oidc_provider_user_info2) | **POST** /identity/oidc/provider/{name}/userinfo | 
*IdentityApi* | [**oidc_read_assignment**](docs/IdentityApi.md#oidc_read_assignment) | **GET** /identity/oidc/assignment/{name} | 
*IdentityApi* | [**oidc_read_client**](docs/IdentityApi.md#oidc_read_client) | **GET** /identity/oidc/client/{name} | 
*IdentityApi* | [**oidc_read_configuration**](docs/IdentityApi.md#oidc_read_configuration) | **GET** /identity/oidc/config | 
*IdentityApi* | [**oidc_read_key**](docs/IdentityApi.md#oidc_read_key) | **GET** /identity/oidc/key/{name} | CRUD operations for OIDC keys.
*IdentityApi* | [**oidc_read_open_id_configuration**](docs/IdentityApi.md#oidc_read_open_id_configuration) | **GET** /identity/oidc/.well-known/openid-configuration | Query OIDC configurations
*IdentityApi* | [**oidc_read_provider**](docs/IdentityApi.md#oidc_read_provider) | **GET** /identity/oidc/provider/{name} | 
*IdentityApi* | [**oidc_read_provider_open_id_configuration**](docs/IdentityApi.md#oidc_read_provider_open_id_configuration) | **GET** /identity/oidc/provider/{name}/.well-known/openid-configuration | 
*IdentityApi* | [**oidc_read_provider_public_keys**](docs/IdentityApi.md#oidc_read_provider_public_keys) | **GET** /identity/oidc/provider/{name}/.well-known/keys | 
*IdentityApi* | [**oidc_read_public_keys**](docs/IdentityApi.md#oidc_read_public_keys) | **GET** /identity/oidc/.well-known/keys | Retrieve public keys
*IdentityApi* | [**oidc_read_role**](docs/IdentityApi.md#oidc_read_role) | **GET** /identity/oidc/role/{name} | CRUD operations on OIDC Roles
*IdentityApi* | [**oidc_read_scope**](docs/IdentityApi.md#oidc_read_scope) | **GET** /identity/oidc/scope/{name} | 
*IdentityApi* | [**oidc_rotate_key**](docs/IdentityApi.md#oidc_rotate_key) | **POST** /identity/oidc/key/{name}/rotate | Rotate a named OIDC key.
*IdentityApi* | [**oidc_write_assignment**](docs/IdentityApi.md#oidc_write_assignment) | **POST** /identity/oidc/assignment/{name} | 
*IdentityApi* | [**oidc_write_client**](docs/IdentityApi.md#oidc_write_client) | **POST** /identity/oidc/client/{name} | 
*IdentityApi* | [**oidc_write_key**](docs/IdentityApi.md#oidc_write_key) | **POST** /identity/oidc/key/{name} | CRUD operations for OIDC keys.
*IdentityApi* | [**oidc_write_provider**](docs/IdentityApi.md#oidc_write_provider) | **POST** /identity/oidc/provider/{name} | 
*IdentityApi* | [**oidc_write_role**](docs/IdentityApi.md#oidc_write_role) | **POST** /identity/oidc/role/{name} | CRUD operations on OIDC Roles
*IdentityApi* | [**oidc_write_scope**](docs/IdentityApi.md#oidc_write_scope) | **POST** /identity/oidc/scope/{name} | 
*IdentityApi* | [**persona_create**](docs/IdentityApi.md#persona_create) | **POST** /identity/persona | Create a new alias.
*IdentityApi* | [**persona_delete_by_id**](docs/IdentityApi.md#persona_delete_by_id) | **DELETE** /identity/persona/id/{id} | 
*IdentityApi* | [**persona_list_by_id**](docs/IdentityApi.md#persona_list_by_id) | **GET** /identity/persona/id/ | List all the alias IDs.
*IdentityApi* | [**persona_read_by_id**](docs/IdentityApi.md#persona_read_by_id) | **GET** /identity/persona/id/{id} | 
*IdentityApi* | [**persona_update_by_id**](docs/IdentityApi.md#persona_update_by_id) | **POST** /identity/persona/id/{id} | 
*SecretsApi* | [**ali_cloud_configure**](docs/SecretsApi.md#ali_cloud_configure) | **POST** /{alicloud_mount_path}/config | 
*SecretsApi* | [**ali_cloud_delete_configuration**](docs/SecretsApi.md#ali_cloud_delete_configuration) | **DELETE** /{alicloud_mount_path}/config | 
*SecretsApi* | [**ali_cloud_delete_role**](docs/SecretsApi.md#ali_cloud_delete_role) | **DELETE** /{alicloud_mount_path}/role/{name} | Read, write and reference policies and roles that API keys or STS credentials can be made for.
*SecretsApi* | [**ali_cloud_generate_credentials**](docs/SecretsApi.md#ali_cloud_generate_credentials) | **GET** /{alicloud_mount_path}/creds/{name} | Generate an API key or STS credential using the given role&#39;s configuration.&#39;
*SecretsApi* | [**ali_cloud_list_roles**](docs/SecretsApi.md#ali_cloud_list_roles) | **GET** /{alicloud_mount_path}/role/ | List the existing roles in this backend.
*SecretsApi* | [**ali_cloud_read_configuration**](docs/SecretsApi.md#ali_cloud_read_configuration) | **GET** /{alicloud_mount_path}/config | 
*SecretsApi* | [**ali_cloud_read_role**](docs/SecretsApi.md#ali_cloud_read_role) | **GET** /{alicloud_mount_path}/role/{name} | Read, write and reference policies and roles that API keys or STS credentials can be made for.
*SecretsApi* | [**ali_cloud_write_role**](docs/SecretsApi.md#ali_cloud_write_role) | **POST** /{alicloud_mount_path}/role/{name} | Read, write and reference policies and roles that API keys or STS credentials can be made for.
*SecretsApi* | [**aws_configure_lease**](docs/SecretsApi.md#aws_configure_lease) | **POST** /{aws_mount_path}/config/lease | 
*SecretsApi* | [**aws_configure_root_iam_credentials**](docs/SecretsApi.md#aws_configure_root_iam_credentials) | **POST** /{aws_mount_path}/config/root | 
*SecretsApi* | [**aws_delete_role**](docs/SecretsApi.md#aws_delete_role) | **DELETE** /{aws_mount_path}/roles/{name} | Read, write and reference IAM policies that access keys can be made for.
*SecretsApi* | [**aws_delete_static_roles_name**](docs/SecretsApi.md#aws_delete_static_roles_name) | **DELETE** /{aws_mount_path}/static-roles/{name} | 
*SecretsApi* | [**aws_generate_credentials**](docs/SecretsApi.md#aws_generate_credentials) | **GET** /{aws_mount_path}/creds/{name} | 
*SecretsApi* | [**aws_generate_credentials_with_parameters**](docs/SecretsApi.md#aws_generate_credentials_with_parameters) | **POST** /{aws_mount_path}/creds/{name} | 
*SecretsApi* | [**aws_generate_sts_credentials**](docs/SecretsApi.md#aws_generate_sts_credentials) | **GET** /{aws_mount_path}/sts/{name} | 
*SecretsApi* | [**aws_generate_sts_credentials_with_parameters**](docs/SecretsApi.md#aws_generate_sts_credentials_with_parameters) | **POST** /{aws_mount_path}/sts/{name} | 
*SecretsApi* | [**aws_list_roles**](docs/SecretsApi.md#aws_list_roles) | **GET** /{aws_mount_path}/roles/ | List the existing roles in this backend
*SecretsApi* | [**aws_read_lease_configuration**](docs/SecretsApi.md#aws_read_lease_configuration) | **GET** /{aws_mount_path}/config/lease | 
*SecretsApi* | [**aws_read_role**](docs/SecretsApi.md#aws_read_role) | **GET** /{aws_mount_path}/roles/{name} | Read, write and reference IAM policies that access keys can be made for.
*SecretsApi* | [**aws_read_root_iam_credentials_configuration**](docs/SecretsApi.md#aws_read_root_iam_credentials_configuration) | **GET** /{aws_mount_path}/config/root | 
*SecretsApi* | [**aws_read_static_creds_name**](docs/SecretsApi.md#aws_read_static_creds_name) | **GET** /{aws_mount_path}/static-creds/{name} | 
*SecretsApi* | [**aws_read_static_roles_name**](docs/SecretsApi.md#aws_read_static_roles_name) | **GET** /{aws_mount_path}/static-roles/{name} | 
*SecretsApi* | [**aws_rotate_root_iam_credentials**](docs/SecretsApi.md#aws_rotate_root_iam_credentials) | **POST** /{aws_mount_path}/config/rotate-root | 
*SecretsApi* | [**aws_write_role**](docs/SecretsApi.md#aws_write_role) | **POST** /{aws_mount_path}/roles/{name} | Read, write and reference IAM policies that access keys can be made for.
*SecretsApi* | [**aws_write_static_roles_name**](docs/SecretsApi.md#aws_write_static_roles_name) | **POST** /{aws_mount_path}/static-roles/{name} | 
*SecretsApi* | [**azure_configure**](docs/SecretsApi.md#azure_configure) | **POST** /{azure_mount_path}/config | 
*SecretsApi* | [**azure_delete_configuration**](docs/SecretsApi.md#azure_delete_configuration) | **DELETE** /{azure_mount_path}/config | 
*SecretsApi* | [**azure_delete_role**](docs/SecretsApi.md#azure_delete_role) | **DELETE** /{azure_mount_path}/roles/{name} | Manage the Vault roles used to generate Azure credentials.
*SecretsApi* | [**azure_list_roles**](docs/SecretsApi.md#azure_list_roles) | **GET** /{azure_mount_path}/roles/ | List existing roles.
*SecretsApi* | [**azure_read_configuration**](docs/SecretsApi.md#azure_read_configuration) | **GET** /{azure_mount_path}/config | 
*SecretsApi* | [**azure_read_role**](docs/SecretsApi.md#azure_read_role) | **GET** /{azure_mount_path}/roles/{name} | Manage the Vault roles used to generate Azure credentials.
*SecretsApi* | [**azure_request_service_principal_credentials**](docs/SecretsApi.md#azure_request_service_principal_credentials) | **GET** /{azure_mount_path}/creds/{role} | 
*SecretsApi* | [**azure_rotate_root**](docs/SecretsApi.md#azure_rotate_root) | **POST** /{azure_mount_path}/rotate-root | 
*SecretsApi* | [**azure_write_role**](docs/SecretsApi.md#azure_write_role) | **POST** /{azure_mount_path}/roles/{name} | Manage the Vault roles used to generate Azure credentials.
*SecretsApi* | [**consul_configure_access**](docs/SecretsApi.md#consul_configure_access) | **POST** /{consul_mount_path}/config/access | 
*SecretsApi* | [**consul_delete_role**](docs/SecretsApi.md#consul_delete_role) | **DELETE** /{consul_mount_path}/roles/{name} | 
*SecretsApi* | [**consul_generate_credentials**](docs/SecretsApi.md#consul_generate_credentials) | **GET** /{consul_mount_path}/creds/{role} | 
*SecretsApi* | [**consul_list_roles**](docs/SecretsApi.md#consul_list_roles) | **GET** /{consul_mount_path}/roles/ | 
*SecretsApi* | [**consul_read_access_configuration**](docs/SecretsApi.md#consul_read_access_configuration) | **GET** /{consul_mount_path}/config/access | 
*SecretsApi* | [**consul_read_role**](docs/SecretsApi.md#consul_read_role) | **GET** /{consul_mount_path}/roles/{name} | 
*SecretsApi* | [**consul_write_role**](docs/SecretsApi.md#consul_write_role) | **POST** /{consul_mount_path}/roles/{name} | 
*SecretsApi* | [**cubbyhole_delete**](docs/SecretsApi.md#cubbyhole_delete) | **DELETE** /cubbyhole/{path} | Deletes the secret at the specified location.
*SecretsApi* | [**cubbyhole_list**](docs/SecretsApi.md#cubbyhole_list) | **GET** /cubbyhole/{path}/ | List secret entries at the specified location.
*SecretsApi* | [**cubbyhole_read**](docs/SecretsApi.md#cubbyhole_read) | **GET** /cubbyhole/{path} | Retrieve the secret at the specified location.
*SecretsApi* | [**cubbyhole_write**](docs/SecretsApi.md#cubbyhole_write) | **POST** /cubbyhole/{path} | Store a secret at the specified location.
*SecretsApi* | [**database_configure_connection**](docs/SecretsApi.md#database_configure_connection) | **POST** /{database_mount_path}/config/{name} | 
*SecretsApi* | [**database_delete_connection_configuration**](docs/SecretsApi.md#database_delete_connection_configuration) | **DELETE** /{database_mount_path}/config/{name} | 
*SecretsApi* | [**database_delete_role**](docs/SecretsApi.md#database_delete_role) | **DELETE** /{database_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**database_delete_static_role**](docs/SecretsApi.md#database_delete_static_role) | **DELETE** /{database_mount_path}/static-roles/{name} | Manage the static roles that can be created with this backend.
*SecretsApi* | [**database_generate_credentials**](docs/SecretsApi.md#database_generate_credentials) | **GET** /{database_mount_path}/creds/{name} | Request database credentials for a certain role.
*SecretsApi* | [**database_list_connections**](docs/SecretsApi.md#database_list_connections) | **GET** /{database_mount_path}/config/ | Configure connection details to a database plugin.
*SecretsApi* | [**database_list_roles**](docs/SecretsApi.md#database_list_roles) | **GET** /{database_mount_path}/roles/ | Manage the roles that can be created with this backend.
*SecretsApi* | [**database_list_static_roles**](docs/SecretsApi.md#database_list_static_roles) | **GET** /{database_mount_path}/static-roles/ | Manage the static roles that can be created with this backend.
*SecretsApi* | [**database_read_connection_configuration**](docs/SecretsApi.md#database_read_connection_configuration) | **GET** /{database_mount_path}/config/{name} | 
*SecretsApi* | [**database_read_role**](docs/SecretsApi.md#database_read_role) | **GET** /{database_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**database_read_static_role**](docs/SecretsApi.md#database_read_static_role) | **GET** /{database_mount_path}/static-roles/{name} | Manage the static roles that can be created with this backend.
*SecretsApi* | [**database_read_static_role_credentials**](docs/SecretsApi.md#database_read_static_role_credentials) | **GET** /{database_mount_path}/static-creds/{name} | Request database credentials for a certain static role. These credentials are rotated periodically.
*SecretsApi* | [**database_reset_connection**](docs/SecretsApi.md#database_reset_connection) | **POST** /{database_mount_path}/reset/{name} | Resets a database plugin.
*SecretsApi* | [**database_rotate_root_credentials**](docs/SecretsApi.md#database_rotate_root_credentials) | **POST** /{database_mount_path}/rotate-root/{name} | 
*SecretsApi* | [**database_rotate_static_role_credentials**](docs/SecretsApi.md#database_rotate_static_role_credentials) | **POST** /{database_mount_path}/rotate-role/{name} | 
*SecretsApi* | [**database_write_role**](docs/SecretsApi.md#database_write_role) | **POST** /{database_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**database_write_static_role**](docs/SecretsApi.md#database_write_static_role) | **POST** /{database_mount_path}/static-roles/{name} | Manage the static roles that can be created with this backend.
*SecretsApi* | [**google_cloud_configure**](docs/SecretsApi.md#google_cloud_configure) | **POST** /{gcp_mount_path}/config | 
*SecretsApi* | [**google_cloud_delete_impersonated_account**](docs/SecretsApi.md#google_cloud_delete_impersonated_account) | **DELETE** /{gcp_mount_path}/impersonated-account/{name} | 
*SecretsApi* | [**google_cloud_delete_roleset**](docs/SecretsApi.md#google_cloud_delete_roleset) | **DELETE** /{gcp_mount_path}/roleset/{name} | 
*SecretsApi* | [**google_cloud_delete_static_account**](docs/SecretsApi.md#google_cloud_delete_static_account) | **DELETE** /{gcp_mount_path}/static-account/{name} | 
*SecretsApi* | [**google_cloud_generate_impersonated_account_access_token**](docs/SecretsApi.md#google_cloud_generate_impersonated_account_access_token) | **GET** /{gcp_mount_path}/impersonated-account/{name}/token | 
*SecretsApi* | [**google_cloud_generate_impersonated_account_access_token2**](docs/SecretsApi.md#google_cloud_generate_impersonated_account_access_token2) | **POST** /{gcp_mount_path}/impersonated-account/{name}/token | 
*SecretsApi* | [**google_cloud_generate_roleset_access_token**](docs/SecretsApi.md#google_cloud_generate_roleset_access_token) | **POST** /{gcp_mount_path}/roleset/{roleset}/token | 
*SecretsApi* | [**google_cloud_generate_roleset_access_token2**](docs/SecretsApi.md#google_cloud_generate_roleset_access_token2) | **GET** /{gcp_mount_path}/roleset/{roleset}/token | 
*SecretsApi* | [**google_cloud_generate_roleset_access_token3**](docs/SecretsApi.md#google_cloud_generate_roleset_access_token3) | **POST** /{gcp_mount_path}/token/{roleset} | 
*SecretsApi* | [**google_cloud_generate_roleset_access_token4**](docs/SecretsApi.md#google_cloud_generate_roleset_access_token4) | **GET** /{gcp_mount_path}/token/{roleset} | 
*SecretsApi* | [**google_cloud_generate_roleset_key**](docs/SecretsApi.md#google_cloud_generate_roleset_key) | **POST** /{gcp_mount_path}/roleset/{roleset}/key | 
*SecretsApi* | [**google_cloud_generate_roleset_key2**](docs/SecretsApi.md#google_cloud_generate_roleset_key2) | **GET** /{gcp_mount_path}/roleset/{roleset}/key | 
*SecretsApi* | [**google_cloud_generate_roleset_key3**](docs/SecretsApi.md#google_cloud_generate_roleset_key3) | **POST** /{gcp_mount_path}/key/{roleset} | 
*SecretsApi* | [**google_cloud_generate_roleset_key4**](docs/SecretsApi.md#google_cloud_generate_roleset_key4) | **GET** /{gcp_mount_path}/key/{roleset} | 
*SecretsApi* | [**google_cloud_generate_static_account_access_token**](docs/SecretsApi.md#google_cloud_generate_static_account_access_token) | **POST** /{gcp_mount_path}/static-account/{name}/token | 
*SecretsApi* | [**google_cloud_generate_static_account_access_token2**](docs/SecretsApi.md#google_cloud_generate_static_account_access_token2) | **GET** /{gcp_mount_path}/static-account/{name}/token | 
*SecretsApi* | [**google_cloud_generate_static_account_key**](docs/SecretsApi.md#google_cloud_generate_static_account_key) | **POST** /{gcp_mount_path}/static-account/{name}/key | 
*SecretsApi* | [**google_cloud_generate_static_account_key2**](docs/SecretsApi.md#google_cloud_generate_static_account_key2) | **GET** /{gcp_mount_path}/static-account/{name}/key | 
*SecretsApi* | [**google_cloud_kms_configure**](docs/SecretsApi.md#google_cloud_kms_configure) | **POST** /{gcpkms_mount_path}/config | 
*SecretsApi* | [**google_cloud_kms_configure_key**](docs/SecretsApi.md#google_cloud_kms_configure_key) | **POST** /{gcpkms_mount_path}/keys/config/{key} | 
*SecretsApi* | [**google_cloud_kms_decrypt**](docs/SecretsApi.md#google_cloud_kms_decrypt) | **POST** /{gcpkms_mount_path}/decrypt/{key} | Decrypt a ciphertext value using a named key
*SecretsApi* | [**google_cloud_kms_delete_configuration**](docs/SecretsApi.md#google_cloud_kms_delete_configuration) | **DELETE** /{gcpkms_mount_path}/config | 
*SecretsApi* | [**google_cloud_kms_delete_key**](docs/SecretsApi.md#google_cloud_kms_delete_key) | **DELETE** /{gcpkms_mount_path}/keys/{key} | Interact with crypto keys in Vault and Google Cloud KMS
*SecretsApi* | [**google_cloud_kms_deregister_key**](docs/SecretsApi.md#google_cloud_kms_deregister_key) | **POST** /{gcpkms_mount_path}/keys/deregister/{key} | 
*SecretsApi* | [**google_cloud_kms_deregister_key2**](docs/SecretsApi.md#google_cloud_kms_deregister_key2) | **DELETE** /{gcpkms_mount_path}/keys/deregister/{key} | 
*SecretsApi* | [**google_cloud_kms_encrypt**](docs/SecretsApi.md#google_cloud_kms_encrypt) | **POST** /{gcpkms_mount_path}/encrypt/{key} | Encrypt a plaintext value using a named key
*SecretsApi* | [**google_cloud_kms_list_keys**](docs/SecretsApi.md#google_cloud_kms_list_keys) | **GET** /{gcpkms_mount_path}/keys/ | List named keys
*SecretsApi* | [**google_cloud_kms_read_configuration**](docs/SecretsApi.md#google_cloud_kms_read_configuration) | **GET** /{gcpkms_mount_path}/config | 
*SecretsApi* | [**google_cloud_kms_read_key**](docs/SecretsApi.md#google_cloud_kms_read_key) | **GET** /{gcpkms_mount_path}/keys/{key} | Interact with crypto keys in Vault and Google Cloud KMS
*SecretsApi* | [**google_cloud_kms_read_key_configuration**](docs/SecretsApi.md#google_cloud_kms_read_key_configuration) | **GET** /{gcpkms_mount_path}/keys/config/{key} | 
*SecretsApi* | [**google_cloud_kms_reencrypt**](docs/SecretsApi.md#google_cloud_kms_reencrypt) | **POST** /{gcpkms_mount_path}/reencrypt/{key} | Re-encrypt existing ciphertext data to a new version
*SecretsApi* | [**google_cloud_kms_register_key**](docs/SecretsApi.md#google_cloud_kms_register_key) | **POST** /{gcpkms_mount_path}/keys/register/{key} | Register an existing crypto key in Google Cloud KMS
*SecretsApi* | [**google_cloud_kms_retrieve_public_key**](docs/SecretsApi.md#google_cloud_kms_retrieve_public_key) | **GET** /{gcpkms_mount_path}/pubkey/{key} | Retrieve the public key associated with the named key
*SecretsApi* | [**google_cloud_kms_rotate_key**](docs/SecretsApi.md#google_cloud_kms_rotate_key) | **POST** /{gcpkms_mount_path}/keys/rotate/{key} | Rotate a crypto key to a new primary version
*SecretsApi* | [**google_cloud_kms_sign**](docs/SecretsApi.md#google_cloud_kms_sign) | **POST** /{gcpkms_mount_path}/sign/{key} | Signs a message or digest using a named key
*SecretsApi* | [**google_cloud_kms_trim_key_versions**](docs/SecretsApi.md#google_cloud_kms_trim_key_versions) | **POST** /{gcpkms_mount_path}/keys/trim/{key} | 
*SecretsApi* | [**google_cloud_kms_trim_key_versions2**](docs/SecretsApi.md#google_cloud_kms_trim_key_versions2) | **DELETE** /{gcpkms_mount_path}/keys/trim/{key} | 
*SecretsApi* | [**google_cloud_kms_verify**](docs/SecretsApi.md#google_cloud_kms_verify) | **POST** /{gcpkms_mount_path}/verify/{key} | Verify a signature using a named key
*SecretsApi* | [**google_cloud_kms_write_key**](docs/SecretsApi.md#google_cloud_kms_write_key) | **POST** /{gcpkms_mount_path}/keys/{key} | Interact with crypto keys in Vault and Google Cloud KMS
*SecretsApi* | [**google_cloud_list_impersonated_accounts**](docs/SecretsApi.md#google_cloud_list_impersonated_accounts) | **GET** /{gcp_mount_path}/impersonated-account/ | 
*SecretsApi* | [**google_cloud_list_impersonated_accounts2**](docs/SecretsApi.md#google_cloud_list_impersonated_accounts2) | **GET** /{gcp_mount_path}/impersonated-accounts/ | 
*SecretsApi* | [**google_cloud_list_rolesets**](docs/SecretsApi.md#google_cloud_list_rolesets) | **GET** /{gcp_mount_path}/roleset/ | 
*SecretsApi* | [**google_cloud_list_rolesets2**](docs/SecretsApi.md#google_cloud_list_rolesets2) | **GET** /{gcp_mount_path}/rolesets/ | 
*SecretsApi* | [**google_cloud_list_static_accounts**](docs/SecretsApi.md#google_cloud_list_static_accounts) | **GET** /{gcp_mount_path}/static-account/ | 
*SecretsApi* | [**google_cloud_list_static_accounts2**](docs/SecretsApi.md#google_cloud_list_static_accounts2) | **GET** /{gcp_mount_path}/static-accounts/ | 
*SecretsApi* | [**google_cloud_read_configuration**](docs/SecretsApi.md#google_cloud_read_configuration) | **GET** /{gcp_mount_path}/config | 
*SecretsApi* | [**google_cloud_read_impersonated_account**](docs/SecretsApi.md#google_cloud_read_impersonated_account) | **GET** /{gcp_mount_path}/impersonated-account/{name} | 
*SecretsApi* | [**google_cloud_read_roleset**](docs/SecretsApi.md#google_cloud_read_roleset) | **GET** /{gcp_mount_path}/roleset/{name} | 
*SecretsApi* | [**google_cloud_read_static_account**](docs/SecretsApi.md#google_cloud_read_static_account) | **GET** /{gcp_mount_path}/static-account/{name} | 
*SecretsApi* | [**google_cloud_rotate_roleset**](docs/SecretsApi.md#google_cloud_rotate_roleset) | **POST** /{gcp_mount_path}/roleset/{name}/rotate | 
*SecretsApi* | [**google_cloud_rotate_roleset_key**](docs/SecretsApi.md#google_cloud_rotate_roleset_key) | **POST** /{gcp_mount_path}/roleset/{name}/rotate-key | 
*SecretsApi* | [**google_cloud_rotate_root_credentials**](docs/SecretsApi.md#google_cloud_rotate_root_credentials) | **POST** /{gcp_mount_path}/config/rotate-root | 
*SecretsApi* | [**google_cloud_rotate_static_account_key**](docs/SecretsApi.md#google_cloud_rotate_static_account_key) | **POST** /{gcp_mount_path}/static-account/{name}/rotate-key | 
*SecretsApi* | [**google_cloud_write_impersonated_account**](docs/SecretsApi.md#google_cloud_write_impersonated_account) | **POST** /{gcp_mount_path}/impersonated-account/{name} | 
*SecretsApi* | [**google_cloud_write_roleset**](docs/SecretsApi.md#google_cloud_write_roleset) | **POST** /{gcp_mount_path}/roleset/{name} | 
*SecretsApi* | [**google_cloud_write_static_account**](docs/SecretsApi.md#google_cloud_write_static_account) | **POST** /{gcp_mount_path}/static-account/{name} | 
*SecretsApi* | [**kubernetes_check_configuration**](docs/SecretsApi.md#kubernetes_check_configuration) | **GET** /{kubernetes_mount_path}/check | 
*SecretsApi* | [**kubernetes_configure**](docs/SecretsApi.md#kubernetes_configure) | **POST** /{kubernetes_mount_path}/config | 
*SecretsApi* | [**kubernetes_delete_configuration**](docs/SecretsApi.md#kubernetes_delete_configuration) | **DELETE** /{kubernetes_mount_path}/config | 
*SecretsApi* | [**kubernetes_delete_role**](docs/SecretsApi.md#kubernetes_delete_role) | **DELETE** /{kubernetes_mount_path}/roles/{name} | 
*SecretsApi* | [**kubernetes_generate_credentials**](docs/SecretsApi.md#kubernetes_generate_credentials) | **POST** /{kubernetes_mount_path}/creds/{name} | 
*SecretsApi* | [**kubernetes_list_roles**](docs/SecretsApi.md#kubernetes_list_roles) | **GET** /{kubernetes_mount_path}/roles/ | 
*SecretsApi* | [**kubernetes_read_configuration**](docs/SecretsApi.md#kubernetes_read_configuration) | **GET** /{kubernetes_mount_path}/config | 
*SecretsApi* | [**kubernetes_read_role**](docs/SecretsApi.md#kubernetes_read_role) | **GET** /{kubernetes_mount_path}/roles/{name} | 
*SecretsApi* | [**kubernetes_write_role**](docs/SecretsApi.md#kubernetes_write_role) | **POST** /{kubernetes_mount_path}/roles/{name} | 
*SecretsApi* | [**kv_v1_delete**](docs/SecretsApi.md#kv_v1_delete) | **DELETE** /{kv_v1_mount_path}/{path} | 
*SecretsApi* | [**kv_v1_list**](docs/SecretsApi.md#kv_v1_list) | **GET** /{kv_v1_mount_path}/{path}/ | 
*SecretsApi* | [**kv_v1_read**](docs/SecretsApi.md#kv_v1_read) | **GET** /{kv_v1_mount_path}/{path} | 
*SecretsApi* | [**kv_v1_write**](docs/SecretsApi.md#kv_v1_write) | **POST** /{kv_v1_mount_path}/{path} | 
*SecretsApi* | [**kv_v2_configure**](docs/SecretsApi.md#kv_v2_configure) | **POST** /{kv_v2_mount_path}/config | Configure backend level settings that are applied to every key in the key-value store.
*SecretsApi* | [**kv_v2_delete**](docs/SecretsApi.md#kv_v2_delete) | **DELETE** /{kv_v2_mount_path}/data/{path} | 
*SecretsApi* | [**kv_v2_delete_metadata_and_all_versions**](docs/SecretsApi.md#kv_v2_delete_metadata_and_all_versions) | **DELETE** /{kv_v2_mount_path}/metadata/{path} | 
*SecretsApi* | [**kv_v2_delete_versions**](docs/SecretsApi.md#kv_v2_delete_versions) | **POST** /{kv_v2_mount_path}/delete/{path} | 
*SecretsApi* | [**kv_v2_destroy_versions**](docs/SecretsApi.md#kv_v2_destroy_versions) | **POST** /{kv_v2_mount_path}/destroy/{path} | 
*SecretsApi* | [**kv_v2_list**](docs/SecretsApi.md#kv_v2_list) | **GET** /{kv_v2_mount_path}/metadata/{path}/ | 
*SecretsApi* | [**kv_v2_read**](docs/SecretsApi.md#kv_v2_read) | **GET** /{kv_v2_mount_path}/data/{path} | 
*SecretsApi* | [**kv_v2_read_configuration**](docs/SecretsApi.md#kv_v2_read_configuration) | **GET** /{kv_v2_mount_path}/config | Read the backend level settings.
*SecretsApi* | [**kv_v2_read_metadata**](docs/SecretsApi.md#kv_v2_read_metadata) | **GET** /{kv_v2_mount_path}/metadata/{path} | 
*SecretsApi* | [**kv_v2_read_subkeys**](docs/SecretsApi.md#kv_v2_read_subkeys) | **GET** /{kv_v2_mount_path}/subkeys/{path} | 
*SecretsApi* | [**kv_v2_undelete_versions**](docs/SecretsApi.md#kv_v2_undelete_versions) | **POST** /{kv_v2_mount_path}/undelete/{path} | 
*SecretsApi* | [**kv_v2_write**](docs/SecretsApi.md#kv_v2_write) | **POST** /{kv_v2_mount_path}/data/{path} | 
*SecretsApi* | [**kv_v2_write_metadata**](docs/SecretsApi.md#kv_v2_write_metadata) | **POST** /{kv_v2_mount_path}/metadata/{path} | 
*SecretsApi* | [**ldap_configure**](docs/SecretsApi.md#ldap_configure) | **POST** /{ldap_mount_path}/config | 
*SecretsApi* | [**ldap_delete_configuration**](docs/SecretsApi.md#ldap_delete_configuration) | **DELETE** /{ldap_mount_path}/config | 
*SecretsApi* | [**ldap_delete_dynamic_role**](docs/SecretsApi.md#ldap_delete_dynamic_role) | **DELETE** /{ldap_mount_path}/role/{name} | 
*SecretsApi* | [**ldap_delete_static_role**](docs/SecretsApi.md#ldap_delete_static_role) | **DELETE** /{ldap_mount_path}/static-role/{name} | 
*SecretsApi* | [**ldap_library_check_in**](docs/SecretsApi.md#ldap_library_check_in) | **POST** /{ldap_mount_path}/library/{name}/check-in | Check service accounts in to the library.
*SecretsApi* | [**ldap_library_check_out**](docs/SecretsApi.md#ldap_library_check_out) | **POST** /{ldap_mount_path}/library/{name}/check-out | Check a service account out from the library.
*SecretsApi* | [**ldap_library_check_status**](docs/SecretsApi.md#ldap_library_check_status) | **GET** /{ldap_mount_path}/library/{name}/status | Check the status of the service accounts in a library set.
*SecretsApi* | [**ldap_library_configure**](docs/SecretsApi.md#ldap_library_configure) | **POST** /{ldap_mount_path}/library/{name} | Update a library set.
*SecretsApi* | [**ldap_library_delete**](docs/SecretsApi.md#ldap_library_delete) | **DELETE** /{ldap_mount_path}/library/{name} | Delete a library set.
*SecretsApi* | [**ldap_library_force_check_in**](docs/SecretsApi.md#ldap_library_force_check_in) | **POST** /{ldap_mount_path}/library/manage/{name}/check-in | Check service accounts in to the library.
*SecretsApi* | [**ldap_library_list**](docs/SecretsApi.md#ldap_library_list) | **GET** /{ldap_mount_path}/library/ | 
*SecretsApi* | [**ldap_library_read**](docs/SecretsApi.md#ldap_library_read) | **GET** /{ldap_mount_path}/library/{name} | Read a library set.
*SecretsApi* | [**ldap_list_dynamic_roles**](docs/SecretsApi.md#ldap_list_dynamic_roles) | **GET** /{ldap_mount_path}/role/ | 
*SecretsApi* | [**ldap_list_static_roles**](docs/SecretsApi.md#ldap_list_static_roles) | **GET** /{ldap_mount_path}/static-role/ | 
*SecretsApi* | [**ldap_read_configuration**](docs/SecretsApi.md#ldap_read_configuration) | **GET** /{ldap_mount_path}/config | 
*SecretsApi* | [**ldap_read_dynamic_role**](docs/SecretsApi.md#ldap_read_dynamic_role) | **GET** /{ldap_mount_path}/role/{name} | 
*SecretsApi* | [**ldap_read_static_role**](docs/SecretsApi.md#ldap_read_static_role) | **GET** /{ldap_mount_path}/static-role/{name} | 
*SecretsApi* | [**ldap_request_dynamic_role_credentials**](docs/SecretsApi.md#ldap_request_dynamic_role_credentials) | **GET** /{ldap_mount_path}/creds/{name} | 
*SecretsApi* | [**ldap_request_static_role_credentials**](docs/SecretsApi.md#ldap_request_static_role_credentials) | **GET** /{ldap_mount_path}/static-cred/{name} | 
*SecretsApi* | [**ldap_rotate_root_credentials**](docs/SecretsApi.md#ldap_rotate_root_credentials) | **POST** /{ldap_mount_path}/rotate-root | 
*SecretsApi* | [**ldap_rotate_static_role**](docs/SecretsApi.md#ldap_rotate_static_role) | **POST** /{ldap_mount_path}/rotate-role/{name} | 
*SecretsApi* | [**ldap_write_dynamic_role**](docs/SecretsApi.md#ldap_write_dynamic_role) | **POST** /{ldap_mount_path}/role/{name} | 
*SecretsApi* | [**ldap_write_static_role**](docs/SecretsApi.md#ldap_write_static_role) | **POST** /{ldap_mount_path}/static-role/{name} | 
*SecretsApi* | [**mongo_db_atlas_configure**](docs/SecretsApi.md#mongo_db_atlas_configure) | **POST** /{mongodbatlas_mount_path}/config | 
*SecretsApi* | [**mongo_db_atlas_delete_role**](docs/SecretsApi.md#mongo_db_atlas_delete_role) | **DELETE** /{mongodbatlas_mount_path}/roles/{name} | Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
*SecretsApi* | [**mongo_db_atlas_generate_credentials**](docs/SecretsApi.md#mongo_db_atlas_generate_credentials) | **GET** /{mongodbatlas_mount_path}/creds/{name} | 
*SecretsApi* | [**mongo_db_atlas_generate_credentials2**](docs/SecretsApi.md#mongo_db_atlas_generate_credentials2) | **POST** /{mongodbatlas_mount_path}/creds/{name} | 
*SecretsApi* | [**mongo_db_atlas_list_roles**](docs/SecretsApi.md#mongo_db_atlas_list_roles) | **GET** /{mongodbatlas_mount_path}/roles/ | List the existing roles in this backend
*SecretsApi* | [**mongo_db_atlas_read_configuration**](docs/SecretsApi.md#mongo_db_atlas_read_configuration) | **GET** /{mongodbatlas_mount_path}/config | 
*SecretsApi* | [**mongo_db_atlas_read_role**](docs/SecretsApi.md#mongo_db_atlas_read_role) | **GET** /{mongodbatlas_mount_path}/roles/{name} | Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
*SecretsApi* | [**mongo_db_atlas_write_role**](docs/SecretsApi.md#mongo_db_atlas_write_role) | **POST** /{mongodbatlas_mount_path}/roles/{name} | Manage the roles used to generate MongoDB Atlas Programmatic API Keys.
*SecretsApi* | [**nomad_configure_access**](docs/SecretsApi.md#nomad_configure_access) | **POST** /{nomad_mount_path}/config/access | 
*SecretsApi* | [**nomad_configure_lease**](docs/SecretsApi.md#nomad_configure_lease) | **POST** /{nomad_mount_path}/config/lease | 
*SecretsApi* | [**nomad_delete_access_configuration**](docs/SecretsApi.md#nomad_delete_access_configuration) | **DELETE** /{nomad_mount_path}/config/access | 
*SecretsApi* | [**nomad_delete_lease_configuration**](docs/SecretsApi.md#nomad_delete_lease_configuration) | **DELETE** /{nomad_mount_path}/config/lease | 
*SecretsApi* | [**nomad_delete_role**](docs/SecretsApi.md#nomad_delete_role) | **DELETE** /{nomad_mount_path}/role/{name} | 
*SecretsApi* | [**nomad_generate_credentials**](docs/SecretsApi.md#nomad_generate_credentials) | **GET** /{nomad_mount_path}/creds/{name} | 
*SecretsApi* | [**nomad_list_roles**](docs/SecretsApi.md#nomad_list_roles) | **GET** /{nomad_mount_path}/role/ | 
*SecretsApi* | [**nomad_read_access_configuration**](docs/SecretsApi.md#nomad_read_access_configuration) | **GET** /{nomad_mount_path}/config/access | 
*SecretsApi* | [**nomad_read_lease_configuration**](docs/SecretsApi.md#nomad_read_lease_configuration) | **GET** /{nomad_mount_path}/config/lease | 
*SecretsApi* | [**nomad_read_role**](docs/SecretsApi.md#nomad_read_role) | **GET** /{nomad_mount_path}/role/{name} | 
*SecretsApi* | [**nomad_write_role**](docs/SecretsApi.md#nomad_write_role) | **POST** /{nomad_mount_path}/role/{name} | 
*SecretsApi* | [**pki_configure_acme**](docs/SecretsApi.md#pki_configure_acme) | **POST** /{pki_mount_path}/config/acme | 
*SecretsApi* | [**pki_configure_auto_tidy**](docs/SecretsApi.md#pki_configure_auto_tidy) | **POST** /{pki_mount_path}/config/auto-tidy | 
*SecretsApi* | [**pki_configure_ca**](docs/SecretsApi.md#pki_configure_ca) | **POST** /{pki_mount_path}/config/ca | 
*SecretsApi* | [**pki_configure_cluster**](docs/SecretsApi.md#pki_configure_cluster) | **POST** /{pki_mount_path}/config/cluster | 
*SecretsApi* | [**pki_configure_crl**](docs/SecretsApi.md#pki_configure_crl) | **POST** /{pki_mount_path}/config/crl | 
*SecretsApi* | [**pki_configure_issuers**](docs/SecretsApi.md#pki_configure_issuers) | **POST** /{pki_mount_path}/config/issuers | 
*SecretsApi* | [**pki_configure_keys**](docs/SecretsApi.md#pki_configure_keys) | **POST** /{pki_mount_path}/config/keys | 
*SecretsApi* | [**pki_configure_urls**](docs/SecretsApi.md#pki_configure_urls) | **POST** /{pki_mount_path}/config/urls | 
*SecretsApi* | [**pki_cross_sign_intermediate**](docs/SecretsApi.md#pki_cross_sign_intermediate) | **POST** /{pki_mount_path}/intermediate/cross-sign | 
*SecretsApi* | [**pki_delete_eab_key**](docs/SecretsApi.md#pki_delete_eab_key) | **DELETE** /{pki_mount_path}/eab/{key_id} | 
*SecretsApi* | [**pki_delete_issuer**](docs/SecretsApi.md#pki_delete_issuer) | **DELETE** /{pki_mount_path}/issuer/{issuer_ref} | 
*SecretsApi* | [**pki_delete_key**](docs/SecretsApi.md#pki_delete_key) | **DELETE** /{pki_mount_path}/key/{key_ref} | 
*SecretsApi* | [**pki_delete_role**](docs/SecretsApi.md#pki_delete_role) | **DELETE** /{pki_mount_path}/roles/{name} | 
*SecretsApi* | [**pki_delete_root**](docs/SecretsApi.md#pki_delete_root) | **DELETE** /{pki_mount_path}/root | 
*SecretsApi* | [**pki_generate_eab_key**](docs/SecretsApi.md#pki_generate_eab_key) | **POST** /{pki_mount_path}/acme/new-eab | 
*SecretsApi* | [**pki_generate_eab_key_for_issuer**](docs/SecretsApi.md#pki_generate_eab_key_for_issuer) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/new-eab | 
*SecretsApi* | [**pki_generate_eab_key_for_issuer_and_role**](docs/SecretsApi.md#pki_generate_eab_key_for_issuer_and_role) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/new-eab | 
*SecretsApi* | [**pki_generate_eab_key_for_role**](docs/SecretsApi.md#pki_generate_eab_key_for_role) | **POST** /{pki_mount_path}/roles/{role}/acme/new-eab | 
*SecretsApi* | [**pki_generate_exported_key**](docs/SecretsApi.md#pki_generate_exported_key) | **POST** /{pki_mount_path}/keys/generate/exported | 
*SecretsApi* | [**pki_generate_intermediate**](docs/SecretsApi.md#pki_generate_intermediate) | **POST** /{pki_mount_path}/intermediate/generate/{exported} | 
*SecretsApi* | [**pki_generate_internal_key**](docs/SecretsApi.md#pki_generate_internal_key) | **POST** /{pki_mount_path}/keys/generate/internal | 
*SecretsApi* | [**pki_generate_kms_key**](docs/SecretsApi.md#pki_generate_kms_key) | **POST** /{pki_mount_path}/keys/generate/kms | 
*SecretsApi* | [**pki_generate_root**](docs/SecretsApi.md#pki_generate_root) | **POST** /{pki_mount_path}/root/generate/{exported} | 
*SecretsApi* | [**pki_import_key**](docs/SecretsApi.md#pki_import_key) | **POST** /{pki_mount_path}/keys/import | 
*SecretsApi* | [**pki_issue_with_role**](docs/SecretsApi.md#pki_issue_with_role) | **POST** /{pki_mount_path}/issue/{role} | 
*SecretsApi* | [**pki_issuer_issue_with_role**](docs/SecretsApi.md#pki_issuer_issue_with_role) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/issue/{role} | 
*SecretsApi* | [**pki_issuer_read_crl**](docs/SecretsApi.md#pki_issuer_read_crl) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl | 
*SecretsApi* | [**pki_issuer_read_crl_delta**](docs/SecretsApi.md#pki_issuer_read_crl_delta) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl/delta | 
*SecretsApi* | [**pki_issuer_read_crl_delta_der**](docs/SecretsApi.md#pki_issuer_read_crl_delta_der) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl/delta/der | 
*SecretsApi* | [**pki_issuer_read_crl_delta_pem**](docs/SecretsApi.md#pki_issuer_read_crl_delta_pem) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl/delta/pem | 
*SecretsApi* | [**pki_issuer_read_crl_der**](docs/SecretsApi.md#pki_issuer_read_crl_der) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl/der | 
*SecretsApi* | [**pki_issuer_read_crl_pem**](docs/SecretsApi.md#pki_issuer_read_crl_pem) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/crl/pem | 
*SecretsApi* | [**pki_issuer_resign_crls**](docs/SecretsApi.md#pki_issuer_resign_crls) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/resign-crls | 
*SecretsApi* | [**pki_issuer_sign_intermediate**](docs/SecretsApi.md#pki_issuer_sign_intermediate) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign-intermediate | 
*SecretsApi* | [**pki_issuer_sign_revocation_list**](docs/SecretsApi.md#pki_issuer_sign_revocation_list) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign-revocation-list | 
*SecretsApi* | [**pki_issuer_sign_self_issued**](docs/SecretsApi.md#pki_issuer_sign_self_issued) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign-self-issued | 
*SecretsApi* | [**pki_issuer_sign_verbatim**](docs/SecretsApi.md#pki_issuer_sign_verbatim) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign-verbatim | 
*SecretsApi* | [**pki_issuer_sign_verbatim_with_role**](docs/SecretsApi.md#pki_issuer_sign_verbatim_with_role) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign-verbatim/{role} | 
*SecretsApi* | [**pki_issuer_sign_with_role**](docs/SecretsApi.md#pki_issuer_sign_with_role) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/sign/{role} | 
*SecretsApi* | [**pki_issuers_generate_intermediate**](docs/SecretsApi.md#pki_issuers_generate_intermediate) | **POST** /{pki_mount_path}/issuers/generate/intermediate/{exported} | 
*SecretsApi* | [**pki_issuers_generate_root**](docs/SecretsApi.md#pki_issuers_generate_root) | **POST** /{pki_mount_path}/issuers/generate/root/{exported} | 
*SecretsApi* | [**pki_issuers_import_bundle**](docs/SecretsApi.md#pki_issuers_import_bundle) | **POST** /{pki_mount_path}/issuers/import/bundle | 
*SecretsApi* | [**pki_issuers_import_cert**](docs/SecretsApi.md#pki_issuers_import_cert) | **POST** /{pki_mount_path}/issuers/import/cert | 
*SecretsApi* | [**pki_list_certs**](docs/SecretsApi.md#pki_list_certs) | **GET** /{pki_mount_path}/certs/ | 
*SecretsApi* | [**pki_list_eab_keys**](docs/SecretsApi.md#pki_list_eab_keys) | **GET** /{pki_mount_path}/eab/ | 
*SecretsApi* | [**pki_list_issuers**](docs/SecretsApi.md#pki_list_issuers) | **GET** /{pki_mount_path}/issuers/ | 
*SecretsApi* | [**pki_list_keys**](docs/SecretsApi.md#pki_list_keys) | **GET** /{pki_mount_path}/keys/ | 
*SecretsApi* | [**pki_list_revoked_certs**](docs/SecretsApi.md#pki_list_revoked_certs) | **GET** /{pki_mount_path}/certs/revoked/ | 
*SecretsApi* | [**pki_list_roles**](docs/SecretsApi.md#pki_list_roles) | **GET** /{pki_mount_path}/roles/ | 
*SecretsApi* | [**pki_query_ocsp**](docs/SecretsApi.md#pki_query_ocsp) | **POST** /{pki_mount_path}/ocsp | 
*SecretsApi* | [**pki_query_ocsp_with_get_req**](docs/SecretsApi.md#pki_query_ocsp_with_get_req) | **GET** /{pki_mount_path}/ocsp/{req} | 
*SecretsApi* | [**pki_read_acme_configuration**](docs/SecretsApi.md#pki_read_acme_configuration) | **GET** /{pki_mount_path}/config/acme | 
*SecretsApi* | [**pki_read_acme_directory**](docs/SecretsApi.md#pki_read_acme_directory) | **GET** /{pki_mount_path}/acme/directory | 
*SecretsApi* | [**pki_read_acme_new_nonce**](docs/SecretsApi.md#pki_read_acme_new_nonce) | **GET** /{pki_mount_path}/acme/new-nonce | 
*SecretsApi* | [**pki_read_auto_tidy_configuration**](docs/SecretsApi.md#pki_read_auto_tidy_configuration) | **GET** /{pki_mount_path}/config/auto-tidy | 
*SecretsApi* | [**pki_read_ca_chain_pem**](docs/SecretsApi.md#pki_read_ca_chain_pem) | **GET** /{pki_mount_path}/ca_chain | 
*SecretsApi* | [**pki_read_ca_der**](docs/SecretsApi.md#pki_read_ca_der) | **GET** /{pki_mount_path}/ca | 
*SecretsApi* | [**pki_read_ca_pem**](docs/SecretsApi.md#pki_read_ca_pem) | **GET** /{pki_mount_path}/ca/pem | 
*SecretsApi* | [**pki_read_cert**](docs/SecretsApi.md#pki_read_cert) | **GET** /{pki_mount_path}/cert/{serial} | 
*SecretsApi* | [**pki_read_cert_ca_chain**](docs/SecretsApi.md#pki_read_cert_ca_chain) | **GET** /{pki_mount_path}/cert/ca_chain | 
*SecretsApi* | [**pki_read_cert_crl**](docs/SecretsApi.md#pki_read_cert_crl) | **GET** /{pki_mount_path}/cert/crl | 
*SecretsApi* | [**pki_read_cert_delta_crl**](docs/SecretsApi.md#pki_read_cert_delta_crl) | **GET** /{pki_mount_path}/cert/delta-crl | 
*SecretsApi* | [**pki_read_cert_raw_der**](docs/SecretsApi.md#pki_read_cert_raw_der) | **GET** /{pki_mount_path}/cert/{serial}/raw | 
*SecretsApi* | [**pki_read_cert_raw_pem**](docs/SecretsApi.md#pki_read_cert_raw_pem) | **GET** /{pki_mount_path}/cert/{serial}/raw/pem | 
*SecretsApi* | [**pki_read_cluster_configuration**](docs/SecretsApi.md#pki_read_cluster_configuration) | **GET** /{pki_mount_path}/config/cluster | 
*SecretsApi* | [**pki_read_crl_configuration**](docs/SecretsApi.md#pki_read_crl_configuration) | **GET** /{pki_mount_path}/config/crl | 
*SecretsApi* | [**pki_read_crl_delta**](docs/SecretsApi.md#pki_read_crl_delta) | **GET** /{pki_mount_path}/crl/delta | 
*SecretsApi* | [**pki_read_crl_delta_pem**](docs/SecretsApi.md#pki_read_crl_delta_pem) | **GET** /{pki_mount_path}/crl/delta/pem | 
*SecretsApi* | [**pki_read_crl_der**](docs/SecretsApi.md#pki_read_crl_der) | **GET** /{pki_mount_path}/crl | 
*SecretsApi* | [**pki_read_crl_pem**](docs/SecretsApi.md#pki_read_crl_pem) | **GET** /{pki_mount_path}/crl/pem | 
*SecretsApi* | [**pki_read_issuer**](docs/SecretsApi.md#pki_read_issuer) | **GET** /{pki_mount_path}/issuer/{issuer_ref} | 
*SecretsApi* | [**pki_read_issuer_der**](docs/SecretsApi.md#pki_read_issuer_der) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/der | 
*SecretsApi* | [**pki_read_issuer_issuer_ref_acme_directory**](docs/SecretsApi.md#pki_read_issuer_issuer_ref_acme_directory) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/acme/directory | 
*SecretsApi* | [**pki_read_issuer_issuer_ref_acme_new_nonce**](docs/SecretsApi.md#pki_read_issuer_issuer_ref_acme_new_nonce) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/acme/new-nonce | 
*SecretsApi* | [**pki_read_issuer_issuer_ref_roles_role_acme_directory**](docs/SecretsApi.md#pki_read_issuer_issuer_ref_roles_role_acme_directory) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/directory | 
*SecretsApi* | [**pki_read_issuer_issuer_ref_roles_role_acme_new_nonce**](docs/SecretsApi.md#pki_read_issuer_issuer_ref_roles_role_acme_new_nonce) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/new-nonce | 
*SecretsApi* | [**pki_read_issuer_json**](docs/SecretsApi.md#pki_read_issuer_json) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/json | 
*SecretsApi* | [**pki_read_issuer_pem**](docs/SecretsApi.md#pki_read_issuer_pem) | **GET** /{pki_mount_path}/issuer/{issuer_ref}/pem | 
*SecretsApi* | [**pki_read_issuers_configuration**](docs/SecretsApi.md#pki_read_issuers_configuration) | **GET** /{pki_mount_path}/config/issuers | 
*SecretsApi* | [**pki_read_key**](docs/SecretsApi.md#pki_read_key) | **GET** /{pki_mount_path}/key/{key_ref} | 
*SecretsApi* | [**pki_read_keys_configuration**](docs/SecretsApi.md#pki_read_keys_configuration) | **GET** /{pki_mount_path}/config/keys | 
*SecretsApi* | [**pki_read_role**](docs/SecretsApi.md#pki_read_role) | **GET** /{pki_mount_path}/roles/{name} | 
*SecretsApi* | [**pki_read_roles_role_acme_directory**](docs/SecretsApi.md#pki_read_roles_role_acme_directory) | **GET** /{pki_mount_path}/roles/{role}/acme/directory | 
*SecretsApi* | [**pki_read_roles_role_acme_new_nonce**](docs/SecretsApi.md#pki_read_roles_role_acme_new_nonce) | **GET** /{pki_mount_path}/roles/{role}/acme/new-nonce | 
*SecretsApi* | [**pki_read_urls_configuration**](docs/SecretsApi.md#pki_read_urls_configuration) | **GET** /{pki_mount_path}/config/urls | 
*SecretsApi* | [**pki_replace_root**](docs/SecretsApi.md#pki_replace_root) | **POST** /{pki_mount_path}/root/replace | 
*SecretsApi* | [**pki_revoke**](docs/SecretsApi.md#pki_revoke) | **POST** /{pki_mount_path}/revoke | 
*SecretsApi* | [**pki_revoke_issuer**](docs/SecretsApi.md#pki_revoke_issuer) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/revoke | 
*SecretsApi* | [**pki_revoke_with_key**](docs/SecretsApi.md#pki_revoke_with_key) | **POST** /{pki_mount_path}/revoke-with-key | 
*SecretsApi* | [**pki_root_sign_intermediate**](docs/SecretsApi.md#pki_root_sign_intermediate) | **POST** /{pki_mount_path}/root/sign-intermediate | 
*SecretsApi* | [**pki_root_sign_self_issued**](docs/SecretsApi.md#pki_root_sign_self_issued) | **POST** /{pki_mount_path}/root/sign-self-issued | 
*SecretsApi* | [**pki_rotate_crl**](docs/SecretsApi.md#pki_rotate_crl) | **GET** /{pki_mount_path}/crl/rotate | 
*SecretsApi* | [**pki_rotate_delta_crl**](docs/SecretsApi.md#pki_rotate_delta_crl) | **GET** /{pki_mount_path}/crl/rotate-delta | 
*SecretsApi* | [**pki_rotate_root**](docs/SecretsApi.md#pki_rotate_root) | **POST** /{pki_mount_path}/root/rotate/{exported} | 
*SecretsApi* | [**pki_set_signed_intermediate**](docs/SecretsApi.md#pki_set_signed_intermediate) | **POST** /{pki_mount_path}/intermediate/set-signed | 
*SecretsApi* | [**pki_sign_verbatim**](docs/SecretsApi.md#pki_sign_verbatim) | **POST** /{pki_mount_path}/sign-verbatim | 
*SecretsApi* | [**pki_sign_verbatim_with_role**](docs/SecretsApi.md#pki_sign_verbatim_with_role) | **POST** /{pki_mount_path}/sign-verbatim/{role} | 
*SecretsApi* | [**pki_sign_with_role**](docs/SecretsApi.md#pki_sign_with_role) | **POST** /{pki_mount_path}/sign/{role} | 
*SecretsApi* | [**pki_tidy**](docs/SecretsApi.md#pki_tidy) | **POST** /{pki_mount_path}/tidy | 
*SecretsApi* | [**pki_tidy_cancel**](docs/SecretsApi.md#pki_tidy_cancel) | **POST** /{pki_mount_path}/tidy-cancel | 
*SecretsApi* | [**pki_tidy_status**](docs/SecretsApi.md#pki_tidy_status) | **GET** /{pki_mount_path}/tidy-status | 
*SecretsApi* | [**pki_write_acme_account_kid**](docs/SecretsApi.md#pki_write_acme_account_kid) | **POST** /{pki_mount_path}/acme/account/{kid} | 
*SecretsApi* | [**pki_write_acme_authorization_auth_id**](docs/SecretsApi.md#pki_write_acme_authorization_auth_id) | **POST** /{pki_mount_path}/acme/authorization/{auth_id} | 
*SecretsApi* | [**pki_write_acme_challenge_auth_id_challenge_type**](docs/SecretsApi.md#pki_write_acme_challenge_auth_id_challenge_type) | **POST** /{pki_mount_path}/acme/challenge/{auth_id}/{challenge_type} | 
*SecretsApi* | [**pki_write_acme_new_account**](docs/SecretsApi.md#pki_write_acme_new_account) | **POST** /{pki_mount_path}/acme/new-account | 
*SecretsApi* | [**pki_write_acme_new_order**](docs/SecretsApi.md#pki_write_acme_new_order) | **POST** /{pki_mount_path}/acme/new-order | 
*SecretsApi* | [**pki_write_acme_order_order_id**](docs/SecretsApi.md#pki_write_acme_order_order_id) | **POST** /{pki_mount_path}/acme/order/{order_id} | 
*SecretsApi* | [**pki_write_acme_order_order_id_cert**](docs/SecretsApi.md#pki_write_acme_order_order_id_cert) | **POST** /{pki_mount_path}/acme/order/{order_id}/cert | 
*SecretsApi* | [**pki_write_acme_order_order_id_finalize**](docs/SecretsApi.md#pki_write_acme_order_order_id_finalize) | **POST** /{pki_mount_path}/acme/order/{order_id}/finalize | 
*SecretsApi* | [**pki_write_acme_orders**](docs/SecretsApi.md#pki_write_acme_orders) | **POST** /{pki_mount_path}/acme/orders | 
*SecretsApi* | [**pki_write_acme_revoke_cert**](docs/SecretsApi.md#pki_write_acme_revoke_cert) | **POST** /{pki_mount_path}/acme/revoke-cert | 
*SecretsApi* | [**pki_write_issuer**](docs/SecretsApi.md#pki_write_issuer) | **POST** /{pki_mount_path}/issuer/{issuer_ref} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_account_kid**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_account_kid) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/account/{kid} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_authorization_auth_id**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_authorization_auth_id) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/authorization/{auth_id} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/challenge/{auth_id}/{challenge_type} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_new_account**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_new_account) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/new-account | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_new_order**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_new_order) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/new-order | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_order_order_id**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_order_order_id) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/order/{order_id} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_order_order_id_cert**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_order_order_id_cert) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/order/{order_id}/cert | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_order_order_id_finalize**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_order_order_id_finalize) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/order/{order_id}/finalize | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_orders**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_orders) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/orders | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_acme_revoke_cert**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_acme_revoke_cert) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/acme/revoke-cert | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_account_kid**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_account_kid) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/account/{kid} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/authorization/{auth_id} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/challenge/{auth_id}/{challenge_type} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_new_account**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_new_account) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/new-account | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_new_order**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_new_order) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/new-order | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_order_order_id**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_order_order_id) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/order/{order_id} | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/order/{order_id}/cert | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/order/{order_id}/finalize | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_orders**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_orders) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/orders | 
*SecretsApi* | [**pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert**](docs/SecretsApi.md#pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert) | **POST** /{pki_mount_path}/issuer/{issuer_ref}/roles/{role}/acme/revoke-cert | 
*SecretsApi* | [**pki_write_key**](docs/SecretsApi.md#pki_write_key) | **POST** /{pki_mount_path}/key/{key_ref} | 
*SecretsApi* | [**pki_write_role**](docs/SecretsApi.md#pki_write_role) | **POST** /{pki_mount_path}/roles/{name} | 
*SecretsApi* | [**pki_write_roles_role_acme_account_kid**](docs/SecretsApi.md#pki_write_roles_role_acme_account_kid) | **POST** /{pki_mount_path}/roles/{role}/acme/account/{kid} | 
*SecretsApi* | [**pki_write_roles_role_acme_authorization_auth_id**](docs/SecretsApi.md#pki_write_roles_role_acme_authorization_auth_id) | **POST** /{pki_mount_path}/roles/{role}/acme/authorization/{auth_id} | 
*SecretsApi* | [**pki_write_roles_role_acme_challenge_auth_id_challenge_type**](docs/SecretsApi.md#pki_write_roles_role_acme_challenge_auth_id_challenge_type) | **POST** /{pki_mount_path}/roles/{role}/acme/challenge/{auth_id}/{challenge_type} | 
*SecretsApi* | [**pki_write_roles_role_acme_new_account**](docs/SecretsApi.md#pki_write_roles_role_acme_new_account) | **POST** /{pki_mount_path}/roles/{role}/acme/new-account | 
*SecretsApi* | [**pki_write_roles_role_acme_new_order**](docs/SecretsApi.md#pki_write_roles_role_acme_new_order) | **POST** /{pki_mount_path}/roles/{role}/acme/new-order | 
*SecretsApi* | [**pki_write_roles_role_acme_order_order_id**](docs/SecretsApi.md#pki_write_roles_role_acme_order_order_id) | **POST** /{pki_mount_path}/roles/{role}/acme/order/{order_id} | 
*SecretsApi* | [**pki_write_roles_role_acme_order_order_id_cert**](docs/SecretsApi.md#pki_write_roles_role_acme_order_order_id_cert) | **POST** /{pki_mount_path}/roles/{role}/acme/order/{order_id}/cert | 
*SecretsApi* | [**pki_write_roles_role_acme_order_order_id_finalize**](docs/SecretsApi.md#pki_write_roles_role_acme_order_order_id_finalize) | **POST** /{pki_mount_path}/roles/{role}/acme/order/{order_id}/finalize | 
*SecretsApi* | [**pki_write_roles_role_acme_orders**](docs/SecretsApi.md#pki_write_roles_role_acme_orders) | **POST** /{pki_mount_path}/roles/{role}/acme/orders | 
*SecretsApi* | [**pki_write_roles_role_acme_revoke_cert**](docs/SecretsApi.md#pki_write_roles_role_acme_revoke_cert) | **POST** /{pki_mount_path}/roles/{role}/acme/revoke-cert | 
*SecretsApi* | [**rabbit_mq_configure_connection**](docs/SecretsApi.md#rabbit_mq_configure_connection) | **POST** /{rabbitmq_mount_path}/config/connection | Configure the connection URI, username, and password to talk to RabbitMQ management HTTP API.
*SecretsApi* | [**rabbit_mq_configure_lease**](docs/SecretsApi.md#rabbit_mq_configure_lease) | **POST** /{rabbitmq_mount_path}/config/lease | 
*SecretsApi* | [**rabbit_mq_delete_role**](docs/SecretsApi.md#rabbit_mq_delete_role) | **DELETE** /{rabbitmq_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**rabbit_mq_list_roles**](docs/SecretsApi.md#rabbit_mq_list_roles) | **GET** /{rabbitmq_mount_path}/roles/ | Manage the roles that can be created with this backend.
*SecretsApi* | [**rabbit_mq_read_lease_configuration**](docs/SecretsApi.md#rabbit_mq_read_lease_configuration) | **GET** /{rabbitmq_mount_path}/config/lease | 
*SecretsApi* | [**rabbit_mq_read_role**](docs/SecretsApi.md#rabbit_mq_read_role) | **GET** /{rabbitmq_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**rabbit_mq_request_credentials**](docs/SecretsApi.md#rabbit_mq_request_credentials) | **GET** /{rabbitmq_mount_path}/creds/{name} | Request RabbitMQ credentials for a certain role.
*SecretsApi* | [**rabbit_mq_write_role**](docs/SecretsApi.md#rabbit_mq_write_role) | **POST** /{rabbitmq_mount_path}/roles/{name} | Manage the roles that can be created with this backend.
*SecretsApi* | [**ssh_configure_ca**](docs/SecretsApi.md#ssh_configure_ca) | **POST** /{ssh_mount_path}/config/ca | 
*SecretsApi* | [**ssh_configure_zero_address**](docs/SecretsApi.md#ssh_configure_zero_address) | **POST** /{ssh_mount_path}/config/zeroaddress | 
*SecretsApi* | [**ssh_delete_ca_configuration**](docs/SecretsApi.md#ssh_delete_ca_configuration) | **DELETE** /{ssh_mount_path}/config/ca | 
*SecretsApi* | [**ssh_delete_role**](docs/SecretsApi.md#ssh_delete_role) | **DELETE** /{ssh_mount_path}/roles/{role} | Manage the &#39;roles&#39; that can be created with this backend.
*SecretsApi* | [**ssh_delete_zero_address_configuration**](docs/SecretsApi.md#ssh_delete_zero_address_configuration) | **DELETE** /{ssh_mount_path}/config/zeroaddress | 
*SecretsApi* | [**ssh_generate_credentials**](docs/SecretsApi.md#ssh_generate_credentials) | **POST** /{ssh_mount_path}/creds/{role} | Creates a credential for establishing SSH connection with the remote host.
*SecretsApi* | [**ssh_issue_certificate**](docs/SecretsApi.md#ssh_issue_certificate) | **POST** /{ssh_mount_path}/issue/{role} | 
*SecretsApi* | [**ssh_list_roles**](docs/SecretsApi.md#ssh_list_roles) | **GET** /{ssh_mount_path}/roles/ | Manage the &#39;roles&#39; that can be created with this backend.
*SecretsApi* | [**ssh_list_roles_by_ip**](docs/SecretsApi.md#ssh_list_roles_by_ip) | **POST** /{ssh_mount_path}/lookup | List all the roles associated with the given IP address.
*SecretsApi* | [**ssh_read_ca_configuration**](docs/SecretsApi.md#ssh_read_ca_configuration) | **GET** /{ssh_mount_path}/config/ca | 
*SecretsApi* | [**ssh_read_public_key**](docs/SecretsApi.md#ssh_read_public_key) | **GET** /{ssh_mount_path}/public_key | Retrieve the public key.
*SecretsApi* | [**ssh_read_role**](docs/SecretsApi.md#ssh_read_role) | **GET** /{ssh_mount_path}/roles/{role} | Manage the &#39;roles&#39; that can be created with this backend.
*SecretsApi* | [**ssh_read_zero_address_configuration**](docs/SecretsApi.md#ssh_read_zero_address_configuration) | **GET** /{ssh_mount_path}/config/zeroaddress | 
*SecretsApi* | [**ssh_sign_certificate**](docs/SecretsApi.md#ssh_sign_certificate) | **POST** /{ssh_mount_path}/sign/{role} | Request signing an SSH key using a certain role with the provided details.
*SecretsApi* | [**ssh_tidy_dynamic_host_keys**](docs/SecretsApi.md#ssh_tidy_dynamic_host_keys) | **DELETE** /{ssh_mount_path}/tidy/dynamic-keys | This endpoint removes the stored host keys used for the removed Dynamic Key feature, if present.
*SecretsApi* | [**ssh_verify_otp**](docs/SecretsApi.md#ssh_verify_otp) | **POST** /{ssh_mount_path}/verify | Validate the OTP provided by Vault SSH Agent.
*SecretsApi* | [**ssh_write_role**](docs/SecretsApi.md#ssh_write_role) | **POST** /{ssh_mount_path}/roles/{role} | Manage the &#39;roles&#39; that can be created with this backend.
*SecretsApi* | [**terraform_cloud_configure**](docs/SecretsApi.md#terraform_cloud_configure) | **POST** /{terraform_mount_path}/config | 
*SecretsApi* | [**terraform_cloud_delete_configuration**](docs/SecretsApi.md#terraform_cloud_delete_configuration) | **DELETE** /{terraform_mount_path}/config | 
*SecretsApi* | [**terraform_cloud_delete_role**](docs/SecretsApi.md#terraform_cloud_delete_role) | **DELETE** /{terraform_mount_path}/role/{name} | 
*SecretsApi* | [**terraform_cloud_generate_credentials**](docs/SecretsApi.md#terraform_cloud_generate_credentials) | **GET** /{terraform_mount_path}/creds/{name} | 
*SecretsApi* | [**terraform_cloud_generate_credentials2**](docs/SecretsApi.md#terraform_cloud_generate_credentials2) | **POST** /{terraform_mount_path}/creds/{name} | 
*SecretsApi* | [**terraform_cloud_list_roles**](docs/SecretsApi.md#terraform_cloud_list_roles) | **GET** /{terraform_mount_path}/role/ | 
*SecretsApi* | [**terraform_cloud_read_configuration**](docs/SecretsApi.md#terraform_cloud_read_configuration) | **GET** /{terraform_mount_path}/config | 
*SecretsApi* | [**terraform_cloud_read_role**](docs/SecretsApi.md#terraform_cloud_read_role) | **GET** /{terraform_mount_path}/role/{name} | 
*SecretsApi* | [**terraform_cloud_rotate_role**](docs/SecretsApi.md#terraform_cloud_rotate_role) | **POST** /{terraform_mount_path}/rotate-role/{name} | 
*SecretsApi* | [**terraform_cloud_write_role**](docs/SecretsApi.md#terraform_cloud_write_role) | **POST** /{terraform_mount_path}/role/{name} | 
*SecretsApi* | [**totp_create_key**](docs/SecretsApi.md#totp_create_key) | **POST** /{totp_mount_path}/keys/{name} | 
*SecretsApi* | [**totp_delete_key**](docs/SecretsApi.md#totp_delete_key) | **DELETE** /{totp_mount_path}/keys/{name} | 
*SecretsApi* | [**totp_generate_code**](docs/SecretsApi.md#totp_generate_code) | **GET** /{totp_mount_path}/code/{name} | 
*SecretsApi* | [**totp_list_keys**](docs/SecretsApi.md#totp_list_keys) | **GET** /{totp_mount_path}/keys/ | Manage the keys that can be created with this backend.
*SecretsApi* | [**totp_read_key**](docs/SecretsApi.md#totp_read_key) | **GET** /{totp_mount_path}/keys/{name} | 
*SecretsApi* | [**totp_validate_code**](docs/SecretsApi.md#totp_validate_code) | **POST** /{totp_mount_path}/code/{name} | 
*SecretsApi* | [**transit_back_up_key**](docs/SecretsApi.md#transit_back_up_key) | **GET** /{transit_mount_path}/backup/{name} | Backup the named key
*SecretsApi* | [**transit_byok_key**](docs/SecretsApi.md#transit_byok_key) | **GET** /{transit_mount_path}/byok-export/{destination}/{source} | Securely export named encryption or signing key
*SecretsApi* | [**transit_byok_key_version**](docs/SecretsApi.md#transit_byok_key_version) | **GET** /{transit_mount_path}/byok-export/{destination}/{source}/{version} | Securely export named encryption or signing key
*SecretsApi* | [**transit_configure_cache**](docs/SecretsApi.md#transit_configure_cache) | **POST** /{transit_mount_path}/cache-config | Configures a new cache of the specified size
*SecretsApi* | [**transit_configure_key**](docs/SecretsApi.md#transit_configure_key) | **POST** /{transit_mount_path}/keys/{name}/config | Configure a named encryption key
*SecretsApi* | [**transit_configure_keys**](docs/SecretsApi.md#transit_configure_keys) | **POST** /{transit_mount_path}/config/keys | 
*SecretsApi* | [**transit_create_key**](docs/SecretsApi.md#transit_create_key) | **POST** /{transit_mount_path}/keys/{name} | 
*SecretsApi* | [**transit_decrypt**](docs/SecretsApi.md#transit_decrypt) | **POST** /{transit_mount_path}/decrypt/{name} | Decrypt a ciphertext value using a named key
*SecretsApi* | [**transit_delete_key**](docs/SecretsApi.md#transit_delete_key) | **DELETE** /{transit_mount_path}/keys/{name} | 
*SecretsApi* | [**transit_encrypt**](docs/SecretsApi.md#transit_encrypt) | **POST** /{transit_mount_path}/encrypt/{name} | Encrypt a plaintext value or a batch of plaintext blocks using a named key
*SecretsApi* | [**transit_export_key**](docs/SecretsApi.md#transit_export_key) | **GET** /{transit_mount_path}/export/{type}/{name} | Export named encryption or signing key
*SecretsApi* | [**transit_export_key_version**](docs/SecretsApi.md#transit_export_key_version) | **GET** /{transit_mount_path}/export/{type}/{name}/{version} | Export named encryption or signing key
*SecretsApi* | [**transit_generate_csr_for_key**](docs/SecretsApi.md#transit_generate_csr_for_key) | **POST** /{transit_mount_path}/keys/{name}/csr | 
*SecretsApi* | [**transit_generate_data_key**](docs/SecretsApi.md#transit_generate_data_key) | **POST** /{transit_mount_path}/datakey/{plaintext}/{name} | Generate a data key
*SecretsApi* | [**transit_generate_hmac**](docs/SecretsApi.md#transit_generate_hmac) | **POST** /{transit_mount_path}/hmac/{name} | Generate an HMAC for input data using the named key
*SecretsApi* | [**transit_generate_hmac_with_algorithm**](docs/SecretsApi.md#transit_generate_hmac_with_algorithm) | **POST** /{transit_mount_path}/hmac/{name}/{urlalgorithm} | Generate an HMAC for input data using the named key
*SecretsApi* | [**transit_generate_random**](docs/SecretsApi.md#transit_generate_random) | **POST** /{transit_mount_path}/random | Generate random bytes
*SecretsApi* | [**transit_generate_random_with_bytes**](docs/SecretsApi.md#transit_generate_random_with_bytes) | **POST** /{transit_mount_path}/random/{urlbytes} | Generate random bytes
*SecretsApi* | [**transit_generate_random_with_source**](docs/SecretsApi.md#transit_generate_random_with_source) | **POST** /{transit_mount_path}/random/{source} | Generate random bytes
*SecretsApi* | [**transit_generate_random_with_source_and_bytes**](docs/SecretsApi.md#transit_generate_random_with_source_and_bytes) | **POST** /{transit_mount_path}/random/{source}/{urlbytes} | Generate random bytes
*SecretsApi* | [**transit_hash**](docs/SecretsApi.md#transit_hash) | **POST** /{transit_mount_path}/hash | Generate a hash sum for input data
*SecretsApi* | [**transit_hash_with_algorithm**](docs/SecretsApi.md#transit_hash_with_algorithm) | **POST** /{transit_mount_path}/hash/{urlalgorithm} | Generate a hash sum for input data
*SecretsApi* | [**transit_import_key**](docs/SecretsApi.md#transit_import_key) | **POST** /{transit_mount_path}/keys/{name}/import | Imports an externally-generated key into a new transit key
*SecretsApi* | [**transit_import_key_version**](docs/SecretsApi.md#transit_import_key_version) | **POST** /{transit_mount_path}/keys/{name}/import_version | Imports an externally-generated key into an existing imported key
*SecretsApi* | [**transit_list_keys**](docs/SecretsApi.md#transit_list_keys) | **GET** /{transit_mount_path}/keys/ | Managed named encryption keys
*SecretsApi* | [**transit_read_cache_configuration**](docs/SecretsApi.md#transit_read_cache_configuration) | **GET** /{transit_mount_path}/cache-config | Returns the size of the active cache
*SecretsApi* | [**transit_read_key**](docs/SecretsApi.md#transit_read_key) | **GET** /{transit_mount_path}/keys/{name} | 
*SecretsApi* | [**transit_read_keys_configuration**](docs/SecretsApi.md#transit_read_keys_configuration) | **GET** /{transit_mount_path}/config/keys | 
*SecretsApi* | [**transit_read_wrapping_key**](docs/SecretsApi.md#transit_read_wrapping_key) | **GET** /{transit_mount_path}/wrapping_key | Returns the public key to use for wrapping imported keys
*SecretsApi* | [**transit_restore_and_rename_key**](docs/SecretsApi.md#transit_restore_and_rename_key) | **POST** /{transit_mount_path}/restore/{name} | Restore the named key
*SecretsApi* | [**transit_restore_key**](docs/SecretsApi.md#transit_restore_key) | **POST** /{transit_mount_path}/restore | Restore the named key
*SecretsApi* | [**transit_rewrap**](docs/SecretsApi.md#transit_rewrap) | **POST** /{transit_mount_path}/rewrap/{name} | Rewrap ciphertext
*SecretsApi* | [**transit_rotate_key**](docs/SecretsApi.md#transit_rotate_key) | **POST** /{transit_mount_path}/keys/{name}/rotate | Rotate named encryption key
*SecretsApi* | [**transit_set_certificate_for_key**](docs/SecretsApi.md#transit_set_certificate_for_key) | **POST** /{transit_mount_path}/keys/{name}/set-certificate | 
*SecretsApi* | [**transit_sign**](docs/SecretsApi.md#transit_sign) | **POST** /{transit_mount_path}/sign/{name} | Generate a signature for input data using the named key
*SecretsApi* | [**transit_sign_with_algorithm**](docs/SecretsApi.md#transit_sign_with_algorithm) | **POST** /{transit_mount_path}/sign/{name}/{urlalgorithm} | Generate a signature for input data using the named key
*SecretsApi* | [**transit_trim_key**](docs/SecretsApi.md#transit_trim_key) | **POST** /{transit_mount_path}/keys/{name}/trim | Trim key versions of a named key
*SecretsApi* | [**transit_verify**](docs/SecretsApi.md#transit_verify) | **POST** /{transit_mount_path}/verify/{name} | Verify a signature or HMAC for input data created using the named key
*SecretsApi* | [**transit_verify_with_algorithm**](docs/SecretsApi.md#transit_verify_with_algorithm) | **POST** /{transit_mount_path}/verify/{name}/{urlalgorithm} | Verify a signature or HMAC for input data created using the named key
*SystemApi* | [**auditing_calculate_hash**](docs/SystemApi.md#auditing_calculate_hash) | **POST** /sys/audit-hash/{path} | 
*SystemApi* | [**auditing_disable_device**](docs/SystemApi.md#auditing_disable_device) | **DELETE** /sys/audit/{path} | Disable the audit device at the given path.
*SystemApi* | [**auditing_disable_request_header**](docs/SystemApi.md#auditing_disable_request_header) | **DELETE** /sys/config/auditing/request-headers/{header} | Disable auditing of the given request header.
*SystemApi* | [**auditing_enable_device**](docs/SystemApi.md#auditing_enable_device) | **POST** /sys/audit/{path} | Enable a new audit device at the supplied path.
*SystemApi* | [**auditing_enable_request_header**](docs/SystemApi.md#auditing_enable_request_header) | **POST** /sys/config/auditing/request-headers/{header} | Enable auditing of a header.
*SystemApi* | [**auditing_list_enabled_devices**](docs/SystemApi.md#auditing_list_enabled_devices) | **GET** /sys/audit | List the enabled audit devices.
*SystemApi* | [**auditing_list_request_headers**](docs/SystemApi.md#auditing_list_request_headers) | **GET** /sys/config/auditing/request-headers | List the request headers that are configured to be audited.
*SystemApi* | [**auditing_read_request_header_information**](docs/SystemApi.md#auditing_read_request_header_information) | **GET** /sys/config/auditing/request-headers/{header} | List the information for the given request header.
*SystemApi* | [**auth_disable_method**](docs/SystemApi.md#auth_disable_method) | **DELETE** /sys/auth/{path} | Disable the auth method at the given auth path
*SystemApi* | [**auth_enable_method**](docs/SystemApi.md#auth_enable_method) | **POST** /sys/auth/{path} | Enables a new auth method.
*SystemApi* | [**auth_list_enabled_methods**](docs/SystemApi.md#auth_list_enabled_methods) | **GET** /sys/auth | 
*SystemApi* | [**auth_read_configuration**](docs/SystemApi.md#auth_read_configuration) | **GET** /sys/auth/{path} | Read the configuration of the auth engine at the given path.
*SystemApi* | [**auth_read_tuning_information**](docs/SystemApi.md#auth_read_tuning_information) | **GET** /sys/auth/{path}/tune | Reads the given auth path&#39;s configuration.
*SystemApi* | [**auth_tune_configuration_parameters**](docs/SystemApi.md#auth_tune_configuration_parameters) | **POST** /sys/auth/{path}/tune | Tune configuration parameters for a given auth path.
*SystemApi* | [**collect_host_information**](docs/SystemApi.md#collect_host_information) | **GET** /sys/host-info | Information about the host instance that this Vault server is running on.
*SystemApi* | [**collect_in_flight_request_information**](docs/SystemApi.md#collect_in_flight_request_information) | **GET** /sys/in-flight-req | reports in-flight requests
*SystemApi* | [**cors_configure**](docs/SystemApi.md#cors_configure) | **POST** /sys/config/cors | Configure the CORS settings.
*SystemApi* | [**cors_delete_configuration**](docs/SystemApi.md#cors_delete_configuration) | **DELETE** /sys/config/cors | Remove any CORS settings.
*SystemApi* | [**cors_read_configuration**](docs/SystemApi.md#cors_read_configuration) | **GET** /sys/config/cors | Return the current CORS settings.
*SystemApi* | [**decode**](docs/SystemApi.md#decode) | **POST** /sys/decode-token | Decodes the encoded token with the otp.
*SystemApi* | [**encryption_key_configure_rotation**](docs/SystemApi.md#encryption_key_configure_rotation) | **POST** /sys/rotate/config | 
*SystemApi* | [**encryption_key_read_rotation_configuration**](docs/SystemApi.md#encryption_key_read_rotation_configuration) | **GET** /sys/rotate/config | 
*SystemApi* | [**encryption_key_rotate**](docs/SystemApi.md#encryption_key_rotate) | **POST** /sys/rotate | 
*SystemApi* | [**encryption_key_status**](docs/SystemApi.md#encryption_key_status) | **GET** /sys/key-status | Provides information about the backend encryption key.
*SystemApi* | [**enterprise_stub_delete_config_control_group**](docs/SystemApi.md#enterprise_stub_delete_config_control_group) | **DELETE** /sys/config/control-group | 
*SystemApi* | [**enterprise_stub_delete_managed_keys_type_name**](docs/SystemApi.md#enterprise_stub_delete_managed_keys_type_name) | **DELETE** /sys/managed-keys/{type}/{name} | 
*SystemApi* | [**enterprise_stub_delete_mfa_method_duo_name**](docs/SystemApi.md#enterprise_stub_delete_mfa_method_duo_name) | **DELETE** /sys/mfa/method/duo/{name} | 
*SystemApi* | [**enterprise_stub_delete_mfa_method_okta_name**](docs/SystemApi.md#enterprise_stub_delete_mfa_method_okta_name) | **DELETE** /sys/mfa/method/okta/{name} | 
*SystemApi* | [**enterprise_stub_delete_mfa_method_pingid_name**](docs/SystemApi.md#enterprise_stub_delete_mfa_method_pingid_name) | **DELETE** /sys/mfa/method/pingid/{name} | 
*SystemApi* | [**enterprise_stub_delete_mfa_method_totp_name**](docs/SystemApi.md#enterprise_stub_delete_mfa_method_totp_name) | **DELETE** /sys/mfa/method/totp/{name} | 
*SystemApi* | [**enterprise_stub_delete_namespaces_path**](docs/SystemApi.md#enterprise_stub_delete_namespaces_path) | **DELETE** /sys/namespaces/{path} | 
*SystemApi* | [**enterprise_stub_delete_policies_egp_name**](docs/SystemApi.md#enterprise_stub_delete_policies_egp_name) | **DELETE** /sys/policies/egp/{name} | 
*SystemApi* | [**enterprise_stub_delete_policies_rgp_name**](docs/SystemApi.md#enterprise_stub_delete_policies_rgp_name) | **DELETE** /sys/policies/rgp/{name} | 
*SystemApi* | [**enterprise_stub_delete_quotas_lease_count_name**](docs/SystemApi.md#enterprise_stub_delete_quotas_lease_count_name) | **DELETE** /sys/quotas/lease-count/{name} | 
*SystemApi* | [**enterprise_stub_delete_replication_performance_primary_paths_filter_id**](docs/SystemApi.md#enterprise_stub_delete_replication_performance_primary_paths_filter_id) | **DELETE** /sys/replication/performance/primary/paths-filter/{id} | 
*SystemApi* | [**enterprise_stub_delete_storage_raft_snapshot_auto_config_name**](docs/SystemApi.md#enterprise_stub_delete_storage_raft_snapshot_auto_config_name) | **DELETE** /sys/storage/raft/snapshot-auto/config/{name} | 
*SystemApi* | [**enterprise_stub_list_managed_keys_type**](docs/SystemApi.md#enterprise_stub_list_managed_keys_type) | **GET** /sys/managed-keys/{type}/ | 
*SystemApi* | [**enterprise_stub_list_mfa_method**](docs/SystemApi.md#enterprise_stub_list_mfa_method) | **GET** /sys/mfa/method/ | 
*SystemApi* | [**enterprise_stub_list_namespaces**](docs/SystemApi.md#enterprise_stub_list_namespaces) | **GET** /sys/namespaces/ | 
*SystemApi* | [**enterprise_stub_list_policies_egp**](docs/SystemApi.md#enterprise_stub_list_policies_egp) | **GET** /sys/policies/egp/ | 
*SystemApi* | [**enterprise_stub_list_policies_rgp**](docs/SystemApi.md#enterprise_stub_list_policies_rgp) | **GET** /sys/policies/rgp/ | 
*SystemApi* | [**enterprise_stub_list_quotas_lease_count**](docs/SystemApi.md#enterprise_stub_list_quotas_lease_count) | **GET** /sys/quotas/lease-count/ | 
*SystemApi* | [**enterprise_stub_list_storage_raft_snapshot_auto_config**](docs/SystemApi.md#enterprise_stub_list_storage_raft_snapshot_auto_config) | **GET** /sys/storage/raft/snapshot-auto/config/ | 
*SystemApi* | [**enterprise_stub_read_config_control_group**](docs/SystemApi.md#enterprise_stub_read_config_control_group) | **GET** /sys/config/control-group | 
*SystemApi* | [**enterprise_stub_read_config_group_policy_application**](docs/SystemApi.md#enterprise_stub_read_config_group_policy_application) | **GET** /sys/config/group-policy-application | 
*SystemApi* | [**enterprise_stub_read_license_status**](docs/SystemApi.md#enterprise_stub_read_license_status) | **GET** /sys/license/status | 
*SystemApi* | [**enterprise_stub_read_managed_keys_type_name**](docs/SystemApi.md#enterprise_stub_read_managed_keys_type_name) | **GET** /sys/managed-keys/{type}/{name} | 
*SystemApi* | [**enterprise_stub_read_mfa_method_duo_name**](docs/SystemApi.md#enterprise_stub_read_mfa_method_duo_name) | **GET** /sys/mfa/method/duo/{name} | 
*SystemApi* | [**enterprise_stub_read_mfa_method_okta_name**](docs/SystemApi.md#enterprise_stub_read_mfa_method_okta_name) | **GET** /sys/mfa/method/okta/{name} | 
*SystemApi* | [**enterprise_stub_read_mfa_method_pingid_name**](docs/SystemApi.md#enterprise_stub_read_mfa_method_pingid_name) | **GET** /sys/mfa/method/pingid/{name} | 
*SystemApi* | [**enterprise_stub_read_mfa_method_totp_name**](docs/SystemApi.md#enterprise_stub_read_mfa_method_totp_name) | **GET** /sys/mfa/method/totp/{name} | 
*SystemApi* | [**enterprise_stub_read_mfa_method_totp_name_generate**](docs/SystemApi.md#enterprise_stub_read_mfa_method_totp_name_generate) | **GET** /sys/mfa/method/totp/{name}/generate | 
*SystemApi* | [**enterprise_stub_read_namespaces_path**](docs/SystemApi.md#enterprise_stub_read_namespaces_path) | **GET** /sys/namespaces/{path} | 
*SystemApi* | [**enterprise_stub_read_plugins_reload_backend_status**](docs/SystemApi.md#enterprise_stub_read_plugins_reload_backend_status) | **GET** /sys/plugins/reload/backend/status | 
*SystemApi* | [**enterprise_stub_read_policies_egp_name**](docs/SystemApi.md#enterprise_stub_read_policies_egp_name) | **GET** /sys/policies/egp/{name} | 
*SystemApi* | [**enterprise_stub_read_policies_rgp_name**](docs/SystemApi.md#enterprise_stub_read_policies_rgp_name) | **GET** /sys/policies/rgp/{name} | 
*SystemApi* | [**enterprise_stub_read_quotas_lease_count_name**](docs/SystemApi.md#enterprise_stub_read_quotas_lease_count_name) | **GET** /sys/quotas/lease-count/{name} | 
*SystemApi* | [**enterprise_stub_read_replication_dr_secondary_license_status**](docs/SystemApi.md#enterprise_stub_read_replication_dr_secondary_license_status) | **GET** /sys/replication/dr/secondary/license/status | 
*SystemApi* | [**enterprise_stub_read_replication_dr_status**](docs/SystemApi.md#enterprise_stub_read_replication_dr_status) | **GET** /sys/replication/dr/status | 
*SystemApi* | [**enterprise_stub_read_replication_performance_primary_dynamic_filter_id**](docs/SystemApi.md#enterprise_stub_read_replication_performance_primary_dynamic_filter_id) | **GET** /sys/replication/performance/primary/dynamic-filter/{id} | 
*SystemApi* | [**enterprise_stub_read_replication_performance_primary_paths_filter_id**](docs/SystemApi.md#enterprise_stub_read_replication_performance_primary_paths_filter_id) | **GET** /sys/replication/performance/primary/paths-filter/{id} | 
*SystemApi* | [**enterprise_stub_read_replication_performance_secondary_dynamic_filter_id**](docs/SystemApi.md#enterprise_stub_read_replication_performance_secondary_dynamic_filter_id) | **GET** /sys/replication/performance/secondary/dynamic-filter/{id} | 
*SystemApi* | [**enterprise_stub_read_replication_performance_status**](docs/SystemApi.md#enterprise_stub_read_replication_performance_status) | **GET** /sys/replication/performance/status | 
*SystemApi* | [**enterprise_stub_read_sealwrap_rewrap**](docs/SystemApi.md#enterprise_stub_read_sealwrap_rewrap) | **GET** /sys/sealwrap/rewrap | 
*SystemApi* | [**enterprise_stub_read_storage_raft_snapshot_auto_config_name**](docs/SystemApi.md#enterprise_stub_read_storage_raft_snapshot_auto_config_name) | **GET** /sys/storage/raft/snapshot-auto/config/{name} | 
*SystemApi* | [**enterprise_stub_read_storage_raft_snapshot_auto_status_name**](docs/SystemApi.md#enterprise_stub_read_storage_raft_snapshot_auto_status_name) | **GET** /sys/storage/raft/snapshot-auto/status/{name} | 
*SystemApi* | [**enterprise_stub_write_config_control_group**](docs/SystemApi.md#enterprise_stub_write_config_control_group) | **POST** /sys/config/control-group | 
*SystemApi* | [**enterprise_stub_write_config_group_policy_application**](docs/SystemApi.md#enterprise_stub_write_config_group_policy_application) | **POST** /sys/config/group-policy-application | 
*SystemApi* | [**enterprise_stub_write_control_group_authorize**](docs/SystemApi.md#enterprise_stub_write_control_group_authorize) | **POST** /sys/control-group/authorize | 
*SystemApi* | [**enterprise_stub_write_control_group_request**](docs/SystemApi.md#enterprise_stub_write_control_group_request) | **POST** /sys/control-group/request | 
*SystemApi* | [**enterprise_stub_write_managed_keys_type_name**](docs/SystemApi.md#enterprise_stub_write_managed_keys_type_name) | **POST** /sys/managed-keys/{type}/{name} | 
*SystemApi* | [**enterprise_stub_write_managed_keys_type_name_test_sign**](docs/SystemApi.md#enterprise_stub_write_managed_keys_type_name_test_sign) | **POST** /sys/managed-keys/{type}/{name}/test/sign | 
*SystemApi* | [**enterprise_stub_write_mfa_method_duo_name**](docs/SystemApi.md#enterprise_stub_write_mfa_method_duo_name) | **POST** /sys/mfa/method/duo/{name} | 
*SystemApi* | [**enterprise_stub_write_mfa_method_okta_name**](docs/SystemApi.md#enterprise_stub_write_mfa_method_okta_name) | **POST** /sys/mfa/method/okta/{name} | 
*SystemApi* | [**enterprise_stub_write_mfa_method_pingid_name**](docs/SystemApi.md#enterprise_stub_write_mfa_method_pingid_name) | **POST** /sys/mfa/method/pingid/{name} | 
*SystemApi* | [**enterprise_stub_write_mfa_method_totp_name**](docs/SystemApi.md#enterprise_stub_write_mfa_method_totp_name) | **POST** /sys/mfa/method/totp/{name} | 
*SystemApi* | [**enterprise_stub_write_mfa_method_totp_name_admin_destroy**](docs/SystemApi.md#enterprise_stub_write_mfa_method_totp_name_admin_destroy) | **POST** /sys/mfa/method/totp/{name}/admin-destroy | 
*SystemApi* | [**enterprise_stub_write_mfa_method_totp_name_admin_generate**](docs/SystemApi.md#enterprise_stub_write_mfa_method_totp_name_admin_generate) | **POST** /sys/mfa/method/totp/{name}/admin-generate | 
*SystemApi* | [**enterprise_stub_write_namespaces_api_lock_lock**](docs/SystemApi.md#enterprise_stub_write_namespaces_api_lock_lock) | **POST** /sys/namespaces/api-lock/lock | 
*SystemApi* | [**enterprise_stub_write_namespaces_api_lock_lock_path**](docs/SystemApi.md#enterprise_stub_write_namespaces_api_lock_lock_path) | **POST** /sys/namespaces/api-lock/lock/{path} | 
*SystemApi* | [**enterprise_stub_write_namespaces_api_lock_unlock**](docs/SystemApi.md#enterprise_stub_write_namespaces_api_lock_unlock) | **POST** /sys/namespaces/api-lock/unlock | 
*SystemApi* | [**enterprise_stub_write_namespaces_api_lock_unlock_path**](docs/SystemApi.md#enterprise_stub_write_namespaces_api_lock_unlock_path) | **POST** /sys/namespaces/api-lock/unlock/{path} | 
*SystemApi* | [**enterprise_stub_write_namespaces_path**](docs/SystemApi.md#enterprise_stub_write_namespaces_path) | **POST** /sys/namespaces/{path} | 
*SystemApi* | [**enterprise_stub_write_policies_egp_name**](docs/SystemApi.md#enterprise_stub_write_policies_egp_name) | **POST** /sys/policies/egp/{name} | 
*SystemApi* | [**enterprise_stub_write_policies_rgp_name**](docs/SystemApi.md#enterprise_stub_write_policies_rgp_name) | **POST** /sys/policies/rgp/{name} | 
*SystemApi* | [**enterprise_stub_write_quotas_lease_count_name**](docs/SystemApi.md#enterprise_stub_write_quotas_lease_count_name) | **POST** /sys/quotas/lease-count/{name} | 
*SystemApi* | [**enterprise_stub_write_replication_dr_primary_demote**](docs/SystemApi.md#enterprise_stub_write_replication_dr_primary_demote) | **POST** /sys/replication/dr/primary/demote | 
*SystemApi* | [**enterprise_stub_write_replication_dr_primary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_dr_primary_disable) | **POST** /sys/replication/dr/primary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_dr_primary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_dr_primary_enable) | **POST** /sys/replication/dr/primary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_dr_primary_revoke_secondary**](docs/SystemApi.md#enterprise_stub_write_replication_dr_primary_revoke_secondary) | **POST** /sys/replication/dr/primary/revoke-secondary | 
*SystemApi* | [**enterprise_stub_write_replication_dr_primary_secondary_token**](docs/SystemApi.md#enterprise_stub_write_replication_dr_primary_secondary_token) | **POST** /sys/replication/dr/primary/secondary-token | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_config_reload_subsystem**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_config_reload_subsystem) | **POST** /sys/replication/dr/secondary/config/reload/{subsystem} | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_disable) | **POST** /sys/replication/dr/secondary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_enable) | **POST** /sys/replication/dr/secondary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_generate_public_key**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_generate_public_key) | **POST** /sys/replication/dr/secondary/generate-public-key | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_operation_token_delete**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_operation_token_delete) | **POST** /sys/replication/dr/secondary/operation-token/delete | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_promote**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_promote) | **POST** /sys/replication/dr/secondary/promote | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_recover**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_recover) | **POST** /sys/replication/dr/secondary/recover | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_reindex**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_reindex) | **POST** /sys/replication/dr/secondary/reindex | 
*SystemApi* | [**enterprise_stub_write_replication_dr_secondary_update_primary**](docs/SystemApi.md#enterprise_stub_write_replication_dr_secondary_update_primary) | **POST** /sys/replication/dr/secondary/update-primary | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_demote**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_demote) | **POST** /sys/replication/performance/primary/demote | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_disable) | **POST** /sys/replication/performance/primary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_enable) | **POST** /sys/replication/performance/primary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_paths_filter_id**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_paths_filter_id) | **POST** /sys/replication/performance/primary/paths-filter/{id} | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_revoke_secondary**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_revoke_secondary) | **POST** /sys/replication/performance/primary/revoke-secondary | 
*SystemApi* | [**enterprise_stub_write_replication_performance_primary_secondary_token**](docs/SystemApi.md#enterprise_stub_write_replication_performance_primary_secondary_token) | **POST** /sys/replication/performance/primary/secondary-token | 
*SystemApi* | [**enterprise_stub_write_replication_performance_secondary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_performance_secondary_disable) | **POST** /sys/replication/performance/secondary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_performance_secondary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_performance_secondary_enable) | **POST** /sys/replication/performance/secondary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_performance_secondary_generate_public_key**](docs/SystemApi.md#enterprise_stub_write_replication_performance_secondary_generate_public_key) | **POST** /sys/replication/performance/secondary/generate-public-key | 
*SystemApi* | [**enterprise_stub_write_replication_performance_secondary_promote**](docs/SystemApi.md#enterprise_stub_write_replication_performance_secondary_promote) | **POST** /sys/replication/performance/secondary/promote | 
*SystemApi* | [**enterprise_stub_write_replication_performance_secondary_update_primary**](docs/SystemApi.md#enterprise_stub_write_replication_performance_secondary_update_primary) | **POST** /sys/replication/performance/secondary/update-primary | 
*SystemApi* | [**enterprise_stub_write_replication_primary_demote**](docs/SystemApi.md#enterprise_stub_write_replication_primary_demote) | **POST** /sys/replication/primary/demote | 
*SystemApi* | [**enterprise_stub_write_replication_primary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_primary_disable) | **POST** /sys/replication/primary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_primary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_primary_enable) | **POST** /sys/replication/primary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_primary_revoke_secondary**](docs/SystemApi.md#enterprise_stub_write_replication_primary_revoke_secondary) | **POST** /sys/replication/primary/revoke-secondary | 
*SystemApi* | [**enterprise_stub_write_replication_primary_secondary_token**](docs/SystemApi.md#enterprise_stub_write_replication_primary_secondary_token) | **POST** /sys/replication/primary/secondary-token | 
*SystemApi* | [**enterprise_stub_write_replication_recover**](docs/SystemApi.md#enterprise_stub_write_replication_recover) | **POST** /sys/replication/recover | 
*SystemApi* | [**enterprise_stub_write_replication_reindex**](docs/SystemApi.md#enterprise_stub_write_replication_reindex) | **POST** /sys/replication/reindex | 
*SystemApi* | [**enterprise_stub_write_replication_secondary_disable**](docs/SystemApi.md#enterprise_stub_write_replication_secondary_disable) | **POST** /sys/replication/secondary/disable | 
*SystemApi* | [**enterprise_stub_write_replication_secondary_enable**](docs/SystemApi.md#enterprise_stub_write_replication_secondary_enable) | **POST** /sys/replication/secondary/enable | 
*SystemApi* | [**enterprise_stub_write_replication_secondary_promote**](docs/SystemApi.md#enterprise_stub_write_replication_secondary_promote) | **POST** /sys/replication/secondary/promote | 
*SystemApi* | [**enterprise_stub_write_replication_secondary_update_primary**](docs/SystemApi.md#enterprise_stub_write_replication_secondary_update_primary) | **POST** /sys/replication/secondary/update-primary | 
*SystemApi* | [**enterprise_stub_write_sealwrap_rewrap**](docs/SystemApi.md#enterprise_stub_write_sealwrap_rewrap) | **POST** /sys/sealwrap/rewrap | 
*SystemApi* | [**enterprise_stub_write_storage_raft_snapshot_auto_config_name**](docs/SystemApi.md#enterprise_stub_write_storage_raft_snapshot_auto_config_name) | **POST** /sys/storage/raft/snapshot-auto/config/{name} | 
*SystemApi* | [**generate_hash**](docs/SystemApi.md#generate_hash) | **POST** /sys/tools/hash | 
*SystemApi* | [**generate_hash_with_algorithm**](docs/SystemApi.md#generate_hash_with_algorithm) | **POST** /sys/tools/hash/{urlalgorithm} | 
*SystemApi* | [**generate_random**](docs/SystemApi.md#generate_random) | **POST** /sys/tools/random | 
*SystemApi* | [**generate_random_with_bytes**](docs/SystemApi.md#generate_random_with_bytes) | **POST** /sys/tools/random/{urlbytes} | 
*SystemApi* | [**generate_random_with_source**](docs/SystemApi.md#generate_random_with_source) | **POST** /sys/tools/random/{source} | 
*SystemApi* | [**generate_random_with_source_and_bytes**](docs/SystemApi.md#generate_random_with_source_and_bytes) | **POST** /sys/tools/random/{source}/{urlbytes} | 
*SystemApi* | [**ha_status**](docs/SystemApi.md#ha_status) | **GET** /sys/ha-status | Check the HA status of a Vault cluster
*SystemApi* | [**initialize**](docs/SystemApi.md#initialize) | **POST** /sys/init | Initialize a new Vault.
*SystemApi* | [**internal_client_activity_configure**](docs/SystemApi.md#internal_client_activity_configure) | **POST** /sys/internal/counters/config | Enable or disable collection of client count, set retention period, or set default reporting period.
*SystemApi* | [**internal_client_activity_export**](docs/SystemApi.md#internal_client_activity_export) | **GET** /sys/internal/counters/activity/export | Report the client count metrics, for this namespace and all child namespaces.
*SystemApi* | [**internal_client_activity_read_configuration**](docs/SystemApi.md#internal_client_activity_read_configuration) | **GET** /sys/internal/counters/config | Read the client count tracking configuration.
*SystemApi* | [**internal_client_activity_report_counts**](docs/SystemApi.md#internal_client_activity_report_counts) | **GET** /sys/internal/counters/activity | Report the client count metrics, for this namespace and all child namespaces.
*SystemApi* | [**internal_client_activity_report_counts_this_month**](docs/SystemApi.md#internal_client_activity_report_counts_this_month) | **GET** /sys/internal/counters/activity/monthly | Report the number of clients for this month, for this namespace and all child namespaces.
*SystemApi* | [**internal_count_entities**](docs/SystemApi.md#internal_count_entities) | **GET** /sys/internal/counters/entities | Backwards compatibility is not guaranteed for this API
*SystemApi* | [**internal_count_requests**](docs/SystemApi.md#internal_count_requests) | **GET** /sys/internal/counters/requests | Backwards compatibility is not guaranteed for this API
*SystemApi* | [**internal_count_tokens**](docs/SystemApi.md#internal_count_tokens) | **GET** /sys/internal/counters/tokens | Backwards compatibility is not guaranteed for this API
*SystemApi* | [**internal_generate_open_api_document**](docs/SystemApi.md#internal_generate_open_api_document) | **GET** /sys/internal/specs/openapi | 
*SystemApi* | [**internal_generate_open_api_document_with_parameters**](docs/SystemApi.md#internal_generate_open_api_document_with_parameters) | **POST** /sys/internal/specs/openapi | 
*SystemApi* | [**internal_inspect_router**](docs/SystemApi.md#internal_inspect_router) | **GET** /sys/internal/inspect/router/{tag} | Expose the route entry and mount entry tables present in the router
*SystemApi* | [**internal_ui_list_enabled_feature_flags**](docs/SystemApi.md#internal_ui_list_enabled_feature_flags) | **GET** /sys/internal/ui/feature-flags | Lists enabled feature flags.
*SystemApi* | [**internal_ui_list_enabled_visible_mounts**](docs/SystemApi.md#internal_ui_list_enabled_visible_mounts) | **GET** /sys/internal/ui/mounts | Lists all enabled and visible auth and secrets mounts.
*SystemApi* | [**internal_ui_list_namespaces**](docs/SystemApi.md#internal_ui_list_namespaces) | **GET** /sys/internal/ui/namespaces | Backwards compatibility is not guaranteed for this API
*SystemApi* | [**internal_ui_read_mount_information**](docs/SystemApi.md#internal_ui_read_mount_information) | **GET** /sys/internal/ui/mounts/{path} | Return information about the given mount.
*SystemApi* | [**internal_ui_read_resultant_acl**](docs/SystemApi.md#internal_ui_read_resultant_acl) | **GET** /sys/internal/ui/resultant-acl | Backwards compatibility is not guaranteed for this API
*SystemApi* | [**leader_status**](docs/SystemApi.md#leader_status) | **GET** /sys/leader | Returns the high availability status and current leader instance of Vault.
*SystemApi* | [**leases_count**](docs/SystemApi.md#leases_count) | **GET** /sys/leases/count | 
*SystemApi* | [**leases_force_revoke_lease_with_prefix**](docs/SystemApi.md#leases_force_revoke_lease_with_prefix) | **POST** /sys/leases/revoke-force/{prefix} | Revokes all secrets or tokens generated under a given prefix immediately
*SystemApi* | [**leases_force_revoke_lease_with_prefix2**](docs/SystemApi.md#leases_force_revoke_lease_with_prefix2) | **POST** /sys/revoke-force/{prefix} | Revokes all secrets or tokens generated under a given prefix immediately
*SystemApi* | [**leases_list**](docs/SystemApi.md#leases_list) | **GET** /sys/leases | 
*SystemApi* | [**leases_look_up**](docs/SystemApi.md#leases_look_up) | **GET** /sys/leases/lookup/{prefix}/ | 
*SystemApi* | [**leases_read_lease**](docs/SystemApi.md#leases_read_lease) | **POST** /sys/leases/lookup | 
*SystemApi* | [**leases_renew_lease**](docs/SystemApi.md#leases_renew_lease) | **POST** /sys/leases/renew | Renews a lease, requesting to extend the lease.
*SystemApi* | [**leases_renew_lease2**](docs/SystemApi.md#leases_renew_lease2) | **POST** /sys/renew | Renews a lease, requesting to extend the lease.
*SystemApi* | [**leases_renew_lease_with_id**](docs/SystemApi.md#leases_renew_lease_with_id) | **POST** /sys/leases/renew/{url_lease_id} | Renews a lease, requesting to extend the lease.
*SystemApi* | [**leases_renew_lease_with_id2**](docs/SystemApi.md#leases_renew_lease_with_id2) | **POST** /sys/renew/{url_lease_id} | Renews a lease, requesting to extend the lease.
*SystemApi* | [**leases_revoke_lease**](docs/SystemApi.md#leases_revoke_lease) | **POST** /sys/leases/revoke | Revokes a lease immediately.
*SystemApi* | [**leases_revoke_lease2**](docs/SystemApi.md#leases_revoke_lease2) | **POST** /sys/revoke | Revokes a lease immediately.
*SystemApi* | [**leases_revoke_lease_with_id**](docs/SystemApi.md#leases_revoke_lease_with_id) | **POST** /sys/leases/revoke/{url_lease_id} | Revokes a lease immediately.
*SystemApi* | [**leases_revoke_lease_with_id2**](docs/SystemApi.md#leases_revoke_lease_with_id2) | **POST** /sys/revoke/{url_lease_id} | Revokes a lease immediately.
*SystemApi* | [**leases_revoke_lease_with_prefix**](docs/SystemApi.md#leases_revoke_lease_with_prefix) | **POST** /sys/leases/revoke-prefix/{prefix} | Revokes all secrets (via a lease ID prefix) or tokens (via the tokens&#39; path property) generated under a given prefix immediately.
*SystemApi* | [**leases_revoke_lease_with_prefix2**](docs/SystemApi.md#leases_revoke_lease_with_prefix2) | **POST** /sys/revoke-prefix/{prefix} | Revokes all secrets (via a lease ID prefix) or tokens (via the tokens&#39; path property) generated under a given prefix immediately.
*SystemApi* | [**leases_tidy**](docs/SystemApi.md#leases_tidy) | **POST** /sys/leases/tidy | 
*SystemApi* | [**list_experimental_features**](docs/SystemApi.md#list_experimental_features) | **GET** /sys/experiments | Returns the available and enabled experiments
*SystemApi* | [**locked_users_list**](docs/SystemApi.md#locked_users_list) | **GET** /sys/locked-users | Report the locked user count metrics, for this namespace and all child namespaces.
*SystemApi* | [**locked_users_unlock**](docs/SystemApi.md#locked_users_unlock) | **POST** /sys/locked-users/{mount_accessor}/unlock/{alias_identifier} | Unlocks the user with given mount_accessor and alias_identifier
*SystemApi* | [**loggers_read_verbosity_level**](docs/SystemApi.md#loggers_read_verbosity_level) | **GET** /sys/loggers | Read the log level for all existing loggers.
*SystemApi* | [**loggers_read_verbosity_level_for**](docs/SystemApi.md#loggers_read_verbosity_level_for) | **GET** /sys/loggers/{name} | Read the log level for a single logger.
*SystemApi* | [**loggers_revert_verbosity_level**](docs/SystemApi.md#loggers_revert_verbosity_level) | **DELETE** /sys/loggers | Revert the all loggers to use log level provided in config.
*SystemApi* | [**loggers_revert_verbosity_level_for**](docs/SystemApi.md#loggers_revert_verbosity_level_for) | **DELETE** /sys/loggers/{name} | Revert a single logger to use log level provided in config.
*SystemApi* | [**loggers_update_verbosity_level**](docs/SystemApi.md#loggers_update_verbosity_level) | **POST** /sys/loggers | Modify the log level for all existing loggers.
*SystemApi* | [**loggers_update_verbosity_level_for**](docs/SystemApi.md#loggers_update_verbosity_level_for) | **POST** /sys/loggers/{name} | Modify the log level of a single logger.
*SystemApi* | [**metrics**](docs/SystemApi.md#metrics) | **GET** /sys/metrics | 
*SystemApi* | [**mfa_validate**](docs/SystemApi.md#mfa_validate) | **POST** /sys/mfa/validate | Validates the login for the given MFA methods. Upon successful validation, it returns an auth response containing the client token
*SystemApi* | [**monitor**](docs/SystemApi.md#monitor) | **GET** /sys/monitor | 
*SystemApi* | [**mounts_disable_secrets_engine**](docs/SystemApi.md#mounts_disable_secrets_engine) | **DELETE** /sys/mounts/{path} | Disable the mount point specified at the given path.
*SystemApi* | [**mounts_enable_secrets_engine**](docs/SystemApi.md#mounts_enable_secrets_engine) | **POST** /sys/mounts/{path} | Enable a new secrets engine at the given path.
*SystemApi* | [**mounts_list_secrets_engines**](docs/SystemApi.md#mounts_list_secrets_engines) | **GET** /sys/mounts | 
*SystemApi* | [**mounts_read_configuration**](docs/SystemApi.md#mounts_read_configuration) | **GET** /sys/mounts/{path} | Read the configuration of the secret engine at the given path.
*SystemApi* | [**mounts_read_tuning_information**](docs/SystemApi.md#mounts_read_tuning_information) | **GET** /sys/mounts/{path}/tune | 
*SystemApi* | [**mounts_tune_configuration_parameters**](docs/SystemApi.md#mounts_tune_configuration_parameters) | **POST** /sys/mounts/{path}/tune | 
*SystemApi* | [**plugins_catalog_list_plugins**](docs/SystemApi.md#plugins_catalog_list_plugins) | **GET** /sys/plugins/catalog | 
*SystemApi* | [**plugins_catalog_list_plugins_with_type**](docs/SystemApi.md#plugins_catalog_list_plugins_with_type) | **GET** /sys/plugins/catalog/{type}/ | List the plugins in the catalog.
*SystemApi* | [**plugins_catalog_read_plugin_configuration**](docs/SystemApi.md#plugins_catalog_read_plugin_configuration) | **GET** /sys/plugins/catalog/{name} | Return the configuration data for the plugin with the given name.
*SystemApi* | [**plugins_catalog_read_plugin_configuration_with_type**](docs/SystemApi.md#plugins_catalog_read_plugin_configuration_with_type) | **GET** /sys/plugins/catalog/{type}/{name} | Return the configuration data for the plugin with the given name.
*SystemApi* | [**plugins_catalog_register_plugin**](docs/SystemApi.md#plugins_catalog_register_plugin) | **POST** /sys/plugins/catalog/{name} | Register a new plugin, or updates an existing one with the supplied name.
*SystemApi* | [**plugins_catalog_register_plugin_with_type**](docs/SystemApi.md#plugins_catalog_register_plugin_with_type) | **POST** /sys/plugins/catalog/{type}/{name} | Register a new plugin, or updates an existing one with the supplied name.
*SystemApi* | [**plugins_catalog_remove_plugin**](docs/SystemApi.md#plugins_catalog_remove_plugin) | **DELETE** /sys/plugins/catalog/{name} | Remove the plugin with the given name.
*SystemApi* | [**plugins_catalog_remove_plugin_with_type**](docs/SystemApi.md#plugins_catalog_remove_plugin_with_type) | **DELETE** /sys/plugins/catalog/{type}/{name} | Remove the plugin with the given name.
*SystemApi* | [**plugins_reload_backends**](docs/SystemApi.md#plugins_reload_backends) | **POST** /sys/plugins/reload/backend | Reload mounted plugin backends.
*SystemApi* | [**plugins_runtimes_catalog_list_plugins_runtimes**](docs/SystemApi.md#plugins_runtimes_catalog_list_plugins_runtimes) | **GET** /sys/plugins/runtimes/catalog/ | 
*SystemApi* | [**plugins_runtimes_catalog_read_plugin_runtime_configuration**](docs/SystemApi.md#plugins_runtimes_catalog_read_plugin_runtime_configuration) | **GET** /sys/plugins/runtimes/catalog/{type}/{name} | Return the configuration data for the plugin runtime with the given name.
*SystemApi* | [**plugins_runtimes_catalog_register_plugin_runtime**](docs/SystemApi.md#plugins_runtimes_catalog_register_plugin_runtime) | **POST** /sys/plugins/runtimes/catalog/{type}/{name} | Register a new plugin runtime, or updates an existing one with the supplied name.
*SystemApi* | [**plugins_runtimes_catalog_remove_plugin_runtime**](docs/SystemApi.md#plugins_runtimes_catalog_remove_plugin_runtime) | **DELETE** /sys/plugins/runtimes/catalog/{type}/{name} | Remove the plugin runtime with the given name.
*SystemApi* | [**policies_delete_acl_policy**](docs/SystemApi.md#policies_delete_acl_policy) | **DELETE** /sys/policies/acl/{name} | Delete the ACL policy with the given name.
*SystemApi* | [**policies_delete_acl_policy2**](docs/SystemApi.md#policies_delete_acl_policy2) | **DELETE** /sys/policy/{name} | Delete the policy with the given name.
*SystemApi* | [**policies_delete_password_policy**](docs/SystemApi.md#policies_delete_password_policy) | **DELETE** /sys/policies/password/{name} | Delete a password policy.
*SystemApi* | [**policies_generate_password_from_password_policy**](docs/SystemApi.md#policies_generate_password_from_password_policy) | **GET** /sys/policies/password/{name}/generate | Generate a password from an existing password policy.
*SystemApi* | [**policies_list_acl_policies**](docs/SystemApi.md#policies_list_acl_policies) | **GET** /sys/policies/acl/ | 
*SystemApi* | [**policies_list_acl_policies2**](docs/SystemApi.md#policies_list_acl_policies2) | **GET** /sys/policy | 
*SystemApi* | [**policies_list_acl_policies3**](docs/SystemApi.md#policies_list_acl_policies3) | **GET** /sys/policy/ | 
*SystemApi* | [**policies_list_password_policies**](docs/SystemApi.md#policies_list_password_policies) | **GET** /sys/policies/password/ | List the existing password policies.
*SystemApi* | [**policies_read_acl_policy**](docs/SystemApi.md#policies_read_acl_policy) | **GET** /sys/policies/acl/{name} | Retrieve information about the named ACL policy.
*SystemApi* | [**policies_read_acl_policy2**](docs/SystemApi.md#policies_read_acl_policy2) | **GET** /sys/policy/{name} | Retrieve the policy body for the named policy.
*SystemApi* | [**policies_read_password_policy**](docs/SystemApi.md#policies_read_password_policy) | **GET** /sys/policies/password/{name} | Retrieve an existing password policy.
*SystemApi* | [**policies_write_acl_policy**](docs/SystemApi.md#policies_write_acl_policy) | **POST** /sys/policies/acl/{name} | Add a new or update an existing ACL policy.
*SystemApi* | [**policies_write_acl_policy2**](docs/SystemApi.md#policies_write_acl_policy2) | **POST** /sys/policy/{name} | Add a new or update an existing policy.
*SystemApi* | [**policies_write_password_policy**](docs/SystemApi.md#policies_write_password_policy) | **POST** /sys/policies/password/{name} | Add a new or update an existing password policy.
*SystemApi* | [**pprof_blocking**](docs/SystemApi.md#pprof_blocking) | **GET** /sys/pprof/block | Returns stack traces that led to blocking on synchronization primitives
*SystemApi* | [**pprof_command_line**](docs/SystemApi.md#pprof_command_line) | **GET** /sys/pprof/cmdline | Returns the running program&#39;s command line.
*SystemApi* | [**pprof_cpu_profile**](docs/SystemApi.md#pprof_cpu_profile) | **GET** /sys/pprof/profile | Returns a pprof-formatted cpu profile payload.
*SystemApi* | [**pprof_execution_trace**](docs/SystemApi.md#pprof_execution_trace) | **GET** /sys/pprof/trace | Returns the execution trace in binary form.
*SystemApi* | [**pprof_goroutines**](docs/SystemApi.md#pprof_goroutines) | **GET** /sys/pprof/goroutine | Returns stack traces of all current goroutines.
*SystemApi* | [**pprof_index**](docs/SystemApi.md#pprof_index) | **GET** /sys/pprof | Returns an HTML page listing the available profiles.
*SystemApi* | [**pprof_memory_allocations**](docs/SystemApi.md#pprof_memory_allocations) | **GET** /sys/pprof/allocs | Returns a sampling of all past memory allocations.
*SystemApi* | [**pprof_memory_allocations_live**](docs/SystemApi.md#pprof_memory_allocations_live) | **GET** /sys/pprof/heap | Returns a sampling of memory allocations of live object.
*SystemApi* | [**pprof_mutexes**](docs/SystemApi.md#pprof_mutexes) | **GET** /sys/pprof/mutex | Returns stack traces of holders of contended mutexes
*SystemApi* | [**pprof_symbols**](docs/SystemApi.md#pprof_symbols) | **GET** /sys/pprof/symbol | Returns the program counters listed in the request.
*SystemApi* | [**pprof_thread_creations**](docs/SystemApi.md#pprof_thread_creations) | **GET** /sys/pprof/threadcreate | Returns stack traces that led to the creation of new OS threads
*SystemApi* | [**query_token_accessor_capabilities**](docs/SystemApi.md#query_token_accessor_capabilities) | **POST** /sys/capabilities-accessor | 
*SystemApi* | [**query_token_capabilities**](docs/SystemApi.md#query_token_capabilities) | **POST** /sys/capabilities | 
*SystemApi* | [**query_token_self_capabilities**](docs/SystemApi.md#query_token_self_capabilities) | **POST** /sys/capabilities-self | 
*SystemApi* | [**rate_limit_quotas_configure**](docs/SystemApi.md#rate_limit_quotas_configure) | **POST** /sys/quotas/config | 
*SystemApi* | [**rate_limit_quotas_delete**](docs/SystemApi.md#rate_limit_quotas_delete) | **DELETE** /sys/quotas/rate-limit/{name} | 
*SystemApi* | [**rate_limit_quotas_list**](docs/SystemApi.md#rate_limit_quotas_list) | **GET** /sys/quotas/rate-limit/ | 
*SystemApi* | [**rate_limit_quotas_read**](docs/SystemApi.md#rate_limit_quotas_read) | **GET** /sys/quotas/rate-limit/{name} | 
*SystemApi* | [**rate_limit_quotas_read_configuration**](docs/SystemApi.md#rate_limit_quotas_read_configuration) | **GET** /sys/quotas/config | 
*SystemApi* | [**rate_limit_quotas_write**](docs/SystemApi.md#rate_limit_quotas_write) | **POST** /sys/quotas/rate-limit/{name} | 
*SystemApi* | [**raw_delete**](docs/SystemApi.md#raw_delete) | **DELETE** /sys/raw/{path} | Delete the key with given path.
*SystemApi* | [**raw_list**](docs/SystemApi.md#raw_list) | **GET** /sys/raw/{path}/ | Return a list keys for a given path prefix.
*SystemApi* | [**raw_read**](docs/SystemApi.md#raw_read) | **GET** /sys/raw/{path} | Read the value of the key at the given path.
*SystemApi* | [**raw_write**](docs/SystemApi.md#raw_write) | **POST** /sys/raw/{path} | Update the value of the key at the given path.
*SystemApi* | [**read_health_status**](docs/SystemApi.md#read_health_status) | **GET** /sys/health | Returns the health status of Vault.
*SystemApi* | [**read_initialization_status**](docs/SystemApi.md#read_initialization_status) | **GET** /sys/init | Returns the initialization status of Vault.
*SystemApi* | [**read_replication_status**](docs/SystemApi.md#read_replication_status) | **GET** /sys/replication/status | 
*SystemApi* | [**read_sanitized_configuration_state**](docs/SystemApi.md#read_sanitized_configuration_state) | **GET** /sys/config/state/sanitized | Return a sanitized version of the Vault server configuration.
*SystemApi* | [**read_wrapping_properties**](docs/SystemApi.md#read_wrapping_properties) | **POST** /sys/wrapping/lookup | Look up wrapping properties for the given token.
*SystemApi* | [**read_wrapping_properties2**](docs/SystemApi.md#read_wrapping_properties2) | **GET** /sys/wrapping/lookup | Look up wrapping properties for the requester&#39;s token.
*SystemApi* | [**rekey_attempt_cancel**](docs/SystemApi.md#rekey_attempt_cancel) | **DELETE** /sys/rekey/init | Cancels any in-progress rekey.
*SystemApi* | [**rekey_attempt_initialize**](docs/SystemApi.md#rekey_attempt_initialize) | **POST** /sys/rekey/init | Initializes a new rekey attempt.
*SystemApi* | [**rekey_attempt_read_progress**](docs/SystemApi.md#rekey_attempt_read_progress) | **GET** /sys/rekey/init | Reads the configuration and progress of the current rekey attempt.
*SystemApi* | [**rekey_attempt_update**](docs/SystemApi.md#rekey_attempt_update) | **POST** /sys/rekey/update | Enter a single unseal key share to progress the rekey of the Vault.
*SystemApi* | [**rekey_delete_backup_key**](docs/SystemApi.md#rekey_delete_backup_key) | **DELETE** /sys/rekey/backup | Delete the backup copy of PGP-encrypted unseal keys.
*SystemApi* | [**rekey_delete_backup_recovery_key**](docs/SystemApi.md#rekey_delete_backup_recovery_key) | **DELETE** /sys/rekey/recovery-key-backup | 
*SystemApi* | [**rekey_read_backup_key**](docs/SystemApi.md#rekey_read_backup_key) | **GET** /sys/rekey/backup | Return the backup copy of PGP-encrypted unseal keys.
*SystemApi* | [**rekey_read_backup_recovery_key**](docs/SystemApi.md#rekey_read_backup_recovery_key) | **GET** /sys/rekey/recovery-key-backup | 
*SystemApi* | [**rekey_verification_cancel**](docs/SystemApi.md#rekey_verification_cancel) | **DELETE** /sys/rekey/verify | Cancel any in-progress rekey verification operation.
*SystemApi* | [**rekey_verification_read_progress**](docs/SystemApi.md#rekey_verification_read_progress) | **GET** /sys/rekey/verify | Read the configuration and progress of the current rekey verification attempt.
*SystemApi* | [**rekey_verification_update**](docs/SystemApi.md#rekey_verification_update) | **POST** /sys/rekey/verify | Enter a single new key share to progress the rekey verification operation.
*SystemApi* | [**reload_subsystem**](docs/SystemApi.md#reload_subsystem) | **POST** /sys/config/reload/{subsystem} | Reload the given subsystem
*SystemApi* | [**remount**](docs/SystemApi.md#remount) | **POST** /sys/remount | Initiate a mount migration
*SystemApi* | [**remount_status**](docs/SystemApi.md#remount_status) | **GET** /sys/remount/status/{migration_id} | Check status of a mount migration
*SystemApi* | [**rewrap**](docs/SystemApi.md#rewrap) | **POST** /sys/wrapping/rewrap | 
*SystemApi* | [**root_token_generation_cancel**](docs/SystemApi.md#root_token_generation_cancel) | **DELETE** /sys/generate-root/attempt | Cancels any in-progress root generation attempt.
*SystemApi* | [**root_token_generation_cancel2**](docs/SystemApi.md#root_token_generation_cancel2) | **DELETE** /sys/generate-root | Cancels any in-progress root generation attempt.
*SystemApi* | [**root_token_generation_initialize**](docs/SystemApi.md#root_token_generation_initialize) | **POST** /sys/generate-root/attempt | Initializes a new root generation attempt.
*SystemApi* | [**root_token_generation_initialize2**](docs/SystemApi.md#root_token_generation_initialize2) | **POST** /sys/generate-root | Initializes a new root generation attempt.
*SystemApi* | [**root_token_generation_read_progress**](docs/SystemApi.md#root_token_generation_read_progress) | **GET** /sys/generate-root/attempt | Read the configuration and progress of the current root generation attempt.
*SystemApi* | [**root_token_generation_read_progress2**](docs/SystemApi.md#root_token_generation_read_progress2) | **GET** /sys/generate-root | Read the configuration and progress of the current root generation attempt.
*SystemApi* | [**root_token_generation_update**](docs/SystemApi.md#root_token_generation_update) | **POST** /sys/generate-root/update | Enter a single unseal key share to progress the root generation attempt.
*SystemApi* | [**seal**](docs/SystemApi.md#seal) | **POST** /sys/seal | Seal the Vault.
*SystemApi* | [**seal_status**](docs/SystemApi.md#seal_status) | **GET** /sys/seal-status | Check the seal status of a Vault.
*SystemApi* | [**step_down_leader**](docs/SystemApi.md#step_down_leader) | **POST** /sys/step-down | Cause the node to give up active status.
*SystemApi* | [**ui_headers_configure**](docs/SystemApi.md#ui_headers_configure) | **POST** /sys/config/ui/headers/{header} | Configure the values to be returned for the UI header.
*SystemApi* | [**ui_headers_delete_configuration**](docs/SystemApi.md#ui_headers_delete_configuration) | **DELETE** /sys/config/ui/headers/{header} | Remove a UI header.
*SystemApi* | [**ui_headers_list**](docs/SystemApi.md#ui_headers_list) | **GET** /sys/config/ui/headers/ | Return a list of configured UI headers.
*SystemApi* | [**ui_headers_read_configuration**](docs/SystemApi.md#ui_headers_read_configuration) | **GET** /sys/config/ui/headers/{header} | Return the given UI header&#39;s configuration
*SystemApi* | [**unseal**](docs/SystemApi.md#unseal) | **POST** /sys/unseal | Unseal the Vault.
*SystemApi* | [**unwrap**](docs/SystemApi.md#unwrap) | **POST** /sys/wrapping/unwrap | 
*SystemApi* | [**version_history**](docs/SystemApi.md#version_history) | **GET** /sys/version-history/ | Returns map of historical version change entries
*SystemApi* | [**wrap**](docs/SystemApi.md#wrap) | **POST** /sys/wrapping/wrap | 


## Documentation For Models

 - [AliCloudConfigureRequest](docs/AliCloudConfigureRequest.md)
 - [AliCloudLoginRequest](docs/AliCloudLoginRequest.md)
 - [AliCloudWriteAuthRoleRequest](docs/AliCloudWriteAuthRoleRequest.md)
 - [AliCloudWriteRoleRequest](docs/AliCloudWriteRoleRequest.md)
 - [AliasCreateRequest](docs/AliasCreateRequest.md)
 - [AliasUpdateByIdRequest](docs/AliasUpdateByIdRequest.md)
 - [AppRoleDestroySecretIdByAccessorRequest](docs/AppRoleDestroySecretIdByAccessorRequest.md)
 - [AppRoleDestroySecretIdRequest](docs/AppRoleDestroySecretIdRequest.md)
 - [AppRoleLoginRequest](docs/AppRoleLoginRequest.md)
 - [AppRoleLoginResponse](docs/AppRoleLoginResponse.md)
 - [AppRoleLookUpSecretIdByAccessorRequest](docs/AppRoleLookUpSecretIdByAccessorRequest.md)
 - [AppRoleLookUpSecretIdByAccessorResponse](docs/AppRoleLookUpSecretIdByAccessorResponse.md)
 - [AppRoleLookUpSecretIdRequest](docs/AppRoleLookUpSecretIdRequest.md)
 - [AppRoleLookUpSecretIdResponse](docs/AppRoleLookUpSecretIdResponse.md)
 - [AppRoleReadBindSecretIdResponse](docs/AppRoleReadBindSecretIdResponse.md)
 - [AppRoleReadBoundCidrListResponse](docs/AppRoleReadBoundCidrListResponse.md)
 - [AppRoleReadLocalSecretIdsResponse](docs/AppRoleReadLocalSecretIdsResponse.md)
 - [AppRoleReadPeriodResponse](docs/AppRoleReadPeriodResponse.md)
 - [AppRoleReadPoliciesResponse](docs/AppRoleReadPoliciesResponse.md)
 - [AppRoleReadRoleIdResponse](docs/AppRoleReadRoleIdResponse.md)
 - [AppRoleReadRoleResponse](docs/AppRoleReadRoleResponse.md)
 - [AppRoleReadSecretIdBoundCidrsResponse](docs/AppRoleReadSecretIdBoundCidrsResponse.md)
 - [AppRoleReadSecretIdNumUsesResponse](docs/AppRoleReadSecretIdNumUsesResponse.md)
 - [AppRoleReadSecretIdTtlResponse](docs/AppRoleReadSecretIdTtlResponse.md)
 - [AppRoleReadTokenBoundCidrsResponse](docs/AppRoleReadTokenBoundCidrsResponse.md)
 - [AppRoleReadTokenMaxTtlResponse](docs/AppRoleReadTokenMaxTtlResponse.md)
 - [AppRoleReadTokenNumUsesResponse](docs/AppRoleReadTokenNumUsesResponse.md)
 - [AppRoleReadTokenTtlResponse](docs/AppRoleReadTokenTtlResponse.md)
 - [AppRoleWriteBindSecretIdRequest](docs/AppRoleWriteBindSecretIdRequest.md)
 - [AppRoleWriteBoundCidrListRequest](docs/AppRoleWriteBoundCidrListRequest.md)
 - [AppRoleWriteCustomSecretIdRequest](docs/AppRoleWriteCustomSecretIdRequest.md)
 - [AppRoleWriteCustomSecretIdResponse](docs/AppRoleWriteCustomSecretIdResponse.md)
 - [AppRoleWritePeriodRequest](docs/AppRoleWritePeriodRequest.md)
 - [AppRoleWritePoliciesRequest](docs/AppRoleWritePoliciesRequest.md)
 - [AppRoleWriteRoleIdRequest](docs/AppRoleWriteRoleIdRequest.md)
 - [AppRoleWriteRoleRequest](docs/AppRoleWriteRoleRequest.md)
 - [AppRoleWriteSecretIdBoundCidrsRequest](docs/AppRoleWriteSecretIdBoundCidrsRequest.md)
 - [AppRoleWriteSecretIdNumUsesRequest](docs/AppRoleWriteSecretIdNumUsesRequest.md)
 - [AppRoleWriteSecretIdRequest](docs/AppRoleWriteSecretIdRequest.md)
 - [AppRoleWriteSecretIdResponse](docs/AppRoleWriteSecretIdResponse.md)
 - [AppRoleWriteSecretIdTtlRequest](docs/AppRoleWriteSecretIdTtlRequest.md)
 - [AppRoleWriteTokenBoundCidrsRequest](docs/AppRoleWriteTokenBoundCidrsRequest.md)
 - [AppRoleWriteTokenMaxTtlRequest](docs/AppRoleWriteTokenMaxTtlRequest.md)
 - [AppRoleWriteTokenNumUsesRequest](docs/AppRoleWriteTokenNumUsesRequest.md)
 - [AppRoleWriteTokenTtlRequest](docs/AppRoleWriteTokenTtlRequest.md)
 - [AuditingCalculateHashRequest](docs/AuditingCalculateHashRequest.md)
 - [AuditingCalculateHashResponse](docs/AuditingCalculateHashResponse.md)
 - [AuditingEnableDeviceRequest](docs/AuditingEnableDeviceRequest.md)
 - [AuditingEnableRequestHeaderRequest](docs/AuditingEnableRequestHeaderRequest.md)
 - [AuditingListRequestHeadersResponse](docs/AuditingListRequestHeadersResponse.md)
 - [AuthEnableMethodRequest](docs/AuthEnableMethodRequest.md)
 - [AuthReadConfigurationResponse](docs/AuthReadConfigurationResponse.md)
 - [AuthReadTuningInformationResponse](docs/AuthReadTuningInformationResponse.md)
 - [AuthTuneConfigurationParametersRequest](docs/AuthTuneConfigurationParametersRequest.md)
 - [AwsConfigureCertificateRequest](docs/AwsConfigureCertificateRequest.md)
 - [AwsConfigureClientRequest](docs/AwsConfigureClientRequest.md)
 - [AwsConfigureIdentityAccessListTidyOperationRequest](docs/AwsConfigureIdentityAccessListTidyOperationRequest.md)
 - [AwsConfigureIdentityIntegrationRequest](docs/AwsConfigureIdentityIntegrationRequest.md)
 - [AwsConfigureIdentityWhitelistTidyOperationRequest](docs/AwsConfigureIdentityWhitelistTidyOperationRequest.md)
 - [AwsConfigureLeaseRequest](docs/AwsConfigureLeaseRequest.md)
 - [AwsConfigureRoleTagBlacklistTidyOperationRequest](docs/AwsConfigureRoleTagBlacklistTidyOperationRequest.md)
 - [AwsConfigureRoleTagDenyListTidyOperationRequest](docs/AwsConfigureRoleTagDenyListTidyOperationRequest.md)
 - [AwsConfigureRootIamCredentialsRequest](docs/AwsConfigureRootIamCredentialsRequest.md)
 - [AwsGenerateCredentialsWithParametersRequest](docs/AwsGenerateCredentialsWithParametersRequest.md)
 - [AwsGenerateStsCredentialsWithParametersRequest](docs/AwsGenerateStsCredentialsWithParametersRequest.md)
 - [AwsLoginRequest](docs/AwsLoginRequest.md)
 - [AwsReadStaticCredsNameResponse](docs/AwsReadStaticCredsNameResponse.md)
 - [AwsReadStaticRolesNameResponse](docs/AwsReadStaticRolesNameResponse.md)
 - [AwsTidyIdentityAccessListRequest](docs/AwsTidyIdentityAccessListRequest.md)
 - [AwsTidyIdentityWhitelistRequest](docs/AwsTidyIdentityWhitelistRequest.md)
 - [AwsTidyRoleTagBlacklistRequest](docs/AwsTidyRoleTagBlacklistRequest.md)
 - [AwsTidyRoleTagDenyListRequest](docs/AwsTidyRoleTagDenyListRequest.md)
 - [AwsWriteAuthRoleRequest](docs/AwsWriteAuthRoleRequest.md)
 - [AwsWriteRoleRequest](docs/AwsWriteRoleRequest.md)
 - [AwsWriteRoleTagRequest](docs/AwsWriteRoleTagRequest.md)
 - [AwsWriteStaticRolesNameRequest](docs/AwsWriteStaticRolesNameRequest.md)
 - [AwsWriteStaticRolesNameResponse](docs/AwsWriteStaticRolesNameResponse.md)
 - [AwsWriteStsRoleRequest](docs/AwsWriteStsRoleRequest.md)
 - [AzureConfigureAuthRequest](docs/AzureConfigureAuthRequest.md)
 - [AzureConfigureRequest](docs/AzureConfigureRequest.md)
 - [AzureLoginRequest](docs/AzureLoginRequest.md)
 - [AzureWriteAuthRoleRequest](docs/AzureWriteAuthRoleRequest.md)
 - [AzureWriteRoleRequest](docs/AzureWriteRoleRequest.md)
 - [CentrifyConfigureRequest](docs/CentrifyConfigureRequest.md)
 - [CentrifyLoginRequest](docs/CentrifyLoginRequest.md)
 - [CertConfigureRequest](docs/CertConfigureRequest.md)
 - [CertLoginRequest](docs/CertLoginRequest.md)
 - [CertWriteCertificateRequest](docs/CertWriteCertificateRequest.md)
 - [CertWriteCrlRequest](docs/CertWriteCrlRequest.md)
 - [CloudFoundryConfigureRequest](docs/CloudFoundryConfigureRequest.md)
 - [CloudFoundryLoginRequest](docs/CloudFoundryLoginRequest.md)
 - [CloudFoundryWriteRoleRequest](docs/CloudFoundryWriteRoleRequest.md)
 - [CollectHostInformationResponse](docs/CollectHostInformationResponse.md)
 - [ConsulConfigureAccessRequest](docs/ConsulConfigureAccessRequest.md)
 - [ConsulWriteRoleRequest](docs/ConsulWriteRoleRequest.md)
 - [CorsConfigureRequest](docs/CorsConfigureRequest.md)
 - [CorsReadConfigurationResponse](docs/CorsReadConfigurationResponse.md)
 - [DatabaseConfigureConnectionRequest](docs/DatabaseConfigureConnectionRequest.md)
 - [DatabaseWriteRoleRequest](docs/DatabaseWriteRoleRequest.md)
 - [DatabaseWriteStaticRoleRequest](docs/DatabaseWriteStaticRoleRequest.md)
 - [DecodeRequest](docs/DecodeRequest.md)
 - [EncryptionKeyConfigureRotationRequest](docs/EncryptionKeyConfigureRotationRequest.md)
 - [EncryptionKeyReadRotationConfigurationResponse](docs/EncryptionKeyReadRotationConfigurationResponse.md)
 - [EntityBatchDeleteRequest](docs/EntityBatchDeleteRequest.md)
 - [EntityCreateAliasRequest](docs/EntityCreateAliasRequest.md)
 - [EntityCreateRequest](docs/EntityCreateRequest.md)
 - [EntityLookUpRequest](docs/EntityLookUpRequest.md)
 - [EntityMergeRequest](docs/EntityMergeRequest.md)
 - [EntityUpdateAliasByIdRequest](docs/EntityUpdateAliasByIdRequest.md)
 - [EntityUpdateByIdRequest](docs/EntityUpdateByIdRequest.md)
 - [EntityUpdateByNameRequest](docs/EntityUpdateByNameRequest.md)
 - [GenerateHashRequest](docs/GenerateHashRequest.md)
 - [GenerateHashResponse](docs/GenerateHashResponse.md)
 - [GenerateHashWithAlgorithmRequest](docs/GenerateHashWithAlgorithmRequest.md)
 - [GenerateHashWithAlgorithmResponse](docs/GenerateHashWithAlgorithmResponse.md)
 - [GenerateRandomRequest](docs/GenerateRandomRequest.md)
 - [GenerateRandomResponse](docs/GenerateRandomResponse.md)
 - [GenerateRandomWithBytesRequest](docs/GenerateRandomWithBytesRequest.md)
 - [GenerateRandomWithBytesResponse](docs/GenerateRandomWithBytesResponse.md)
 - [GenerateRandomWithSourceAndBytesRequest](docs/GenerateRandomWithSourceAndBytesRequest.md)
 - [GenerateRandomWithSourceAndBytesResponse](docs/GenerateRandomWithSourceAndBytesResponse.md)
 - [GenerateRandomWithSourceRequest](docs/GenerateRandomWithSourceRequest.md)
 - [GenerateRandomWithSourceResponse](docs/GenerateRandomWithSourceResponse.md)
 - [GithubConfigureRequest](docs/GithubConfigureRequest.md)
 - [GithubLoginRequest](docs/GithubLoginRequest.md)
 - [GithubWriteTeamMappingRequest](docs/GithubWriteTeamMappingRequest.md)
 - [GithubWriteUserMappingRequest](docs/GithubWriteUserMappingRequest.md)
 - [GoogleCloudConfigureAuthRequest](docs/GoogleCloudConfigureAuthRequest.md)
 - [GoogleCloudConfigureRequest](docs/GoogleCloudConfigureRequest.md)
 - [GoogleCloudEditLabelsForRoleRequest](docs/GoogleCloudEditLabelsForRoleRequest.md)
 - [GoogleCloudEditServiceAccountsForRoleRequest](docs/GoogleCloudEditServiceAccountsForRoleRequest.md)
 - [GoogleCloudGenerateRolesetKey3Request](docs/GoogleCloudGenerateRolesetKey3Request.md)
 - [GoogleCloudGenerateRolesetKeyRequest](docs/GoogleCloudGenerateRolesetKeyRequest.md)
 - [GoogleCloudGenerateStaticAccountKeyRequest](docs/GoogleCloudGenerateStaticAccountKeyRequest.md)
 - [GoogleCloudKmsConfigureKeyRequest](docs/GoogleCloudKmsConfigureKeyRequest.md)
 - [GoogleCloudKmsConfigureRequest](docs/GoogleCloudKmsConfigureRequest.md)
 - [GoogleCloudKmsDecryptRequest](docs/GoogleCloudKmsDecryptRequest.md)
 - [GoogleCloudKmsEncryptRequest](docs/GoogleCloudKmsEncryptRequest.md)
 - [GoogleCloudKmsReencryptRequest](docs/GoogleCloudKmsReencryptRequest.md)
 - [GoogleCloudKmsRegisterKeyRequest](docs/GoogleCloudKmsRegisterKeyRequest.md)
 - [GoogleCloudKmsSignRequest](docs/GoogleCloudKmsSignRequest.md)
 - [GoogleCloudKmsVerifyRequest](docs/GoogleCloudKmsVerifyRequest.md)
 - [GoogleCloudKmsWriteKeyRequest](docs/GoogleCloudKmsWriteKeyRequest.md)
 - [GoogleCloudLoginRequest](docs/GoogleCloudLoginRequest.md)
 - [GoogleCloudWriteImpersonatedAccountRequest](docs/GoogleCloudWriteImpersonatedAccountRequest.md)
 - [GoogleCloudWriteRoleRequest](docs/GoogleCloudWriteRoleRequest.md)
 - [GoogleCloudWriteRolesetRequest](docs/GoogleCloudWriteRolesetRequest.md)
 - [GoogleCloudWriteStaticAccountRequest](docs/GoogleCloudWriteStaticAccountRequest.md)
 - [GroupCreateAliasRequest](docs/GroupCreateAliasRequest.md)
 - [GroupCreateRequest](docs/GroupCreateRequest.md)
 - [GroupLookUpRequest](docs/GroupLookUpRequest.md)
 - [GroupUpdateAliasByIdRequest](docs/GroupUpdateAliasByIdRequest.md)
 - [GroupUpdateByIdRequest](docs/GroupUpdateByIdRequest.md)
 - [GroupUpdateByNameRequest](docs/GroupUpdateByNameRequest.md)
 - [HaStatusResponse](docs/HaStatusResponse.md)
 - [InitializeRequest](docs/InitializeRequest.md)
 - [InternalClientActivityConfigureRequest](docs/InternalClientActivityConfigureRequest.md)
 - [InternalCountEntitiesResponse](docs/InternalCountEntitiesResponse.md)
 - [InternalCountTokensResponse](docs/InternalCountTokensResponse.md)
 - [InternalGenerateOpenApiDocumentWithParametersRequest](docs/InternalGenerateOpenApiDocumentWithParametersRequest.md)
 - [InternalUiListEnabledFeatureFlagsResponse](docs/InternalUiListEnabledFeatureFlagsResponse.md)
 - [InternalUiListEnabledVisibleMountsResponse](docs/InternalUiListEnabledVisibleMountsResponse.md)
 - [InternalUiListNamespacesResponse](docs/InternalUiListNamespacesResponse.md)
 - [InternalUiReadMountInformationResponse](docs/InternalUiReadMountInformationResponse.md)
 - [InternalUiReadResultantAclResponse](docs/InternalUiReadResultantAclResponse.md)
 - [JwtConfigureRequest](docs/JwtConfigureRequest.md)
 - [JwtLoginRequest](docs/JwtLoginRequest.md)
 - [JwtOidcCallbackFormPostRequest](docs/JwtOidcCallbackFormPostRequest.md)
 - [JwtOidcRequestAuthorizationUrlRequest](docs/JwtOidcRequestAuthorizationUrlRequest.md)
 - [JwtWriteRoleRequest](docs/JwtWriteRoleRequest.md)
 - [KerberosConfigureLdapRequest](docs/KerberosConfigureLdapRequest.md)
 - [KerberosConfigureRequest](docs/KerberosConfigureRequest.md)
 - [KerberosLoginRequest](docs/KerberosLoginRequest.md)
 - [KerberosWriteGroupRequest](docs/KerberosWriteGroupRequest.md)
 - [KubernetesConfigureAuthRequest](docs/KubernetesConfigureAuthRequest.md)
 - [KubernetesConfigureRequest](docs/KubernetesConfigureRequest.md)
 - [KubernetesGenerateCredentialsRequest](docs/KubernetesGenerateCredentialsRequest.md)
 - [KubernetesLoginRequest](docs/KubernetesLoginRequest.md)
 - [KubernetesWriteAuthRoleRequest](docs/KubernetesWriteAuthRoleRequest.md)
 - [KubernetesWriteRoleRequest](docs/KubernetesWriteRoleRequest.md)
 - [KvV2ConfigureRequest](docs/KvV2ConfigureRequest.md)
 - [KvV2DeleteVersionsRequest](docs/KvV2DeleteVersionsRequest.md)
 - [KvV2DestroyVersionsRequest](docs/KvV2DestroyVersionsRequest.md)
 - [KvV2PatchResponse](docs/KvV2PatchResponse.md)
 - [KvV2ReadConfigurationResponse](docs/KvV2ReadConfigurationResponse.md)
 - [KvV2ReadMetadataResponse](docs/KvV2ReadMetadataResponse.md)
 - [KvV2ReadResponse](docs/KvV2ReadResponse.md)
 - [KvV2ReadSubkeysResponse](docs/KvV2ReadSubkeysResponse.md)
 - [KvV2UndeleteVersionsRequest](docs/KvV2UndeleteVersionsRequest.md)
 - [KvV2WriteMetadataRequest](docs/KvV2WriteMetadataRequest.md)
 - [KvV2WriteRequest](docs/KvV2WriteRequest.md)
 - [KvV2WriteResponse](docs/KvV2WriteResponse.md)
 - [LdapConfigureAuthRequest](docs/LdapConfigureAuthRequest.md)
 - [LdapConfigureRequest](docs/LdapConfigureRequest.md)
 - [LdapLibraryCheckInRequest](docs/LdapLibraryCheckInRequest.md)
 - [LdapLibraryCheckOutRequest](docs/LdapLibraryCheckOutRequest.md)
 - [LdapLibraryConfigureRequest](docs/LdapLibraryConfigureRequest.md)
 - [LdapLibraryForceCheckInRequest](docs/LdapLibraryForceCheckInRequest.md)
 - [LdapLoginRequest](docs/LdapLoginRequest.md)
 - [LdapWriteDynamicRoleRequest](docs/LdapWriteDynamicRoleRequest.md)
 - [LdapWriteGroupRequest](docs/LdapWriteGroupRequest.md)
 - [LdapWriteStaticRoleRequest](docs/LdapWriteStaticRoleRequest.md)
 - [LdapWriteUserRequest](docs/LdapWriteUserRequest.md)
 - [LeaderStatusResponse](docs/LeaderStatusResponse.md)
 - [LeasesCountResponse](docs/LeasesCountResponse.md)
 - [LeasesListResponse](docs/LeasesListResponse.md)
 - [LeasesLookUpResponse](docs/LeasesLookUpResponse.md)
 - [LeasesReadLeaseRequest](docs/LeasesReadLeaseRequest.md)
 - [LeasesReadLeaseResponse](docs/LeasesReadLeaseResponse.md)
 - [LeasesRenewLease2Request](docs/LeasesRenewLease2Request.md)
 - [LeasesRenewLeaseRequest](docs/LeasesRenewLeaseRequest.md)
 - [LeasesRenewLeaseWithId2Request](docs/LeasesRenewLeaseWithId2Request.md)
 - [LeasesRenewLeaseWithIdRequest](docs/LeasesRenewLeaseWithIdRequest.md)
 - [LeasesRevokeLease2Request](docs/LeasesRevokeLease2Request.md)
 - [LeasesRevokeLeaseRequest](docs/LeasesRevokeLeaseRequest.md)
 - [LeasesRevokeLeaseWithId2Request](docs/LeasesRevokeLeaseWithId2Request.md)
 - [LeasesRevokeLeaseWithIdRequest](docs/LeasesRevokeLeaseWithIdRequest.md)
 - [LeasesRevokeLeaseWithPrefix2Request](docs/LeasesRevokeLeaseWithPrefix2Request.md)
 - [LeasesRevokeLeaseWithPrefixRequest](docs/LeasesRevokeLeaseWithPrefixRequest.md)
 - [LoggersUpdateVerbosityLevelForRequest](docs/LoggersUpdateVerbosityLevelForRequest.md)
 - [LoggersUpdateVerbosityLevelRequest](docs/LoggersUpdateVerbosityLevelRequest.md)
 - [MfaAdminDestroyTotpSecretRequest](docs/MfaAdminDestroyTotpSecretRequest.md)
 - [MfaAdminGenerateTotpSecretRequest](docs/MfaAdminGenerateTotpSecretRequest.md)
 - [MfaCreateDuoMethodRequest](docs/MfaCreateDuoMethodRequest.md)
 - [MfaCreateOktaMethodRequest](docs/MfaCreateOktaMethodRequest.md)
 - [MfaCreatePingIdMethodRequest](docs/MfaCreatePingIdMethodRequest.md)
 - [MfaCreateTotpMethodRequest](docs/MfaCreateTotpMethodRequest.md)
 - [MfaGenerateTotpSecretRequest](docs/MfaGenerateTotpSecretRequest.md)
 - [MfaUpdateDuoMethodRequest](docs/MfaUpdateDuoMethodRequest.md)
 - [MfaUpdateOktaMethodRequest](docs/MfaUpdateOktaMethodRequest.md)
 - [MfaUpdatePingIdMethodRequest](docs/MfaUpdatePingIdMethodRequest.md)
 - [MfaUpdateTotpMethodRequest](docs/MfaUpdateTotpMethodRequest.md)
 - [MfaValidateRequest](docs/MfaValidateRequest.md)
 - [MfaWriteLoginEnforcementRequest](docs/MfaWriteLoginEnforcementRequest.md)
 - [MongoDbAtlasConfigureRequest](docs/MongoDbAtlasConfigureRequest.md)
 - [MongoDbAtlasWriteRoleRequest](docs/MongoDbAtlasWriteRoleRequest.md)
 - [MountsEnableSecretsEngineRequest](docs/MountsEnableSecretsEngineRequest.md)
 - [MountsReadConfigurationResponse](docs/MountsReadConfigurationResponse.md)
 - [MountsReadTuningInformationResponse](docs/MountsReadTuningInformationResponse.md)
 - [MountsTuneConfigurationParametersRequest](docs/MountsTuneConfigurationParametersRequest.md)
 - [NomadConfigureAccessRequest](docs/NomadConfigureAccessRequest.md)
 - [NomadConfigureLeaseRequest](docs/NomadConfigureLeaseRequest.md)
 - [NomadWriteRoleRequest](docs/NomadWriteRoleRequest.md)
 - [OciConfigureRequest](docs/OciConfigureRequest.md)
 - [OciLoginRequest](docs/OciLoginRequest.md)
 - [OciWriteRoleRequest](docs/OciWriteRoleRequest.md)
 - [OidcConfigureRequest](docs/OidcConfigureRequest.md)
 - [OidcIntrospectRequest](docs/OidcIntrospectRequest.md)
 - [OidcProviderAuthorizeWithParametersRequest](docs/OidcProviderAuthorizeWithParametersRequest.md)
 - [OidcProviderTokenRequest](docs/OidcProviderTokenRequest.md)
 - [OidcRotateKeyRequest](docs/OidcRotateKeyRequest.md)
 - [OidcWriteAssignmentRequest](docs/OidcWriteAssignmentRequest.md)
 - [OidcWriteClientRequest](docs/OidcWriteClientRequest.md)
 - [OidcWriteKeyRequest](docs/OidcWriteKeyRequest.md)
 - [OidcWriteProviderRequest](docs/OidcWriteProviderRequest.md)
 - [OidcWriteRoleRequest](docs/OidcWriteRoleRequest.md)
 - [OidcWriteScopeRequest](docs/OidcWriteScopeRequest.md)
 - [OktaConfigureRequest](docs/OktaConfigureRequest.md)
 - [OktaLoginRequest](docs/OktaLoginRequest.md)
 - [OktaWriteGroupRequest](docs/OktaWriteGroupRequest.md)
 - [OktaWriteUserRequest](docs/OktaWriteUserRequest.md)
 - [PersonaCreateRequest](docs/PersonaCreateRequest.md)
 - [PersonaUpdateByIdRequest](docs/PersonaUpdateByIdRequest.md)
 - [PkiConfigureAcmeRequest](docs/PkiConfigureAcmeRequest.md)
 - [PkiConfigureAutoTidyRequest](docs/PkiConfigureAutoTidyRequest.md)
 - [PkiConfigureAutoTidyResponse](docs/PkiConfigureAutoTidyResponse.md)
 - [PkiConfigureCaRequest](docs/PkiConfigureCaRequest.md)
 - [PkiConfigureCaResponse](docs/PkiConfigureCaResponse.md)
 - [PkiConfigureClusterRequest](docs/PkiConfigureClusterRequest.md)
 - [PkiConfigureClusterResponse](docs/PkiConfigureClusterResponse.md)
 - [PkiConfigureCrlRequest](docs/PkiConfigureCrlRequest.md)
 - [PkiConfigureCrlResponse](docs/PkiConfigureCrlResponse.md)
 - [PkiConfigureIssuersRequest](docs/PkiConfigureIssuersRequest.md)
 - [PkiConfigureIssuersResponse](docs/PkiConfigureIssuersResponse.md)
 - [PkiConfigureKeysRequest](docs/PkiConfigureKeysRequest.md)
 - [PkiConfigureKeysResponse](docs/PkiConfigureKeysResponse.md)
 - [PkiConfigureUrlsRequest](docs/PkiConfigureUrlsRequest.md)
 - [PkiConfigureUrlsResponse](docs/PkiConfigureUrlsResponse.md)
 - [PkiCrossSignIntermediateRequest](docs/PkiCrossSignIntermediateRequest.md)
 - [PkiCrossSignIntermediateResponse](docs/PkiCrossSignIntermediateResponse.md)
 - [PkiGenerateEabKeyForIssuerAndRoleResponse](docs/PkiGenerateEabKeyForIssuerAndRoleResponse.md)
 - [PkiGenerateEabKeyForIssuerResponse](docs/PkiGenerateEabKeyForIssuerResponse.md)
 - [PkiGenerateEabKeyForRoleResponse](docs/PkiGenerateEabKeyForRoleResponse.md)
 - [PkiGenerateEabKeyResponse](docs/PkiGenerateEabKeyResponse.md)
 - [PkiGenerateExportedKeyRequest](docs/PkiGenerateExportedKeyRequest.md)
 - [PkiGenerateExportedKeyResponse](docs/PkiGenerateExportedKeyResponse.md)
 - [PkiGenerateIntermediateRequest](docs/PkiGenerateIntermediateRequest.md)
 - [PkiGenerateIntermediateResponse](docs/PkiGenerateIntermediateResponse.md)
 - [PkiGenerateInternalKeyRequest](docs/PkiGenerateInternalKeyRequest.md)
 - [PkiGenerateInternalKeyResponse](docs/PkiGenerateInternalKeyResponse.md)
 - [PkiGenerateKmsKeyRequest](docs/PkiGenerateKmsKeyRequest.md)
 - [PkiGenerateKmsKeyResponse](docs/PkiGenerateKmsKeyResponse.md)
 - [PkiGenerateRootRequest](docs/PkiGenerateRootRequest.md)
 - [PkiGenerateRootResponse](docs/PkiGenerateRootResponse.md)
 - [PkiImportKeyRequest](docs/PkiImportKeyRequest.md)
 - [PkiImportKeyResponse](docs/PkiImportKeyResponse.md)
 - [PkiIssueWithRoleRequest](docs/PkiIssueWithRoleRequest.md)
 - [PkiIssueWithRoleResponse](docs/PkiIssueWithRoleResponse.md)
 - [PkiIssuerIssueWithRoleRequest](docs/PkiIssuerIssueWithRoleRequest.md)
 - [PkiIssuerIssueWithRoleResponse](docs/PkiIssuerIssueWithRoleResponse.md)
 - [PkiIssuerReadCrlDeltaDerResponse](docs/PkiIssuerReadCrlDeltaDerResponse.md)
 - [PkiIssuerReadCrlDeltaPemResponse](docs/PkiIssuerReadCrlDeltaPemResponse.md)
 - [PkiIssuerReadCrlDeltaResponse](docs/PkiIssuerReadCrlDeltaResponse.md)
 - [PkiIssuerReadCrlDerResponse](docs/PkiIssuerReadCrlDerResponse.md)
 - [PkiIssuerReadCrlPemResponse](docs/PkiIssuerReadCrlPemResponse.md)
 - [PkiIssuerReadCrlResponse](docs/PkiIssuerReadCrlResponse.md)
 - [PkiIssuerResignCrlsRequest](docs/PkiIssuerResignCrlsRequest.md)
 - [PkiIssuerResignCrlsResponse](docs/PkiIssuerResignCrlsResponse.md)
 - [PkiIssuerSignIntermediateRequest](docs/PkiIssuerSignIntermediateRequest.md)
 - [PkiIssuerSignIntermediateResponse](docs/PkiIssuerSignIntermediateResponse.md)
 - [PkiIssuerSignRevocationListRequest](docs/PkiIssuerSignRevocationListRequest.md)
 - [PkiIssuerSignRevocationListResponse](docs/PkiIssuerSignRevocationListResponse.md)
 - [PkiIssuerSignSelfIssuedRequest](docs/PkiIssuerSignSelfIssuedRequest.md)
 - [PkiIssuerSignSelfIssuedResponse](docs/PkiIssuerSignSelfIssuedResponse.md)
 - [PkiIssuerSignVerbatimRequest](docs/PkiIssuerSignVerbatimRequest.md)
 - [PkiIssuerSignVerbatimResponse](docs/PkiIssuerSignVerbatimResponse.md)
 - [PkiIssuerSignVerbatimWithRoleRequest](docs/PkiIssuerSignVerbatimWithRoleRequest.md)
 - [PkiIssuerSignVerbatimWithRoleResponse](docs/PkiIssuerSignVerbatimWithRoleResponse.md)
 - [PkiIssuerSignWithRoleRequest](docs/PkiIssuerSignWithRoleRequest.md)
 - [PkiIssuerSignWithRoleResponse](docs/PkiIssuerSignWithRoleResponse.md)
 - [PkiIssuersGenerateIntermediateRequest](docs/PkiIssuersGenerateIntermediateRequest.md)
 - [PkiIssuersGenerateIntermediateResponse](docs/PkiIssuersGenerateIntermediateResponse.md)
 - [PkiIssuersGenerateRootRequest](docs/PkiIssuersGenerateRootRequest.md)
 - [PkiIssuersGenerateRootResponse](docs/PkiIssuersGenerateRootResponse.md)
 - [PkiIssuersImportBundleRequest](docs/PkiIssuersImportBundleRequest.md)
 - [PkiIssuersImportBundleResponse](docs/PkiIssuersImportBundleResponse.md)
 - [PkiIssuersImportCertRequest](docs/PkiIssuersImportCertRequest.md)
 - [PkiIssuersImportCertResponse](docs/PkiIssuersImportCertResponse.md)
 - [PkiListEabKeysResponse](docs/PkiListEabKeysResponse.md)
 - [PkiListIssuersResponse](docs/PkiListIssuersResponse.md)
 - [PkiListKeysResponse](docs/PkiListKeysResponse.md)
 - [PkiPatchIssuerResponse](docs/PkiPatchIssuerResponse.md)
 - [PkiPatchRoleResponse](docs/PkiPatchRoleResponse.md)
 - [PkiReadAutoTidyConfigurationResponse](docs/PkiReadAutoTidyConfigurationResponse.md)
 - [PkiReadCaChainPemResponse](docs/PkiReadCaChainPemResponse.md)
 - [PkiReadCaDerResponse](docs/PkiReadCaDerResponse.md)
 - [PkiReadCaPemResponse](docs/PkiReadCaPemResponse.md)
 - [PkiReadCertCaChainResponse](docs/PkiReadCertCaChainResponse.md)
 - [PkiReadCertCrlResponse](docs/PkiReadCertCrlResponse.md)
 - [PkiReadCertDeltaCrlResponse](docs/PkiReadCertDeltaCrlResponse.md)
 - [PkiReadCertRawDerResponse](docs/PkiReadCertRawDerResponse.md)
 - [PkiReadCertRawPemResponse](docs/PkiReadCertRawPemResponse.md)
 - [PkiReadCertResponse](docs/PkiReadCertResponse.md)
 - [PkiReadClusterConfigurationResponse](docs/PkiReadClusterConfigurationResponse.md)
 - [PkiReadCrlConfigurationResponse](docs/PkiReadCrlConfigurationResponse.md)
 - [PkiReadCrlDeltaPemResponse](docs/PkiReadCrlDeltaPemResponse.md)
 - [PkiReadCrlDeltaResponse](docs/PkiReadCrlDeltaResponse.md)
 - [PkiReadCrlDerResponse](docs/PkiReadCrlDerResponse.md)
 - [PkiReadCrlPemResponse](docs/PkiReadCrlPemResponse.md)
 - [PkiReadIssuerDerResponse](docs/PkiReadIssuerDerResponse.md)
 - [PkiReadIssuerJsonResponse](docs/PkiReadIssuerJsonResponse.md)
 - [PkiReadIssuerPemResponse](docs/PkiReadIssuerPemResponse.md)
 - [PkiReadIssuerResponse](docs/PkiReadIssuerResponse.md)
 - [PkiReadIssuersConfigurationResponse](docs/PkiReadIssuersConfigurationResponse.md)
 - [PkiReadKeyResponse](docs/PkiReadKeyResponse.md)
 - [PkiReadKeysConfigurationResponse](docs/PkiReadKeysConfigurationResponse.md)
 - [PkiReadRoleResponse](docs/PkiReadRoleResponse.md)
 - [PkiReadUrlsConfigurationResponse](docs/PkiReadUrlsConfigurationResponse.md)
 - [PkiReplaceRootRequest](docs/PkiReplaceRootRequest.md)
 - [PkiReplaceRootResponse](docs/PkiReplaceRootResponse.md)
 - [PkiRevokeIssuerResponse](docs/PkiRevokeIssuerResponse.md)
 - [PkiRevokeRequest](docs/PkiRevokeRequest.md)
 - [PkiRevokeResponse](docs/PkiRevokeResponse.md)
 - [PkiRevokeWithKeyRequest](docs/PkiRevokeWithKeyRequest.md)
 - [PkiRevokeWithKeyResponse](docs/PkiRevokeWithKeyResponse.md)
 - [PkiRootSignIntermediateRequest](docs/PkiRootSignIntermediateRequest.md)
 - [PkiRootSignIntermediateResponse](docs/PkiRootSignIntermediateResponse.md)
 - [PkiRootSignSelfIssuedRequest](docs/PkiRootSignSelfIssuedRequest.md)
 - [PkiRootSignSelfIssuedResponse](docs/PkiRootSignSelfIssuedResponse.md)
 - [PkiRotateCrlResponse](docs/PkiRotateCrlResponse.md)
 - [PkiRotateDeltaCrlResponse](docs/PkiRotateDeltaCrlResponse.md)
 - [PkiRotateRootRequest](docs/PkiRotateRootRequest.md)
 - [PkiRotateRootResponse](docs/PkiRotateRootResponse.md)
 - [PkiSetSignedIntermediateRequest](docs/PkiSetSignedIntermediateRequest.md)
 - [PkiSetSignedIntermediateResponse](docs/PkiSetSignedIntermediateResponse.md)
 - [PkiSignVerbatimRequest](docs/PkiSignVerbatimRequest.md)
 - [PkiSignVerbatimResponse](docs/PkiSignVerbatimResponse.md)
 - [PkiSignVerbatimWithRoleRequest](docs/PkiSignVerbatimWithRoleRequest.md)
 - [PkiSignVerbatimWithRoleResponse](docs/PkiSignVerbatimWithRoleResponse.md)
 - [PkiSignWithRoleRequest](docs/PkiSignWithRoleRequest.md)
 - [PkiSignWithRoleResponse](docs/PkiSignWithRoleResponse.md)
 - [PkiTidyCancelResponse](docs/PkiTidyCancelResponse.md)
 - [PkiTidyRequest](docs/PkiTidyRequest.md)
 - [PkiTidyStatusResponse](docs/PkiTidyStatusResponse.md)
 - [PkiWriteAcmeAccountKidRequest](docs/PkiWriteAcmeAccountKidRequest.md)
 - [PkiWriteAcmeAuthorizationAuthIdRequest](docs/PkiWriteAcmeAuthorizationAuthIdRequest.md)
 - [PkiWriteAcmeChallengeAuthIdChallengeTypeRequest](docs/PkiWriteAcmeChallengeAuthIdChallengeTypeRequest.md)
 - [PkiWriteAcmeNewAccountRequest](docs/PkiWriteAcmeNewAccountRequest.md)
 - [PkiWriteAcmeNewOrderRequest](docs/PkiWriteAcmeNewOrderRequest.md)
 - [PkiWriteAcmeOrderOrderIdCertRequest](docs/PkiWriteAcmeOrderOrderIdCertRequest.md)
 - [PkiWriteAcmeOrderOrderIdFinalizeRequest](docs/PkiWriteAcmeOrderOrderIdFinalizeRequest.md)
 - [PkiWriteAcmeOrderOrderIdRequest](docs/PkiWriteAcmeOrderOrderIdRequest.md)
 - [PkiWriteAcmeOrdersRequest](docs/PkiWriteAcmeOrdersRequest.md)
 - [PkiWriteAcmeRevokeCertRequest](docs/PkiWriteAcmeRevokeCertRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeAccountKidRequest](docs/PkiWriteIssuerIssuerRefAcmeAccountKidRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeAuthorizationAuthIdRequest](docs/PkiWriteIssuerIssuerRefAcmeAuthorizationAuthIdRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeChallengeAuthIdChallengeTypeRequest](docs/PkiWriteIssuerIssuerRefAcmeChallengeAuthIdChallengeTypeRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeNewAccountRequest](docs/PkiWriteIssuerIssuerRefAcmeNewAccountRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeNewOrderRequest](docs/PkiWriteIssuerIssuerRefAcmeNewOrderRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeOrderOrderIdCertRequest](docs/PkiWriteIssuerIssuerRefAcmeOrderOrderIdCertRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeOrderOrderIdFinalizeRequest](docs/PkiWriteIssuerIssuerRefAcmeOrderOrderIdFinalizeRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeOrderOrderIdRequest](docs/PkiWriteIssuerIssuerRefAcmeOrderOrderIdRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeOrdersRequest](docs/PkiWriteIssuerIssuerRefAcmeOrdersRequest.md)
 - [PkiWriteIssuerIssuerRefAcmeRevokeCertRequest](docs/PkiWriteIssuerIssuerRefAcmeRevokeCertRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeAccountKidRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeAccountKidRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeAuthorizationAuthIdRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeAuthorizationAuthIdRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeChallengeAuthIdChallengeTypeRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeChallengeAuthIdChallengeTypeRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeNewAccountRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeNewAccountRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeNewOrderRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeNewOrderRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdCertRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdCertRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdFinalizeRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdFinalizeRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeOrdersRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeOrdersRequest.md)
 - [PkiWriteIssuerIssuerRefRolesRoleAcmeRevokeCertRequest](docs/PkiWriteIssuerIssuerRefRolesRoleAcmeRevokeCertRequest.md)
 - [PkiWriteIssuerRequest](docs/PkiWriteIssuerRequest.md)
 - [PkiWriteIssuerResponse](docs/PkiWriteIssuerResponse.md)
 - [PkiWriteKeyRequest](docs/PkiWriteKeyRequest.md)
 - [PkiWriteKeyResponse](docs/PkiWriteKeyResponse.md)
 - [PkiWriteRoleRequest](docs/PkiWriteRoleRequest.md)
 - [PkiWriteRoleResponse](docs/PkiWriteRoleResponse.md)
 - [PkiWriteRolesRoleAcmeAccountKidRequest](docs/PkiWriteRolesRoleAcmeAccountKidRequest.md)
 - [PkiWriteRolesRoleAcmeAuthorizationAuthIdRequest](docs/PkiWriteRolesRoleAcmeAuthorizationAuthIdRequest.md)
 - [PkiWriteRolesRoleAcmeChallengeAuthIdChallengeTypeRequest](docs/PkiWriteRolesRoleAcmeChallengeAuthIdChallengeTypeRequest.md)
 - [PkiWriteRolesRoleAcmeNewAccountRequest](docs/PkiWriteRolesRoleAcmeNewAccountRequest.md)
 - [PkiWriteRolesRoleAcmeNewOrderRequest](docs/PkiWriteRolesRoleAcmeNewOrderRequest.md)
 - [PkiWriteRolesRoleAcmeOrderOrderIdCertRequest](docs/PkiWriteRolesRoleAcmeOrderOrderIdCertRequest.md)
 - [PkiWriteRolesRoleAcmeOrderOrderIdFinalizeRequest](docs/PkiWriteRolesRoleAcmeOrderOrderIdFinalizeRequest.md)
 - [PkiWriteRolesRoleAcmeOrderOrderIdRequest](docs/PkiWriteRolesRoleAcmeOrderOrderIdRequest.md)
 - [PkiWriteRolesRoleAcmeOrdersRequest](docs/PkiWriteRolesRoleAcmeOrdersRequest.md)
 - [PkiWriteRolesRoleAcmeRevokeCertRequest](docs/PkiWriteRolesRoleAcmeRevokeCertRequest.md)
 - [PluginsCatalogListPluginsResponse](docs/PluginsCatalogListPluginsResponse.md)
 - [PluginsCatalogListPluginsWithTypeResponse](docs/PluginsCatalogListPluginsWithTypeResponse.md)
 - [PluginsCatalogReadPluginConfigurationResponse](docs/PluginsCatalogReadPluginConfigurationResponse.md)
 - [PluginsCatalogReadPluginConfigurationWithTypeResponse](docs/PluginsCatalogReadPluginConfigurationWithTypeResponse.md)
 - [PluginsCatalogRegisterPluginRequest](docs/PluginsCatalogRegisterPluginRequest.md)
 - [PluginsCatalogRegisterPluginWithTypeRequest](docs/PluginsCatalogRegisterPluginWithTypeRequest.md)
 - [PluginsReloadBackendsRequest](docs/PluginsReloadBackendsRequest.md)
 - [PluginsReloadBackendsResponse](docs/PluginsReloadBackendsResponse.md)
 - [PluginsRuntimesCatalogListPluginsRuntimesResponse](docs/PluginsRuntimesCatalogListPluginsRuntimesResponse.md)
 - [PluginsRuntimesCatalogReadPluginRuntimeConfigurationResponse](docs/PluginsRuntimesCatalogReadPluginRuntimeConfigurationResponse.md)
 - [PluginsRuntimesCatalogRegisterPluginRuntimeRequest](docs/PluginsRuntimesCatalogRegisterPluginRuntimeRequest.md)
 - [PoliciesGeneratePasswordFromPasswordPolicyResponse](docs/PoliciesGeneratePasswordFromPasswordPolicyResponse.md)
 - [PoliciesListAclPolicies2Response](docs/PoliciesListAclPolicies2Response.md)
 - [PoliciesListAclPolicies3Response](docs/PoliciesListAclPolicies3Response.md)
 - [PoliciesListAclPoliciesResponse](docs/PoliciesListAclPoliciesResponse.md)
 - [PoliciesReadAclPolicy2Response](docs/PoliciesReadAclPolicy2Response.md)
 - [PoliciesReadAclPolicyResponse](docs/PoliciesReadAclPolicyResponse.md)
 - [PoliciesReadPasswordPolicyResponse](docs/PoliciesReadPasswordPolicyResponse.md)
 - [PoliciesWriteAclPolicy2Request](docs/PoliciesWriteAclPolicy2Request.md)
 - [PoliciesWriteAclPolicyRequest](docs/PoliciesWriteAclPolicyRequest.md)
 - [PoliciesWritePasswordPolicyRequest](docs/PoliciesWritePasswordPolicyRequest.md)
 - [QueryTokenAccessorCapabilitiesRequest](docs/QueryTokenAccessorCapabilitiesRequest.md)
 - [QueryTokenCapabilitiesRequest](docs/QueryTokenCapabilitiesRequest.md)
 - [QueryTokenSelfCapabilitiesRequest](docs/QueryTokenSelfCapabilitiesRequest.md)
 - [RabbitMqConfigureConnectionRequest](docs/RabbitMqConfigureConnectionRequest.md)
 - [RabbitMqConfigureLeaseRequest](docs/RabbitMqConfigureLeaseRequest.md)
 - [RabbitMqWriteRoleRequest](docs/RabbitMqWriteRoleRequest.md)
 - [RadiusConfigureRequest](docs/RadiusConfigureRequest.md)
 - [RadiusLoginRequest](docs/RadiusLoginRequest.md)
 - [RadiusLoginWithUsernameRequest](docs/RadiusLoginWithUsernameRequest.md)
 - [RadiusWriteUserRequest](docs/RadiusWriteUserRequest.md)
 - [RateLimitQuotasConfigureRequest](docs/RateLimitQuotasConfigureRequest.md)
 - [RateLimitQuotasReadConfigurationResponse](docs/RateLimitQuotasReadConfigurationResponse.md)
 - [RateLimitQuotasReadResponse](docs/RateLimitQuotasReadResponse.md)
 - [RateLimitQuotasWriteRequest](docs/RateLimitQuotasWriteRequest.md)
 - [RawReadResponse](docs/RawReadResponse.md)
 - [RawWriteRequest](docs/RawWriteRequest.md)
 - [ReadWrappingProperties2Response](docs/ReadWrappingProperties2Response.md)
 - [ReadWrappingPropertiesRequest](docs/ReadWrappingPropertiesRequest.md)
 - [ReadWrappingPropertiesResponse](docs/ReadWrappingPropertiesResponse.md)
 - [RekeyAttemptInitializeRequest](docs/RekeyAttemptInitializeRequest.md)
 - [RekeyAttemptInitializeResponse](docs/RekeyAttemptInitializeResponse.md)
 - [RekeyAttemptReadProgressResponse](docs/RekeyAttemptReadProgressResponse.md)
 - [RekeyAttemptUpdateRequest](docs/RekeyAttemptUpdateRequest.md)
 - [RekeyAttemptUpdateResponse](docs/RekeyAttemptUpdateResponse.md)
 - [RekeyReadBackupKeyResponse](docs/RekeyReadBackupKeyResponse.md)
 - [RekeyReadBackupRecoveryKeyResponse](docs/RekeyReadBackupRecoveryKeyResponse.md)
 - [RekeyVerificationCancelResponse](docs/RekeyVerificationCancelResponse.md)
 - [RekeyVerificationReadProgressResponse](docs/RekeyVerificationReadProgressResponse.md)
 - [RekeyVerificationUpdateRequest](docs/RekeyVerificationUpdateRequest.md)
 - [RekeyVerificationUpdateResponse](docs/RekeyVerificationUpdateResponse.md)
 - [RemountRequest](docs/RemountRequest.md)
 - [RemountResponse](docs/RemountResponse.md)
 - [RemountStatusResponse](docs/RemountStatusResponse.md)
 - [RewrapRequest](docs/RewrapRequest.md)
 - [RootTokenGenerationInitialize2Request](docs/RootTokenGenerationInitialize2Request.md)
 - [RootTokenGenerationInitialize2Response](docs/RootTokenGenerationInitialize2Response.md)
 - [RootTokenGenerationInitializeRequest](docs/RootTokenGenerationInitializeRequest.md)
 - [RootTokenGenerationInitializeResponse](docs/RootTokenGenerationInitializeResponse.md)
 - [RootTokenGenerationReadProgress2Response](docs/RootTokenGenerationReadProgress2Response.md)
 - [RootTokenGenerationReadProgressResponse](docs/RootTokenGenerationReadProgressResponse.md)
 - [RootTokenGenerationUpdateRequest](docs/RootTokenGenerationUpdateRequest.md)
 - [RootTokenGenerationUpdateResponse](docs/RootTokenGenerationUpdateResponse.md)
 - [SealStatusResponse](docs/SealStatusResponse.md)
 - [SshConfigureCaRequest](docs/SshConfigureCaRequest.md)
 - [SshConfigureZeroAddressRequest](docs/SshConfigureZeroAddressRequest.md)
 - [SshGenerateCredentialsRequest](docs/SshGenerateCredentialsRequest.md)
 - [SshIssueCertificateRequest](docs/SshIssueCertificateRequest.md)
 - [SshListRolesByIpRequest](docs/SshListRolesByIpRequest.md)
 - [SshSignCertificateRequest](docs/SshSignCertificateRequest.md)
 - [SshVerifyOtpRequest](docs/SshVerifyOtpRequest.md)
 - [SshWriteRoleRequest](docs/SshWriteRoleRequest.md)
 - [StandardListResponse](docs/StandardListResponse.md)
 - [TerraformCloudConfigureRequest](docs/TerraformCloudConfigureRequest.md)
 - [TerraformCloudWriteRoleRequest](docs/TerraformCloudWriteRoleRequest.md)
 - [TokenCreateAgainstRoleRequest](docs/TokenCreateAgainstRoleRequest.md)
 - [TokenCreateOrphanRequest](docs/TokenCreateOrphanRequest.md)
 - [TokenCreateRequest](docs/TokenCreateRequest.md)
 - [TokenLookUpAccessorRequest](docs/TokenLookUpAccessorRequest.md)
 - [TokenLookUpRequest](docs/TokenLookUpRequest.md)
 - [TokenLookUpSelf2Request](docs/TokenLookUpSelf2Request.md)
 - [TokenRenewAccessorRequest](docs/TokenRenewAccessorRequest.md)
 - [TokenRenewRequest](docs/TokenRenewRequest.md)
 - [TokenRenewSelfRequest](docs/TokenRenewSelfRequest.md)
 - [TokenRevokeAccessorRequest](docs/TokenRevokeAccessorRequest.md)
 - [TokenRevokeOrphanRequest](docs/TokenRevokeOrphanRequest.md)
 - [TokenRevokeRequest](docs/TokenRevokeRequest.md)
 - [TokenWriteRoleRequest](docs/TokenWriteRoleRequest.md)
 - [TotpCreateKeyRequest](docs/TotpCreateKeyRequest.md)
 - [TotpValidateCodeRequest](docs/TotpValidateCodeRequest.md)
 - [TransitConfigureCacheRequest](docs/TransitConfigureCacheRequest.md)
 - [TransitConfigureKeyRequest](docs/TransitConfigureKeyRequest.md)
 - [TransitConfigureKeysRequest](docs/TransitConfigureKeysRequest.md)
 - [TransitCreateKeyRequest](docs/TransitCreateKeyRequest.md)
 - [TransitDecryptRequest](docs/TransitDecryptRequest.md)
 - [TransitEncryptRequest](docs/TransitEncryptRequest.md)
 - [TransitGenerateCsrForKeyRequest](docs/TransitGenerateCsrForKeyRequest.md)
 - [TransitGenerateDataKeyRequest](docs/TransitGenerateDataKeyRequest.md)
 - [TransitGenerateHmacRequest](docs/TransitGenerateHmacRequest.md)
 - [TransitGenerateHmacWithAlgorithmRequest](docs/TransitGenerateHmacWithAlgorithmRequest.md)
 - [TransitGenerateRandomRequest](docs/TransitGenerateRandomRequest.md)
 - [TransitGenerateRandomWithBytesRequest](docs/TransitGenerateRandomWithBytesRequest.md)
 - [TransitGenerateRandomWithSourceAndBytesRequest](docs/TransitGenerateRandomWithSourceAndBytesRequest.md)
 - [TransitGenerateRandomWithSourceRequest](docs/TransitGenerateRandomWithSourceRequest.md)
 - [TransitHashRequest](docs/TransitHashRequest.md)
 - [TransitHashWithAlgorithmRequest](docs/TransitHashWithAlgorithmRequest.md)
 - [TransitImportKeyRequest](docs/TransitImportKeyRequest.md)
 - [TransitImportKeyVersionRequest](docs/TransitImportKeyVersionRequest.md)
 - [TransitRestoreAndRenameKeyRequest](docs/TransitRestoreAndRenameKeyRequest.md)
 - [TransitRestoreKeyRequest](docs/TransitRestoreKeyRequest.md)
 - [TransitRewrapRequest](docs/TransitRewrapRequest.md)
 - [TransitRotateKeyRequest](docs/TransitRotateKeyRequest.md)
 - [TransitSetCertificateForKeyRequest](docs/TransitSetCertificateForKeyRequest.md)
 - [TransitSignRequest](docs/TransitSignRequest.md)
 - [TransitSignWithAlgorithmRequest](docs/TransitSignWithAlgorithmRequest.md)
 - [TransitTrimKeyRequest](docs/TransitTrimKeyRequest.md)
 - [TransitVerifyRequest](docs/TransitVerifyRequest.md)
 - [TransitVerifyWithAlgorithmRequest](docs/TransitVerifyWithAlgorithmRequest.md)
 - [UiHeadersConfigureRequest](docs/UiHeadersConfigureRequest.md)
 - [UiHeadersListResponse](docs/UiHeadersListResponse.md)
 - [UiHeadersReadConfigurationResponse](docs/UiHeadersReadConfigurationResponse.md)
 - [UnsealRequest](docs/UnsealRequest.md)
 - [UnsealResponse](docs/UnsealResponse.md)
 - [UnwrapRequest](docs/UnwrapRequest.md)
 - [UserpassLoginRequest](docs/UserpassLoginRequest.md)
 - [UserpassResetPasswordRequest](docs/UserpassResetPasswordRequest.md)
 - [UserpassUpdatePoliciesRequest](docs/UserpassUpdatePoliciesRequest.md)
 - [UserpassWriteUserRequest](docs/UserpassWriteUserRequest.md)
 - [VersionHistoryResponse](docs/VersionHistoryResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




